-- * PLSQL:       doe_co2_summary_ascii_pkg.sql Version 1.1 06/11/2014
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2014 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE doe_co2_summary_ascii_pkg AS
  PROCEDURE build_csv_page_all;
  PROCEDURE build_csv_page(sCounty IN VARCHAR2);
  PROCEDURE build_csv_las_page(sCounty IN VARCHAR2);
  PROCEDURE build_csv_tops_page(sCounty IN VARCHAR2);
  PROCEDURE build_csv_geo_page(sCounty IN VARCHAR2);
  PROCEDURE build_csv_las3_page(sCounty IN VARCHAR2);
--
  PROCEDURE build_csv_las_page;
  PROCEDURE build_csv_tops_page;
  PROCEDURE build_csv_las3_page;
--
  PROCEDURE add_well(sKID IN VARCHAR2);
  PROCEDURE add_las(sKID IN VARCHAR2);
  FUNCTION count_log(sLASKID IN VARCHAR2,
                     sPhrase IN VARCHAR2) RETURN NUMBER;
  PROCEDURE add_tops(sKID IN VARCHAR2);
  PROCEDURE add_georeport(sKID IN VARCHAR2);
  PROCEDURE add_las3(sKID IN VARCHAR2);
END doe_co2_summary_ascii_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY doe_co2_summary_ascii_pkg AS
--
-- PROCEDURE    build_csv_page_all()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_page_all IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_api    user_headers.api_number%TYPE;  -- API-Number
    o_temp   VARCHAR2(255);
--
    CURSOR crsr IS
      SELECT kid, qwh.api_number
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid
     ORDER BY api_number;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid;
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>DOE_CO2_Wells</TITLE></HEAD><BODY>');
    htp.p( 'Summary Page for All Type Log Wells<br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Type Log, LAS Files,Tops,Georeport,LAS 3.0,Status, <br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;    -- API-Number
        EXIT WHEN crsr%NOTFOUND;
--
        add_well(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_page_all;
--
--
-- PROCEDURE    build_csv_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>'||INITCAP(sCounty)||'</TITLE></HEAD><BODY>');
--    
    htp.p( 'Summary Page for '||INITCAP(sCounty)||' County <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Type Log,LAS Files,Tops,Georeport,LAS 3.0,Status, <br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_well(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_page;
--
--
-- PROCEDURE    build_csv_las_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the KGS LAS File Information.
-- * Input:     sCounty = the county to select from 
-- * Output:    Tops Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_las_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>'||INITCAP(sCounty)||'_LAS</TITLE></HEAD><BODY>');
--    
    htp.p( 'KGS LAS File Summary Page for '||INITCAP(sCounty)||' County <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Start,Stop,SP,GR,OHM-M,DT,RHOB,NPHI,PE,TH,U,K,GR,NEUT,LAS File,<br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_las(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_las_page;
--
--
-- PROCEDURE    build_csv_tops_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the Type Tops Data.
-- * Input:     sCounty = the county to select from 
-- * Output:    Tops Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_tops_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>'||INITCAP(sCounty)||'_Tops</TITLE></HEAD><BODY>');
--    
    htp.p( 'Tops Summary Page for '||INITCAP(sCounty)||' County <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Top,Base,Name,Rank,System,Subsystem,Series,Source,Level,Reject, <br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_tops(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_tops_page;
--
--
-- PROCEDURE    build_csv_geo_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the Geologist Report File Information.
-- * Input:     sCounty = the county to select from 
-- * Output:    Tops Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_geo_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>'||INITCAP(sCounty)||'_GEO_REPORTS</TITLE></HEAD><BODY>');
--    
    htp.p( 'Geologist Report File Summary Page for '||INITCAP(sCounty)||' County <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Start,Stop,Geologist Report ASCII File,<br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_georeport(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_geo_page;
--
--
-- PROCEDURE    build_csv_las3_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the KGS LAS 3.0 File Information.
-- * Input:     sCounty = the county to select from 
-- * Output:    Tops Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_las3_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>'||INITCAP(sCounty)||'_LAS_3</TITLE></HEAD><BODY>');
--    
    htp.p( 'LAS version 3.0 File Summary Page for '||INITCAP(sCounty)||' County <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Start,Stop,GR,OHM-M,DT,RHOB,NPHI,PE,TH,U,K,LAS 3.0 File,<br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_las3(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_las3_page;
--
--
-- PROCEDURE    build_csv_las_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the KGS LAS File Information.
-- * Output:    Tops Summary Web Page for Kansas.
--
  PROCEDURE build_csv_las_page IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid;
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>All_Counties_LAS</TITLE></HEAD><BODY>');
--    
    htp.p( 'KGS LAS File Summary Page for All Counties <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Start,Stop,SP,GR,OHM-M,DT,RHOB,NPHI,PE,TH,U,K,GR,NEUT,LAS File,<br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_las(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_las_page;
--
--
-- PROCEDURE    build_csv_tops_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the Type Tops Data.
-- * Output:    Tops Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_csv_tops_page IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid;
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE> All Counties Tops</TITLE></HEAD><BODY>');
--    
    htp.p( 'Tops Summary Page for All Counties <br>' );
    o_temp := 'KID, API-Number, Well Name,Operator,TRS,Top,Base,Name,Rank,System,Subsystem,Series,Source,Level,Reject, <br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_tops(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_tops_page;
--
--
-- PROCEDURE    build_csv_las3_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table and the KGS LAS 3.0 File Information.
-- * Output:    Tops Summary Web Page for all Counties of Kansas.
--
  PROCEDURE build_csv_las3_page IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
    o_temp   VARCHAR2(255);
--
    CURSOR crsr IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
       WHERE qwh.kid = itlw.well_header_kid;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid;
--
--  Start CSV Output
--
    htp.print('<HTML><HEAD><TITLE>All_Counties_LAS_3</TITLE></HEAD><BODY>');
--    
    htp.p( 'LAS version 3.0 File Summary Page for All Counties <br>' );
    o_temp := 'KID, API-Number, Well Name,TRS,Start,Stop,GR,OHM-M,DT,RHOB,NPHI,PE,TH,U,K,LAS 3.0 File,<br>';
    htp.p( o_temp );
--
    IF (l_count > 0) THEN
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        add_las3(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    htp.print('</BODY></HTML>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
        htp.p(SQLERRM);
  END build_csv_las3_page;
--
--
-- PROCEDURE    add_well()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct well data table.
-- Input:       sKID = Headers Primary Key of the header information data 
--
  PROCEDURE add_well(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
    o_temp       VARCHAR2(255);
--    
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
    l_percent    NUMBER;
--
    tl_cnt       NUMBER(6);  -- Number of Type Log indicator
    l_cnt        NUMBER(6);  -- Number of LAS Files
    lu_cnt       NUMBER(6);  -- Number of LAS Upload Files
    t_cnt        NUMBER(6);  -- Number of tops
    te_cnt       NUMBER(6);  -- Number of tops Evaluated
    tr_cnt       NUMBER(6);  -- Number of tops Evaluated-Rejected
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
    e_cnt        NUMBER(6);  -- Number of ELOG Davies Files
    e2_cnt       NUMBER(6);  -- Number of ELOG Files
    s_cnt        NUMBER(6);  -- Number of Scan URLs 
    g_cnt        NUMBER(6);  -- Number of ASCII Georeport Files
    l3_cnt       NUMBER(6);  -- Number of LAS 3.0 Files
    l3_status    iqstrat.doe_co2_las3.file_status%TYPE; -- Status
--
    l_start      las.well_headers.depth_start%TYPE;  -- Starting Depth of LAS File
    l_stop       las.well_headers.depth_stop%TYPE;   -- Ending Depth of LAS File
    l_max        NUMBER(6);
    l_min        NUMBER(6);   
    las_value    NUMBER(6);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),',',' '), '-99'),
             NVL(status, '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT MIN(depth_start),           
           MAX(depth_stop)             
      FROM las.well_headers
     WHERE well_header_kid = sKID;
--       
  BEGIN
--
    o_kid       := '-99';
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Location Columns
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Location Columns
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df;        -- elevation derrick floor (well)
--            o_comments;  -- general comments
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
      tl_cnt := 0;
      SELECT COUNT(*)
        INTO tl_cnt
        FROM iqstrat.type_log_wells        
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid);
--
      e_cnt := 0;
      SELECT COUNT(*)
        INTO e_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
--       WHERE well_header_kid = o_kid
         AND logger_id = 6422
         AND (tool_id = 6423
          OR  tool_id = 7924);
--
      e2_cnt := 0;
      SELECT COUNT(*)
        INTO e2_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
         AND logger_id = 83
         AND tool_id   = 1165;
--          OR tool_id   = 1137;
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
        FROM iqstrat.doe_co2_tops
       WHERE well_header_kid  = o_kid;
--       
      g_cnt := 0;
      SELECT COUNT(*)
        INTO g_cnt
       FROM iqstrat.doe_co2_georeport
      WHERE well_header_kid = o_kid; 
--
      l3_cnt := 0;
      SELECT COUNT(*)
        INTO l3_cnt
        FROM iqstrat.doe_co2_las3
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--         
--    Validate LAS File Depth Range with Tops
--
      IF (l_cnt > 0) THEN
        las_value := 0;
--        
        OPEN las_file_info_crsr(o_kid);
        LOOP
          FETCH las_file_info_crsr
           INTO  l_start,
                 l_stop;
          EXIT WHEN las_file_info_crsr%NOTFOUND;
--
          IF (t_cnt > 0) AND (las_value = 0) THEN
            SELECT MAX(depth_top), MIN(depth_top)
              INTO l_max, l_min
              FROM iqstrat.doe_co2_tops
             WHERE well_header_kid = o_kid;
--      
            IF (l_min >= l_start) AND (l_max <= l_stop) THEN
                las_value := 2;
            ELSIF (l_min >= l_start) OR (l_max <= l_stop) THEN
                IF (las_value < 2) THEN
                  las_value := 1;
                END IF;
            ELSE
              IF (las_value < 1) THEN
                las_value := 0;
              END IF;
            END IF;
          END IF;
--
        END LOOP;
        CLOSE las_file_info_crsr;
      END IF;
--
--    CSV Well Record
--
      o_temp := o_kid||',';
--
      IF (o_api != '-99') THEN
        o_temp := o_temp||o_api||',';
      ELSE
        o_temp := o_temp||' ,';
      END IF;
--
      o_temp := o_temp||o_name||',';
      o_temp := o_temp||o_TRS||',';
--      
      IF (tl_cnt > 0) THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||' ,';
      END IF;
--        
      o_temp := o_temp||l_cnt||',';
      o_temp := o_temp||t_cnt||',';
--
      IF (e_cnt > 0) AND (g_cnt = 0) THEN
        o_temp := o_temp||'TIFF (Davies),';
      ELSIF (e2_cnt > 0) AND (g_cnt = 0) THEN
        o_temp := o_temp||'TIFF (Other),';
      ELSIF (g_cnt > 0) THEN
        o_temp := o_temp||'ASCII Text,';
      ELSE
        o_temp := o_temp||' ,';
      END IF;
--
      l3_status := '-99';
      IF (l3_cnt > 0) THEN
        SELECT NVL(file_status, '-99') 
          INTO l3_status
          FROM iqstrat.doe_co2_las3
--         WHERE well_header_kid = o_kid; 
         WHERE well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = o_kid));
--
        IF (l3_status != '-99') THEN
          o_temp := o_temp||'GOOD,';
        ELSE
          o_temp := o_temp||'FAIR,';
        END IF;
      ELSE 
        o_temp := o_temp||' ,';
      END IF;
--
      IF (t_cnt > 0) THEN
        IF (l_cnt > 0) THEN
          IF (l_percent < 15) THEN
            o_temp := o_temp||'Poor';
          ELSIF (l_percent < 60) THEN
            o_temp := o_temp||'Partial';
          ELSIF (l_percent < 95) THEN
            o_temp := o_temp||'Good';
          ELSIF (l3_status != '-99') THEN
            o_temp := o_temp||'Complete';
          ELSE
            o_temp := o_temp||'Excellent';
          END IF;
        ELSE
          o_temp := o_temp||'Poor';
        END IF;
      ELSE
        o_temp := o_temp||'Empty';
      END IF;
--
      htp.p( o_temp||', <br>' );
--        
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
--
  END add_well;
--
--
-- PROCEDURE    add_las
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_las(sKID IN VARCHAR2) IS
--
    o_kid           NUMBER(10);    -- Well Header KID
    l_count         NUMBER(6);     -- Total Number of LAS Files
    o_temp          VARCHAR2(255);
    o_temp2         VARCHAR2(255);
--   LAS File Information
    o_las_kid       NUMBER(10);    -- Primary Key for the LAS File
    o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
    o_file_path     VARCHAR2(255); -- File Path to LAS File
    o_path          VARCHAR2(255); -- File Path to LAS File
    o_file_name     VARCHAR2(255); -- File Name of LAS File
    o_version       VARCHAR2(20);  -- Version Number of LAS File
    o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
    o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
    o_proprietary   NUMBER(5);     -- Proprietary Indicator
    o_length        NUMBER(4);     -- Total las_path to trim
--   Type of Log Curves Available
    o_ohm           NUMBER(3);     -- Resistivity Log Curves
    o_density       NUMBER(3);     -- Density Log Curves
    o_neutron       NUMBER(3);     -- Neutron Log Curves
    o_sonic         NUMBER(3);     -- Sonic Log Curves
    o_sp            NUMBER(3);     -- Spontaneous Potential Log Curve
    o_gamma         NUMBER(3);     -- Gamma Ray Log Curve
    o_caliper       NUMBER(3);     -- Caliper Log Curves
    o_pe            NUMBER(3);     -- Photoelectric Log Curves
    o_th            NUMBER(3);     -- Thorium Log Curve
    o_u             NUMBER(3);     -- Uranium Log Curves
    o_p             NUMBER(3);     -- Potassium Log Curves
    o_gr_cnt        NUMBER(3);     -- Gamma Ray Count Log Curve
    o_neut_cnt      NUMBER(3);     -- Neutron Count Log Curve
--
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_well_name  VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
--
    CURSOR crsr0 (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),',',' '), '-99'),
             NVL(status, '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
-- LAS File Cursor to retrieve all the LAS Files for a specific well
--
    CURSOR las_file_info_crsr (sKID VARCHAR2) IS
      SELECT kid,                   -- Primary Key for the LAS File
             well_header_kid,       -- Primary Key for the Well Header
             las_path,              -- Strip Initial Unix File Path for URL Ref
             las_filename,          -- Filename of LAS File
             las_version,           -- Version Number of LAS File
             depth_start,           -- Starting Depth of LAS File
             depth_stop,            -- Ending Depth of LAS File
             proprietary,           -- Is the File Protected?
             INSTR(las_path, 'WellLogs')
      FROM las.well_headers
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = (SELECT well_header_kid
                                                           FROM qualified.well_headers
                                                          WHERE kid = sKID));
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM las.well_headers
      WHERE well_header_kid IN (SELECT kid
                                  FROM qualified.well_headers
                                 WHERE well_header_kid = (SELECT well_header_kid
                                                            FROM qualified.well_headers
                                                           WHERE kid = sKID));
--
--  Build Table
--
    IF (l_count > 0) THEN
--
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
        o_temp2 := o_temp2||o_TRS||',';
--
      CLOSE crsr0;
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_las_kid,
              o_well_kid,
              o_file_path,
              o_file_name,
              o_version,
              o_depth_start,
              o_depth_end,
              o_proprietary,
              o_length;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
      SELECT SUBSTR(o_file_path, o_length)
        INTO o_path
        FROM DUAL;
--
        o_caliper := count_log(o_las_kid,'%CALIPER%');
        o_sp := count_log(o_las_kid,'%SPONTANEOUS%');
        o_gamma := count_log(o_las_kid,'%GAMMA%');
        o_ohm := count_log(o_las_kid,'%RESISTIVITY%');
        o_sonic := count_log(o_las_kid,'%SONIC%');
        o_density := count_log(o_las_kid,'%DENSITY%');
        o_neutron := count_log(o_las_kid,'%NEUTRON%');
        o_pe := count_log(o_las_kid,'%PHOTOELECTRIC%');
        o_th := count_log(o_las_kid,'%THORIUM%');
        o_u := count_log(o_las_kid,'%URANIUM%');
        o_p := count_log(o_las_kid,'%POTASSIUM%');
        o_gr_cnt   := 0;
        o_neut_cnt := count_log(o_las_kid,'%NEUTRON COUNTS%');
--
        o_temp := o_depth_start||',';
        o_temp := o_temp||o_depth_end||',';
--          
        IF (o_sp > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_gamma > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_ohm > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_sonic > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_density > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_neutron > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_pe > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_th > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_u > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--          
        IF (o_p > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--   
        IF (o_gr_cnt > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--   
        IF (o_neut_cnt > 0) THEN
          o_temp := o_temp||'YES,';
        ELSE
          o_temp := o_temp||'NO,';
        END IF;
--   
        o_temp := o_temp||'http://www.kgs.ku.edu/'||o_path||'/'||o_las_kid||'.las,';
--
        htp.p( o_temp2||o_temp||' <br>' );
--
      END LOOP;
      CLOSE las_file_info_crsr;
    ELSE
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
        o_temp2 := o_temp2||o_TRS||',';
        o_temp2 := o_temp2||', , , , , , , , , , , , , , ,';
--
      CLOSE crsr0;
--
      htp.p( o_temp2||' <br>' );
--
    END IF;
--
  END add_las;
--
--
-- PROCEDURE    count_log
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    Count of specific curve type.
--
  FUNCTION count_log(sLASKID IN VARCHAR2,
                     sPhrase IN VARCHAR2) RETURN NUMBER IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Curve Types
--
  BEGIN
    l_count := 0;
--
    SELECT COUNT(*)
      INTO l_count               -- Key Word for the LAS Curve
      FROM las.tools,
           las.well_headers_curves
     WHERE las.tools.kid = las.well_headers_curves.tool_kid
       AND UPPER(standard_name) LIKE sPhrase
       AND las.well_headers_curves.las_kid = sLASKID;
--
     RETURN l_count;
--
  END count_log;
--
--
-- PROCEDURE    add_tops
-- Description: This procedure will build a Well Tops Table
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_tops(sKID IN VARCHAR2) IS
--
    l_cnt        NUMBER;
    tr_cnt       NUMBER;
    l_count      NUMBER(6);
    l_count2     NUMBER(6);
    o_temp       VARCHAR2(255);
    o_temp2      VARCHAR2(255);
--
    o_initials   iqstrat.type_log_users.initials%TYPE;  -- User's Initials
--
    o_kid        iqstrat.zeller.KID%TYPE;      -- Unique KEY For record
    o_seq        iqstrat.zeller.sequence%TYPE; -- Order 
    o_rank       iqstrat.zeller.rank%TYPE;     -- Rank, SYSTEM,SERIES, etc.
    o_name       iqstrat.zeller.name%TYPE;     -- Name of Unit
--    
    o_src        iqstrat.doe_co2_tops.source_kid%TYPE; -- Source KID
    o_top        iqstrat.doe_co2_tops.depth_top%TYPE;  -- Start Depth
    o_base       iqstrat.doe_co2_tops.depth_base%TYPE; -- End Depth
--    
    o_level      VARCHAR2(20);
--
    o_system     iqstrat.zeller.name%TYPE;     -- System name
    o_series     iqstrat.zeller.name%TYPE;     -- Series name
    o_subsystem  iqstrat.zeller.name%TYPE;     -- Subsystem name
    o_subseries  iqstrat.zeller.name%TYPE;     -- Subseries name                       
    o_stage      iqstrat.zeller.name%TYPE;     -- Stage name
    o_supergroup iqstrat.zeller.name%TYPE;     -- Supergroup name
    o_group      iqstrat.zeller.name%TYPE;     -- Group name
    o_subgroup   iqstrat.zeller.name%TYPE;     -- Subgroup name
    o_formation  iqstrat.zeller.name%TYPE;     -- formation name
--
    o_well_kid   qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_well_name  VARCHAR(200);                           -- Well Name or Outcrop Name
    o_operator   qualified.well_headers.operator_name%TYPE;   -- Operator Name 
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
--
    CURSOR crsr0 (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),',',' '), '-99'),
             NVL(REPLACE(operator_name,',',' '), '-99'),
             NVL(status, '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.source_kid,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
         AND tlt.well_header_kid = sKID
    ORDER BY iz.sequence;
--
  BEGIN
--
    SELECT COUNT(iz.kid) 
      INTO l_count
      FROM iqstrat.zeller iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
       AND tlt.well_header_kid = sKID;
--
    IF (l_count > 0) THEN
--
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_operator,  -- Operator Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;
--
        o_temp2 := o_temp2||o_well_name||',';
--
        IF (o_operator != '-99') THEN
          o_temp2 := o_temp2||o_operator||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;
--
        o_temp2 := o_temp2||o_TRS||',';
--
      CLOSE crsr0;
--
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_kid,        -- Unique KEY For record
              o_seq,        -- Order 
              o_rank,       -- Rank, SYSTEM,SERIES, etc.
              o_name,       -- Name of Unit
--            
              o_src,        -- Source KID
              o_top,        -- Start Depth
              o_base,       -- End Depth
--    
              o_system,     -- System name
              o_series,     -- Series name
              o_subsystem,  -- Subsystem name
              o_subseries,  -- Subseries name                       
              o_stage,      -- Stage name
              o_supergroup, -- Supergroup name
              o_group,      -- Group name
              o_subgroup,   -- Subgroup name
              o_formation;  -- formation name
        EXIT WHEN crsr%NOTFOUND;
--
        SELECT initials
          INTO o_initials
          FROM iqstrat.type_log_users
         WHERE kid = o_src;
--
        o_temp := o_top||',';
--
        IF (o_base > o_top) THEN
          o_temp := o_temp||o_base||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--          
        o_temp := o_temp||o_name||',';
--          
        o_temp := o_temp||o_rank||',';
--          
        IF (o_system != '99999') THEN
          o_temp := o_temp||o_system||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--          
        IF (o_subsystem != '99999') THEN
          o_temp := o_temp||o_subsystem||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--          
        IF (o_series != '99999') THEN
          o_temp := o_temp||o_series||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--          
        o_temp := o_temp||o_initials||',';
--          
        IF (l_cnt = 3) THEN
          o_temp := o_temp||'Excellent,';
        ELSIF (l_cnt = 2) THEN
          o_temp := o_temp||'Good,';
        ELSIF (l_cnt = 1) THEN
          o_temp := o_temp||'Fair,';
        ELSE      
          o_temp := o_temp||'Poor,';
        END IF;
--
        IF (tr_cnt > 0) THEN
          o_temp := o_temp||tr_cnt||',';
        ELSE
          o_temp := o_temp||' ,';
        END IF;
--
      htp.p( o_temp2||o_temp||' <br>' );
--
    END LOOP;
    CLOSE crsr;
--
    ELSE
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_operator,  -- Operator Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
--
        IF (o_operator != '-99') THEN
          o_temp2 := o_temp2||o_operator||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;
--
        o_temp2 := o_temp2||o_TRS||',';
        o_temp2 := o_temp2||' , , , , , , , , , ,';
--
        htp.p( o_temp2||' <br>' );
--        
      CLOSE crsr0;
--
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
--
  END add_tops;
--
--
-- PROCEDURE    add_georeport
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_georeport(sKID IN VARCHAR2) IS
--
    l_count         NUMBER(6);     -- Total Number of LAS Files
    o_temp          VARCHAR2(255);
    o_temp2         VARCHAR2(255);
-- LAS File Information
    o_las_kid       NUMBER(10);    -- Primary Key for the LAS File
    o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
    o_file_path     VARCHAR2(255); -- File Path to LAS File
    o_file_name     VARCHAR2(255); -- File Name of LAS File
    o_version       VARCHAR2(20);  -- Version Number of LAS File
    o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
    o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
    o_proprietary   NUMBER(5);     -- Proprietary Indicator
--
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_well_name  VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
--
    CURSOR crsr0 (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),',',' '), '-99'),
             NVL(status, '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
-- LAS File Cursor to retrieve all the LAS Files for a specific well
--
    CURSOR las_file_info_crsr (sKID VARCHAR2) IS
      SELECT well_header_kid,       -- Primary Key for the Well Header
             geo_path,              -- Unix File Path for URL Ref
             geo_filename,          -- Filename of File
             depth_start,           -- Starting Depth of File
             depth_stop             -- Ending Depth of File
        FROM iqstrat.doe_co2_georeport
       WHERE well_header_kid = sKID;
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(well_header_kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM iqstrat.doe_co2_georeport
     WHERE well_header_kid = sKID;
--
--  Build Table
--
    IF (l_count > 0) THEN
--    
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
        o_temp2 := o_temp2||o_TRS||',';
--
      CLOSE crsr0;
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_well_kid,
              o_file_path,
              o_file_name,
              o_depth_start,
              o_depth_end;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
        o_temp := o_depth_start||',';
        o_temp := o_temp||o_depth_end||',';
--          
        o_temp := o_temp||'http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||',';
--
        htp.p( o_temp2||o_temp||' <br>' );
--
      END LOOP;
      CLOSE las_file_info_crsr;
    ELSE
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
        o_temp2 := o_temp2||o_TRS||',';
        o_temp2 := o_temp2||' , , ,';
--
        htp.p( o_temp2||' <br>' );
--
      CLOSE crsr0;
--
    END IF;
--
  END add_georeport;
--
--
-- PROCEDURE    add_las3
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_las3(sKID IN VARCHAR2) IS
--
    o_kid           NUMBER(10);    -- Well Header KID
    l_count         NUMBER(6);     -- Total Number of LAS Files
    l_count2        NUMBER(6);     -- Total Number of LAS Files
    o_temp          VARCHAR2(255);
    o_temp2         VARCHAR2(255);
-- LAS File Information
    o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
    o_file_path     VARCHAR2(255); -- File Path to LAS File
    o_file_name     VARCHAR2(255); -- File Name of LAS File
    o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
    o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
-- Type of Log Curves Available
    o_ohm           iqstrat.doe_co2_las3.ohm_log%TYPE;     -- Resistivity Log Curves
    o_density       iqstrat.doe_co2_las3.density_log%TYPE; -- Density Log Curves
    o_neutron       iqstrat.doe_co2_las3.neutron_log%TYPE; -- Neutron Log Curves
    o_sonic         iqstrat.doe_co2_las3.sonic_log%TYPE;   -- Sonic Log Curves
    o_gamma         iqstrat.doe_co2_las3.gr_log%TYPE;      -- Gamma Ray Log Curve
    o_pe            iqstrat.doe_co2_las3.pe_log%TYPE;      -- Photoelectric Log Curves
    o_th            iqstrat.doe_co2_las3.th_log%TYPE;      -- Thorium Log Curve
    o_u             iqstrat.doe_co2_las3.u_log%TYPE;       -- Uranium Log Curves
    o_p             iqstrat.doe_co2_las3.k_log%TYPE;       -- Potassium Log Curves
--
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_well_name  VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
--
    CURSOR crsr0 (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),',',' '), '-99'),
             NVL(status, '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
-- LAS File Cursor to retrieve all the LAS Files for a specific well
--
    CURSOR las_file_info_crsr (sKID VARCHAR2) IS
      SELECT file_path,             -- File Path for URL Ref
             file_name,             -- Filename of LAS File
             depth_start,           -- Starting Depth of LAS File
             depth_stop,            -- Ending Depth of LAS File
             gr_log,
             ohm_log,
             neutron_log,
             density_log,
             pe_log,
             sonic_log,
             th_log,
             u_log,
             k_log
        FROM iqstrat.doe_co2_las3
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = sKID));
--
    CURSOR crsr3(sKID VARCHAR2)  IS
      SELECT file_path,             -- File Path for URL Ref
             file_name,             -- Filename of LAS File
             depth_start,           -- Starting Depth of LAS File
             depth_stop,            -- Ending Depth of LAS File
             gr_log,
             ohm_log,
             neutron_log,
             density_log,
             pe_log,
             sonic_log,
             th_log,
             u_log,
             k_log
        FROM iqstrat.doe_co2_las3
       WHERE well_header_kid = sKID;
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(well_header_kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM iqstrat.doe_co2_las3
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = (SELECT well_header_kid
                                                           FROM qualified.well_headers
                                                          WHERE kid = sKID));
--
    SELECT COUNT(well_header_kid)
      INTO l_count2                   -- Total Number of Digital LAS Files
      FROM iqstrat.doe_co2_las3
     WHERE well_header_kid = sKID;
--
--  Build Table
--
    IF ((l_count > 0) OR (l_count2 > 0)) THEN
--    
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
        o_temp2 := o_temp2||o_TRS||',';
--
      CLOSE crsr0;
--
      IF (l_count > 0) THEN
        OPEN las_file_info_crsr(sKID);
--
        LOOP
          FETCH las_file_info_crsr
           INTO o_file_path,
                o_file_name,
                o_depth_start,
                o_depth_end,
                o_gamma,   -- Gamma Ray Log Curve
                o_ohm,     -- Resistivity Log Curves
                o_neutron, -- Neutron Log Curves
                o_density, -- Density Log Curves
                o_pe,      -- Photoelectric Log Curves
                o_sonic,   -- Sonic Log Curves
                o_th,      -- Thorium Log Curve
                o_u,       -- Uranium Log Curves
                o_p;       -- Potassium Log Curves
          EXIT WHEN las_file_info_crsr%NOTFOUND;
        END LOOP;
        CLOSE las_file_info_crsr;
      ELSIF (l_count2 > 0) THEN
        OPEN crsr3(sKID);
--
        LOOP
          FETCH crsr3
           INTO o_file_path,
                o_file_name,
                o_depth_start,
                o_depth_end,
                o_gamma,   -- Gamma Ray Log Curve
                o_ohm,     -- Resistivity Log Curves
                o_neutron, -- Neutron Log Curves
                o_density, -- Density Log Curves
                o_pe,      -- Photoelectric Log Curves
                o_sonic,   -- Sonic Log Curves
                o_th,      -- Thorium Log Curve
                o_u,       -- Uranium Log Curves
                o_p;       -- Potassium Log Curves
          EXIT WHEN crsr3%NOTFOUND;
        END LOOP;
        CLOSE crsr3;
      END IF;
--
      o_temp := o_depth_start||',';
      o_temp := o_temp||o_depth_end||',';
--          
      IF (o_gamma = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_ohm = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_sonic = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_density = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_neutron = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_pe = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--         
      IF (o_th = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_u = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--          
      IF (o_p = 'YES') THEN
        o_temp := o_temp||'YES,';
      ELSE
        o_temp := o_temp||'NO,';
      END IF;
--   
      o_temp := o_temp||'http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||',';
--          
      htp.p( o_temp2||o_temp||' <br>' );
--
    ELSE
      OPEN crsr0(sKID);
        FETCH crsr0
         INTO o_well_kid,  -- Primary Key for table
              o_api,       -- Well API-Number or UWI 
              o_well_name, -- Well Name or Outcrop Name
              o_status,    -- well status or Outcrop Type  
              -- Location Columns
              o_township,  -- Township
              o_town_dir,  -- Township direction
              o_range,     -- Range
              o_range_dir, -- Range direction
              o_section,   -- Section
              -- Z Position - Depth, Elevation Columns
              o_depth,     -- depth of well or height of outcrop
              o_kb,        -- elevation kelly bushing (well)
              o_gl,        -- elevation ground level
              o_df;        -- elevation derrick floor (well)
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
        o_temp2 := o_well_kid||',';
--
        IF (o_api != '-99') THEN
          o_temp2 := o_temp2||o_api||',';
        ELSE
          o_temp2 := o_temp2||' ,';
        END IF;

        o_temp2 := o_temp2||o_well_name||',';
        o_temp2 := o_temp2||o_TRS||',';
        o_temp2 := o_temp2||' , , , , , , , , , , ,';
--
        htp.p( o_temp2||' <br>' );
--
      CLOSE crsr0;
--
    END IF;
--
  END add_las3;
--
--
END doe_co2_summary_ascii_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON doe_co2_summary_ascii_pkg TO apex_public_user;