-- * PLSQL:       doe_co2_summary_pkg.sql Version 1.1 02/11/2009
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2009 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE doe_co2_summary_pkg AS
  PROCEDURE getXML;
  PROCEDURE dtd_and_columns;
-----
  PROCEDURE build_web_page(sCounty IN VARCHAR2);
  PROCEDURE build_web_page(sKID IN VARCHAR2);
-----  
  PROCEDURE build_image_page(sKID IN VARCHAR2);
  PROCEDURE add_well(sKID IN VARCHAR2);
  PROCEDURE add_las(sKID IN VARCHAR2);
  FUNCTION  count_log(sLASKID IN VARCHAR2,
                     sPhrase IN VARCHAR2) RETURN NUMBER;
  PROCEDURE add_tops(sKID IN VARCHAR2);
  PROCEDURE add_georeport(sKID IN VARCHAR2);
  PROCEDURE add_core_csv(sKID IN VARCHAR2);
  PROCEDURE add_las3(sKID IN VARCHAR2);
  PROCEDURE build_title_icons(sTitle IN VARCHAR2);
  PROCEDURE build_finish(sCounty IN VARCHAR2);
-----
  PROCEDURE build_web_page_by_tops(sCounty IN VARCHAR2, sTops IN VARCHAR2);
END doe_co2_summary_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY doe_co2_summary_pkg AS
--
-- PROCEDURE    getXML
-- Description: This procedure will retrieve a unique KID from the
--              the KGS Database and send it by XML.
--
  PROCEDURE getXML IS
--
    o_kid   headers.kid%TYPE;  -- Primary Key for table
--    
  BEGIN
--
--  ADD DTD 
--
    dtd_and_columns;
--
--  GET UNIQUE KID
--
    SELECT global.maintain.getnextkid() 
      INTO o_kid
      FROM DUAL;
--
--  BUILD BODY OF XML
--
    htp.print('<db_key>');     
    htp.print('  <data key="'||o_kid||'"/>');
    htp.print('</db_key>');     
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
--
  END getXML;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns for the unqiue key
--
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE db_key [');
    htp.print('<!ELEMENT db_key (data*)>');                  
    htp.print('<!ELEMENT data  EMPTY>');                       
    htp.print('<!ATTLIST data  key   CDATA #IMPLIED>]>');  -- Primary KGS KEY
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
--
--
-----------
-----------
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_web_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    iqstrat.doe_co2_wells.well_header_kid%TYPE; -- headers table primary key
    o_api    qualified.well_headers.api_number%TYPE;  -- Primary Key for table
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
--      SELECT UNIQUE(kid)
      SELECT kid, api_number
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
--             iqstrat.doe_co2_wells itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty)
      ORDER BY api_number, kid;
--
  BEGIN
--
--    SELECT COUNT(UNIQUE(kid))
    SELECT COUNT(kid)
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
--           iqstrat.doe_co2_wells itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Type Log Summary Page');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    build_title_icons( 'Summary Page for '||INITCAP(sCounty)||' County' );
--
    htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
--
--    htp.tableRowOpen('CENTER');
    htp.print('<center><table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.p('<TH bgColor=#b0c4de colspan="5">&nbsp;</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="5">Wells with</TH>');
    htp.p('<TH bgColor=#b0c4de>&nbsp;</TH>');
    htp.tableRowClose;
--
    htp.p('<TH bgColor=#b0c4de>KID</TH>');
    htp.p('<TH bgColor=#b0c4de>API-Number</TH>');
    htp.p('<TH bgColor=#b0c4de>Well Name</TH>');
    htp.p('<TH bgColor=#b0c4de>TRS</TH>');
    htp.p('<TH bgColor=#b0c4de>TYPE LOG</TH>');
    htp.p('<TH bgColor=#b0c4de>LAS Files</TH>');
    htp.p('<TH bgColor=#b0c4de>Tops</TH>');
    htp.p('<TH bgColor=#b0c4de>Core CSV</TH>');
--    htp.p('<TH bgColor=#b0c4de>Core</TH>');
--    htp.p('<TH bgColor=#b0c4de>Images</TH>');
    htp.p('<TH bgColor=#b0c4de>Georeport</TH>');
    htp.p('<TH bgColor=#b0c4de>LAS 3.0</TH>');
    htp.p('<TH bgColor=#b0c4de>Status</TH>');      
    htp.tableRowClose;
    htp.print('</center>');
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;
        EXIT WHEN crsr%NOTFOUND;
--
        add_well(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    END IF;
--
    htp.tableClose;
--
    htp.print('<p><center><A href="http://www.kgs.ku.edu/PRS/Ozark/Summary/Legend.html" target="_blank">Click for Legend</A></center> ');
--    
    htp.p('<hr>');
--
    htp.p('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.p('  <tr><td><center><h3>Comma Separated Values (CSV) Links</h3></center></td></tr>');
    htp.p('</table>');
--
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the wells in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_las_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the KGS LAS Files in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_tops_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the tops in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_geo_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the Geologist Report ASCII Files in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_las3_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the LAS version 3.0 Files in this county</a>');
--
    build_finish(sCounty);
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--
  PROCEDURE build_web_page(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid_well   qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_county     global.states_counties.county_name%TYPE;  -- County Name
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   qualified.well_headers.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  qualified.well_headers.nad27_longitude%TYPE;    -- Longitude in decimal degrees
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
    o_Reference  VARCHAR(200);
    l_percent    NUMBER;
--
    l_cnt        NUMBER(6);  -- Number of LAS Files
    t_cnt        NUMBER(6);  -- Number of tops
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
--
    l_start      las.well_headers.depth_start%TYPE;  -- Starting Depth of LAS File
    l_stop       las.well_headers.depth_stop%TYPE;   -- Ending Depth of LAS File
    l_max        NUMBER(6);
    l_min        NUMBER(6);   
    las_value    NUMBER(6);
--
    CURSOR crsr0 (sKID VARCHAR2) IS
      SELECT kid,
             well_header_kid
        FROM qualified.well_headers qwh
       WHERE well_header_kid = (SELECT UNIQUE(well_header_kid)
                                  FROM qualified.well_headers
                                 WHERE kid = skid);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL((SELECT county_name 
                    FROM global.states_counties 
                   WHERE state_code = A.state_code
                     AND county_code = A.county_code), '-99'), 
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99)
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT depth_start,           
           depth_stop             
      FROM las.well_headers
     WHERE well_header_kid = sKID;
--       
  BEGIN
--
    o_kid        := '-99';
    o_api        := '-99';  -- Well API-Number or UWI 
    o_name       := '-99';  -- Well Name or Outcrop Name
    o_status     := '-99';  -- well status or Outcrop Type  
-- Location Columns
    o_township   := -99;    -- Township
    o_town_dir   := 'X';    -- Township direction
    o_range      := -99;    -- Range
    o_range_dir  := 'X';    -- Range direction
    o_section    := -9;     -- Section
-- XY Position of Columns
    o_latitude   := -99;    -- Latitude in decimal degrees
    o_longitude  := -99;    -- Longitude in decimal degrees
-- Z Position - Depth, Elevation Columns
    o_depth      := -99;    -- depth of well or height of outcrop
    o_kb         := -99;    -- elevation kelly bushing (well)
    o_gl         := -99;    -- elevation ground level
    o_df         := -99;    -- elevation derrick floor (well)
--
    o_Reference := '&nbsp;';
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Type Log Summary Page');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    SELECT NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99')
      INTO o_name
      FROM qualified.well_headers A
     WHERE kid = sKID;
--
    build_title_icons( 'Summary Page for '||INITCAP(o_name)||' Well' );
--
    OPEN crsr0(sKID);
    LOOP
      FETCH crsr0
       INTO o_kid,       -- Primary Key for table
            o_kid_well;
      EXIT WHEN crsr0%NOTFOUND;
--
      IF (o_kid != o_kid_well) THEN
        htp.p('<a href="http://chasm.kgs.ku.edu/apex/qualified.well_page.DisplayWell?f_kid='||o_kid||'"
               target="body">REWORK WELL: </a>Kansas Geological Survey Specific Well Web Page');
      ELSE
        htp.p('<a href="http://chasm.kgs.ku.edu/apex/qualified.well_page.DisplayWell?f_kid='||o_kid||'"
               target="body">ORIGINAL WELL: </a> Kansas Geological Survey Specific Well Web Page');
      END IF;
--
      htp.p('<P>');
--      
    END LOOP;
    CLOSE crsr0;
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Location Columns
            o_county,    -- County Name
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df;        -- elevation derrick floor (well)
      EXIT WHEN crsr%NOTFOUND;
--
    htp.tableOpen('BORDER=0 ALIGN="CENTER" CELLPADDING=1');
      htp.tableRowOpen('LEFT');
        htp.tableData('<b>KID: </b>'||o_kid);
        IF (o_api != '-99') THEN
          htp.tableData('<b>API-Number: </b>'||o_api);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
        htp.tableData('<b>Well Name:  </b>'||o_name);
      htp.tableRowClose;
--  
--
      IF (o_township != -99) THEN
        o_TRS := 'T'||o_township||o_town_dir;
      END IF;       
--          
      IF (o_range != -99) THEN
        o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
      END IF;       
--          
      IF (o_section != -9) THEN
        o_TRS := o_TRS||' '||'sec. '||o_section;
      END IF;       
--
      htp.tableRowOpen('LEFT');
        htp.tableData('<b>Location: </b>'||o_TRS);
        htp.tableData('&nbsp;');
        htp.tableData('&nbsp;');
      htp.tableRowClose;
--
      IF ((o_latitude != -99) OR (o_longitude != -99)) THEN
        htp.tableRowOpen('LEFT');
          htp.tableData('<b>Latitude: </b>'||o_latitude);
          htp.tableData('<b>Longitude: </b>'||o_longitude);
          htp.tableData('&nbsp;');
        htp.tableRowClose;
      END IF;  
--
      htp.tableRowOpen('LEFT');
        htp.tableData('<b>County: </b>'||o_county);
        htp.tableData('&nbsp;');
        htp.tableData('<b>Status: </b>'||o_status);
      htp.tableRowClose;
--
      htp.tableRowOpen('LEFT');
        htp.tableData('<b>Total Depth: </b>'||o_depth);
        IF (o_gl != -99) THEN
          htp.tableData('<b>Elevation GL: </b>'||o_gl);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
        IF (o_kb != -99) THEN
          htp.tableData('<b>Elevation KB: </b>'||o_kb);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
      htp.tableRowClose;
--      
      htp.tableClose;
--
      htp.p('<P>');
      add_las(sKID);
--
      htp.p('<P>');
      add_georeport(sKID);
--
      htp.p('<P>');
      add_core_csv(sKID);
--
      htp.p('<P>');
      add_tops(sKID);
-- 
    END LOOP;
    CLOSE crsr;
--
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.tableRowOpen('CENTER');
        htp.tableData(SQLERRM);
      htp.tableRowClose;
--
  END build_web_page;
--
--
-- PROCEDURE    build_image_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sKID = Headers Primary Key of the header information data 
-- * Output:    Summary Web Page for LAS 3.0 File Image Plot.
--
  PROCEDURE build_image_page(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
    l_count2     NUMBER;
    o_kid        user_headers.headers_kid%TYPE; -- headers table primary key
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
--    
    o_path       iqstrat.doe_co2_las3.file_path%TYPE;   -- File Path to LAS 3.0 file
    o_file       iqstrat.doe_co2_las3.file_name%TYPE;   -- File Name to LAS 3.0 file
    o_start      iqstrat.doe_co2_las3.depth_start%TYPE; -- start depth of LAS 3.0 file
    o_stop       iqstrat.doe_co2_las3.depth_stop%TYPE;  -- stop depth of LAS 3.0 file
    o_type       iqstrat.doe_co2_images.file_type%TYPE; -- Image File Type  
--    
    o_path_las   iqstrat.doe_co2_las3.file_path%TYPE;   -- File Path to LAS 3.0 file
    o_file_las   iqstrat.doe_co2_las3.file_name%TYPE;   -- File Name to LAS 3.0 file
    o_start_las  iqstrat.doe_co2_las3.depth_start%TYPE; -- start depth of LAS 3.0 file
    o_stop_las   iqstrat.doe_co2_las3.depth_stop%TYPE;  -- stop depth of LAS 3.0 file
--
    o_path_pdf   iqstrat.doe_co2_las3.file_path%TYPE;   -- File Path to PDF Image file
    o_file_pdf   iqstrat.doe_co2_las3.file_name%TYPE;   -- File Name to PDF Image file
    o_start_pdf  iqstrat.doe_co2_las3.depth_start%TYPE; -- start depth of PDF Image file
    o_stop_pdf   iqstrat.doe_co2_las3.depth_stop%TYPE;  -- stop depth of PDF Image file
--
    o_path_png   iqstrat.doe_co2_las3.file_path%TYPE;   -- File Path to PNG Image file
    o_file_png   iqstrat.doe_co2_las3.file_name%TYPE;   -- File Name to PNG Image file
    o_start_png  iqstrat.doe_co2_las3.depth_start%TYPE; -- start depth of PNG Image file
    o_stop_png   iqstrat.doe_co2_las3.depth_stop%TYPE;  -- stop depth of PNG Image file
--
    CURSOR crsr_well (sKID VARCHAR2) IS
      SELECT NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99')
        FROM qualified.well_headers 
       WHERE kid = sKID;
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT file_path,
             file_name,
             depth_start,
             depth_stop             
        FROM iqstrat.doe_co2_las3
       WHERE well_header_kid = sKID;
--
    CURSOR crsr2(sKID IN VARCHAR2) IS
      SELECT file_path,
             file_name,
             file_type,
             depth_start,
             depth_stop             
        FROM iqstrat.doe_co2_images
--       WHERE well_header_kid = sKID;
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = sKID));
--
  BEGIN
--
    SELECT COUNT(*)
      INTO l_count
      FROM iqstrat.doe_co2_las3
       WHERE well_header_kid = sKID;
--
    SELECT COUNT(*)
      INTO l_count2
      FROM iqstrat.doe_co2_images
--       WHERE well_header_kid = sKID;
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = sKID));
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/TYPE_LOG/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Type Log LAS 3.0 File Page');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    OPEN crsr_well(sKID);
      FETCH crsr_well
       INTO o_name;  -- Well Name or Outcrop Name
    CLOSE crsr_well;

    build_title_icons( o_name );
--
    htp.p('<P>');
    add_las3(sKID);
--
    IF (l_count2 > 0) THEN
      OPEN crsr2(sKID);
      LOOP
        FETCH crsr2
         INTO o_path,  -- File Path to LAS 3.0 file
              o_file,  -- File Name to LAS 3.0 file
              o_type,  -- Image File Type  
              o_start, -- start depth of LAS 3.0 file
              o_stop;  -- stop depth of LAS 3.0 file
        EXIT WHEN crsr2%NOTFOUND;
--
        IF (o_type = 'PDF') THEN
          htp.print('<p><center><a href="http://www.kgs.ku.edu/'||o_path||'/'||o_file||'">View Portable Document Format (PDF) of Image</a></center>');
        END IF;
--
      END LOOP;
      CLOSE crsr2;
--      
      OPEN crsr2(sKID);
      LOOP
        FETCH crsr2
         INTO o_path,  -- File Path to LAS 3.0 file
              o_file,  -- File Name to LAS 3.0 file
              o_type,  -- Image File Type  
              o_start, -- start depth of LAS 3.0 file
              o_stop;  -- stop depth of LAS 3.0 file
        EXIT WHEN crsr2%NOTFOUND;
--
        IF (o_type = 'PNG') THEN
          htp.print('<p><center><img src="http://www.kgs.ku.edu/'||o_path||'/'||o_file||'"></center>');
        END IF;
--
      END LOOP;
      CLOSE crsr2;
    END IF;
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_image_page;
--
--
-- PROCEDURE    add_well()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct well data table.
-- Input:       sKID = Headers Primary Key of the header information data 
--
  PROCEDURE add_well(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
    l_percent    NUMBER;
--
    tl_cnt       NUMBER(6);  -- Number of Type Log indicator
    l_cnt        NUMBER(6);  -- Number of LAS Files
    t_cnt        NUMBER(6);  -- Number of tops
    ts_cnt       NUMBER(6);  -- Number of tops sources
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
    e_cnt        NUMBER(6);  -- Number of ELOG Files
    e2_cnt       NUMBER(6);  -- Number of ELOG Files
--    s_cnt        NUMBER(6);  -- Number of Scan URLs 
    g_cnt        NUMBER(6);  -- Number of ASCII Georeport Files
    l3_cnt       NUMBER(6);  -- Number of LAS 3.0 Files
    l3_status    iqstrat.doe_co2_las3.file_status%TYPE; -- Status
--
    l_start      las.well_headers.depth_start%TYPE;  -- Starting Depth of LAS File
    l_stop       las.well_headers.depth_stop%TYPE;   -- Ending Depth of LAS File
    l_max        NUMBER(6);
    l_min        NUMBER(6);   
    las_value    NUMBER(6);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT depth_start,           
           depth_stop             
      FROM las.well_headers
     WHERE well_header_kid = sKID;
--       
  BEGIN
--
    o_kid       := '-99';
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Location Columns
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Location Columns
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df;        -- elevation derrick floor (well)
--            o_comments;  -- general comments
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
      tl_cnt := 0;
      SELECT COUNT(*)
        INTO tl_cnt
        FROM iqstrat.type_log_wells        
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid);
--
      e_cnt := 0;
      SELECT COUNT(*)
        INTO e_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
--       WHERE well_header_kid = o_kid
         AND logger_id = 6422
         AND (tool_id = 6423
          OR tool_id = 7924);
--
      e2_cnt := 0;
      SELECT COUNT(*)
        INTO e2_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
         AND logger_id = 83
         AND tool_id   = 1165;
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
--        FROM qualified.well_tops
        FROM iqstrat.doe_co2_tops
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid);
--
      ts_cnt := 0;
      IF (t_cnt> 0) THEN
        SELECT COUNT(Unique(data_source))
          INTO ts_cnt
          FROM qualified.well_tops
         WHERE well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = o_kid));
--         WHERE well_header_kid IN (SELECT kid
--                                     FROM qualified.well_headers
--                                    WHERE kid = o_kid);
      END IF;
--
      c_cnt := 0;
      SELECT COUNT(*)
        INTO c_cnt
       FROM iqstrat.doe_co2_core_csv
      WHERE well_header_kid = o_kid; 
--
--      c_cnt := 0;
--      SELECT COUNT(*)
--        INTO c_cnt
--        FROM core_library.core_data_and_descriptions
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE well_header_kid = (SELECT well_header_kid
--                                                             FROM qualified.well_headers
--                                                            WHERE kid = o_kid))
--         AND depth_top_core_ft IS NOT NULL;
--
      i_cnt := 0;
      SELECT COUNT(*)
        INTO i_cnt
        FROM qualified.images
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid)
         AND file_url IS NOT NULL;
--
      g_cnt := 0;
      SELECT COUNT(*)
        INTO g_cnt
       FROM iqstrat.doe_co2_georeport
      WHERE well_header_kid = o_kid; 
--         
      l3_cnt := 0;
      SELECT COUNT(*)
        INTO l3_cnt
        FROM iqstrat.doe_co2_las3
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--         
--    Validate LAS File Depth Range with Tops
--
      IF (l_cnt > 0) THEN
        las_value := 0;
--        
        OPEN las_file_info_crsr(o_kid);
        LOOP
          FETCH las_file_info_crsr
           INTO  l_start,
                 l_stop;
          EXIT WHEN las_file_info_crsr%NOTFOUND;
--
          IF (t_cnt > 0) AND (las_value = 0) THEN
            SELECT MAX(depth_top), MIN(depth_top)
              INTO l_max, l_min
--              FROM qualified.well_tops
              FROM iqstrat.doe_co2_tops
             WHERE well_header_kid = o_kid;
--      
            IF (l_min >= l_start) AND (l_max <= l_stop) THEN
                las_value := 2;
            ELSIF (l_min >= l_start) OR (l_max <= l_stop) THEN
                IF (las_value < 2) THEN
                  las_value := 1;
                END IF;
            ELSE
              IF (las_value < 1) THEN
                las_value := 0;
              END IF;
            END IF;
          END IF;
--
        END LOOP;
        CLOSE las_file_info_crsr;
      END IF;
--
      htp.tableRowOpen('LEFT');
        htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_web_page?sKID='||o_kid||'" target="body">'||o_kid||'</a></td>');
--        htp.tableData(o_kid);
        IF (o_api != '-99') THEN
          htp.tableData(o_api);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
        htp.tableData(o_name);
        htp.tableData(o_TRS);
        IF (tl_cnt > 0) THEN
          htp.p('<td class=excellent>YES</td>');
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        
        IF (l_cnt = 0) THEN
          htp.p('<td class=empty>'||l_cnt||'</td>');
        ELSIF (l_cnt > 0) THEN
          IF (las_value = 2) THEN
            htp.p('<td class=good>'||l_cnt||'</td>');
          ELSIF (las_value = 1) THEN
            htp.p('<td class=fair>'||l_cnt||'</td>');
          ELSE
            htp.p('<td class=poor>'||l_cnt||'</td>');
          END IF;
        ELSE
          htp.tableData(l_cnt);
        END IF;
--        
        IF (t_cnt = 0) THEN
          htp.p('<td class=empty>'||t_cnt||'</td>');
        ELSIF (t_cnt < 10) THEN
          htp.p('<td class=poor>'||t_cnt||'</td>');
        ELSIF (t_cnt < 20) THEN
          htp.p('<td class=fair>'||t_cnt||'</td>');
        ELSIF (t_cnt < 30) THEN
          htp.p('<td class=good>'||t_cnt||'</td>');
        ELSIF (t_cnt >= 30) THEN
          htp.p('<td class=excellent>'||t_cnt||'</td>');
        END IF;
--
--        l_percent := 0;
--        IF (t_cnt > 0) THEN
--          l_percent := (te_cnt * 100) / (3 * t_cnt);
--        END IF;
--
        IF (c_cnt > 0) THEN
          htp.p('<td class=good>YES</td>');
        ELSE 
          htp.tableData('&nbsp;');
        END IF;
--        
--        IF (c_cnt = 0) THEN
--          htp.tableData(c_cnt);
--        ELSIF (c_cnt > 0) THEN
--          htp.p('<td class=good>'||c_cnt||'</td>');
--        END IF;
--
--        IF (i_cnt = 0) THEN
--          htp.tableData(i_cnt);
--        ELSIF (i_cnt > 0) THEN
--          htp.p('<td class=good>'||i_cnt||'</td>');
--        END IF;
--
--        IF (l_percent > 95) THEN
--          htp.p('<td class=gold>'||te_cnt||'</td>');
--        ELSIF (l_percent > 60) THEN
--          htp.p('<td class=silver>'||te_cnt||'</td>');
--        ELSIF (l_percent > 15) THEN
--          htp.p('<td class=copper>'||te_cnt||'</td>');
--        ELSE 
--          htp.p('<td class=lead>'||te_cnt||'</td>');
--        END IF;
--        
--        IF (e_cnt > 0) THEN
--          htp.p('<td class=good>'||e_cnt||'</td>');
--        ELSE
--          htp.tableData(e_cnt);
--        END IF;
--        
--        IF (e_cnt > 0) THEN
--          htp.p('<td class=good>'||e_cnt||'</td>');
--        ELSE
--          htp.tableData(e_cnt);
--        END IF;
--        
        IF (e_cnt > 0) AND (g_cnt = 0) THEN
          htp.p('<td class=fair>TIFF (Davies)</td>');
        ELSIF (e2_cnt > 0) AND (g_cnt = 0) THEN
          htp.p('<td class=poor>TIFF (Other)</td>');
        ELSIF (g_cnt > 0) THEN
          htp.p('<td class=good>ASCII Text</td>');
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        
        l3_status := '-99';
        IF (l3_cnt > 0) THEN
          SELECT NVL(file_status, '-99') 
            INTO l3_status
            FROM iqstrat.doe_co2_las3
--           WHERE well_header_kid = o_kid; 
           WHERE well_header_kid IN (SELECT kid
                                       FROM qualified.well_headers
                                      WHERE well_header_kid = (SELECT well_header_kid
                                                                 FROM qualified.well_headers
                                                                WHERE kid = o_kid));
--
          IF (l3_status != '-99') THEN
            htp.p('<td class=good><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_image_page?sKID='||o_kid||'" target="body">VIEW</a></td>');
          ELSE
            htp.p('<td class=fair><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_image_page?sKID='||o_kid||'" target="body">VIEW</a></td>');
          END IF;
        ELSE 
          htp.tableData('&nbsp;');
        END IF;
--        
--        htp.tableData('NO');
-- 
        IF (l_cnt = 0) AND (t_cnt = 0) THEN
          htp.p('<td class=empty>Empty</td>');
        ELSIF (l3_status != '-99') AND (las_value = 2) THEN
          htp.p('<td class=complete>Complete</td>');
        ELSIF (l3_cnt > 0) AND (las_value = 2) THEN
          htp.p('<td class=excellent>Done</td>');
        ELSIF (l_cnt = 0) AND (t_cnt > 0) THEN
          htp.p('<td class=empty>Missing</td>');
        ELSIF (l_cnt > 0) AND (t_cnt = 0) THEN
          htp.p('<td class=empty>Missing</td>');
        ELSIF (l_cnt > 0) AND (t_cnt < 10) THEN
          htp.p('<td class=poor>Poor</td>');
        ELSIF (l_cnt > 0) AND (t_cnt < 30) THEN
          htp.p('<td class=fair>Fair</td>');
        ELSIF (l_cnt > 0) AND (t_cnt >= 30) THEN
          htp.p('<td class=good>Good</td>');
        END IF;
--        
      htp.tableRowClose;
--
--
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.tableRowOpen('CENTER');
        htp.tableData(SQLERRM);
      htp.tableRowClose;
--
  END add_well;
--
--
-- PROCEDURE    add_las
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_las(sKID IN VARCHAR2) IS
--
  o_kid           NUMBER(10);    -- Well Header KID
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- LAS File Information
  o_las_kid       NUMBER(10);    -- Primary Key for the LAS File
  o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
  o_file_path     VARCHAR2(255); -- File Path to LAS File
  o_path          VARCHAR2(255); -- File Path to LAS File
  o_file_name     VARCHAR2(255); -- File Name of LAS File
  o_version       VARCHAR2(20);  -- Version Number of LAS File
  o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
  o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
  o_proprietary   NUMBER(5);     -- Proprietary Indicator
  o_length        NUMBER(4);     -- Total las_path to trim
-- Type of Log Curves Available
  o_temp          VARCHAR2(10000); -- KEY word of LAS Curve
  o_ohm           NUMBER(3);     -- Resistivity Log Curves
  o_density       NUMBER(3);     -- Density Log Curves
  o_neutron       NUMBER(3);     -- Neutron Log Curves
  o_sonic         NUMBER(3);     -- Sonic Log Curves
  o_sp            NUMBER(3);     -- Spontaneous Potential Log Curve
  o_gamma         NUMBER(3);     -- Gamma Ray Log Curve
  o_caliper       NUMBER(3);     -- Caliper Log Curves
  o_pe            NUMBER(3);     -- Photoelectric Log Curves
  o_th            NUMBER(3);     -- Thorium Log Curve
  o_u             NUMBER(3);     -- Uranium Log Curves
  o_p             NUMBER(3);     -- Potassium Log Curves
  o_gr_cnt        NUMBER(3);     -- Gamma Ray Count Log Curve
  o_neut_cnt      NUMBER(3);     -- Neutron Count Log Curve
--
-- LAS File Cursor to retrieve all the LAS Files for a specific well
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT kid,                   -- Primary Key for the LAS File
           well_header_kid,       -- Primary Key for the Well Header
--           SUBSTR(las_path,16),   -- Strip Initial Unix File Path for URL Ref
           las_path,              -- Strip Initial Unix File Path for URL Ref
           las_filename,          -- Filename of LAS File
           las_version,           -- Version Number of LAS File
           depth_start,           -- Starting Depth of LAS File
           depth_stop,            -- Ending Depth of LAS File
           proprietary,            -- Is the File Protected?
           INSTR(las_path, 'WellLogs')
      FROM las.well_headers
--     WHERE well_header_kid IN (SELECT kid
--                                 FROM qualified.well_headers
--                                WHERE kid = sKID
--                                   OR well_header_kid = sKID);
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = (SELECT well_header_kid
                                                           FROM qualified.well_headers
                                                          WHERE kid = sKID));
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM las.well_headers
--     WHERE well_header_kid IN (SELECT kid
--                                 FROM qualified.well_headers
--                                WHERE kid = sKID
--                                   OR well_header_kid = sKID);
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = (SELECT well_header_kid
                                                           FROM qualified.well_headers
                                                          WHERE kid = sKID));
--
--  Build Table
--
    IF (l_count > 0) THEN
--    
      htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
      htp.p('<TH bgColor=#b0c4de colspan="16">Log ASCII Standard (LAS) File(s)</TH>');      
      htp.tableRowClose;
--      
      htp.p('<TH bgColor=#b0c4de colspan="2">Depth Range</TH>');
      htp.p('<TH bgColor=#b0c4de colspan="10">Log Curves Available</TH>');
      htp.p('<TH bgColor=#b0c4de colspan="2" >Log Count</TH>');
      htp.p('<TH bgColor=#b0c4de >Download</TH>');
      htp.p('<TH bgColor=#b0c4de >View this</TH>');      
      htp.tableRowClose;
--
      htp.p('<TH bgColor=#b0c4de>Start</TH>');
      htp.p('<TH bgColor=#b0c4de>Stop</TH>');
      htp.p('<TH bgColor=#b0c4de>SP</TH>');
      htp.p('<TH bgColor=#b0c4de>GR</TH>');
      htp.p('<TH bgColor=#b0c4de>OHM-M</TH>');
      htp.p('<TH bgColor=#b0c4de>DT</TH>');
      htp.p('<TH bgColor=#b0c4de>RHOB</TH>');
      htp.p('<TH bgColor=#b0c4de>NPHI</TH>');
      htp.p('<TH bgColor=#b0c4de>PE</TH>');
      htp.p('<TH bgColor=#b0c4de>TH</TH>');
      htp.p('<TH bgColor=#b0c4de>U</TH>');
      htp.p('<TH bgColor=#b0c4de>K</TH>');
      htp.p('<TH bgColor=#b0c4de>GR</TH>');
      htp.p('<TH bgColor=#b0c4de>NEUT</TH>');
      htp.p('<TH bgColor=#b0c4de >this log</TH>');
      htp.p('<TH bgColor=#b0c4de >log header</TH>');
      htp.tableRowClose;
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_las_kid,
              o_well_kid,
              o_file_path,
              o_file_name,
              o_version,
              o_depth_start,
              o_depth_end,
              o_proprietary,
              o_length;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
      SELECT SUBSTR(o_file_path, o_length)
        INTO o_path
        FROM DUAL;
--
        o_caliper := count_log(o_las_kid,'%CALIPER%');
        o_sp := count_log(o_las_kid,'%SPONTANEOUS%');
        o_gamma := count_log(o_las_kid,'%GAMMA%');
        o_ohm := count_log(o_las_kid,'%RESISTIVITY%');
        o_sonic := count_log(o_las_kid,'%SONIC%');
        o_density := count_log(o_las_kid,'%DENSITY%');
        o_neutron := count_log(o_las_kid,'%NEUTRON%');
        o_pe := count_log(o_las_kid,'%PHOTOELECTRIC%');
        o_th := count_log(o_las_kid,'%THORIUM%');
        o_u := count_log(o_las_kid,'%URANIUM%');
        o_p := count_log(o_las_kid,'%POTASSIUM%');
        o_gr_cnt   := 0;
        o_neut_cnt := count_log(o_las_kid,'%NEUTRON COUNTS%');
--
        htp.tableRowOpen('LEFT');
          htp.tableData(o_depth_start);
          htp.tableData(o_depth_end);
--          
          IF (o_sp > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_gamma > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_ohm > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_sonic > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_density > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_neutron > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_pe > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_th > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_u > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_p > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_gr_cnt > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--   
          IF (o_neut_cnt > 0) THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--   
--          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||'" target="body">LAS File</a></td>');
--          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_file_path||'/'||o_las_kid||'.zip" target="body">LAS File</a></td>');
          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_path||'/'||o_las_kid||'.zip" target="body">LAS File</a></td>');
          htp.p('<td><a href="http://chasm.kgs.ku.edu/apex/qualified.well_page.ViewLasHeader?f_kid='||o_las_kid||'" target="body">LAS Header</a></td>');
--
        htp.tableRowClose;
--
      END LOOP;
      htp.tableClose;
      CLOSE las_file_info_crsr;
    END IF;
--
  END add_las;
--
--
-- PROCEDURE    count_log
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    Count of specific curve type.
--
  FUNCTION count_log(sLASKID IN VARCHAR2,
                     sPhrase IN VARCHAR2) RETURN NUMBER IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Curve Types
--
  BEGIN
    l_count := 0;
--
    SELECT COUNT(*)
      INTO l_count               -- Key Word for the LAS Curve
      FROM las.tools,
           las.well_headers_curves
     WHERE las.tools.kid = las.well_headers_curves.tool_kid
       AND UPPER(standard_name) LIKE sPhrase
       AND las.well_headers_curves.las_kid = sLASKID;
--
     RETURN l_count;
--
  END count_log;
--
--
-- PROCEDURE    add_tops
-- Description: This procedure will build a Well Tops Table
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_tops(sKID IN VARCHAR2) IS
--
    l_cnt        NUMBER;
    l_count      NUMBER(6);
    l_count2     NUMBER(6);
--
    o_top        qualified.well_tops.depth_top%TYPE;          -- Depth Top
    o_base       qualified.well_tops.depth_base%TYPE;         -- Depth Base
    o_source     qualified.well_tops.data_source%TYPE;        -- Source Name of Tops
    o_name       nomenclature.strat_units.name%TYPE;          -- Standard Name for Tops
    o_rank       nomenclature.strat_units.rank%TYPE;          -- Rank of formation
    o_system     VARCHAR2(60);                 -- system name
    o_series     VARCHAR2(60);                 -- series name
    o_subsystem  VARCHAR2(60);                 -- subsystem name
    o_subseries  VARCHAR2(60);                 -- subseries name
    o_stage      VARCHAR2(60);                 -- stage name
    o_supergroup VARCHAR2(60);                 -- super group name
    o_group      VARCHAR2(60);                 -- group name
    o_subgroup   VARCHAR2(60);                 -- subgroup name
    o_formation  VARCHAR2(60);                 -- formation name
--

    CURSOR crsr (sKID VARCHAR2) IS
      SELECT iz.rank,
             iz.name,
             'PG',
--             tlt.source_kid,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
         AND tlt.well_header_kid = sKID
    ORDER BY iz.sequence;
--      SELECT nsu.rank,
--             nsu.name,
--             'PG',
----             NVL((SELECT initials FROM type_log_users WHERE kid= qwt.source_kid), 'unknown'),
----             (qwt.data_source, 'unknown'),
--             NVL(qwt.depth_top,  0.0),
--             NVL(qwt.depth_base, 0.0),
--             NVL(REPLACE((select name from nomenclature.strat_units where sequence = nsu.sequence_system), ' System', ''), '99999'),
--             NVL(REPLACE((select name from nomenclature.strat_units where sequence = nsu.sequence_series), ' Series', ''), '99999'),
--             NVL(REPLACE((select name from nomenclature.strat_units where sequence = nsu.sequence_stage), ' Stage', ''), '99999'),
--             NVL(REPLACE((select name from nomenclature.strat_units where sequence = nsu.sequence_group), ' Group', ''), '99999'),
--             NVL(REPLACE((select name from nomenclature.strat_units where sequence = nsu.sequence_formation), 'Formation', ''), '99999')
----        FROM qualified.well_tops qwt,
--        FROM iqstrat.doe_co2_tops qwt,
--             nomenclature.strat_units nsu
--       WHERE qwt.strat_unit_kid  = nsu.kid
----         AND qwt.well_header_kid = sKID
--         AND qwt.well_header_kid IN (SELECT kid
--                                       FROM qualified.well_headers
--                                      WHERE well_header_kid = (SELECT well_header_kid
--                                                                 FROM qualified.well_headers
--                                                                WHERE kid = sKID))
--      ORDER BY qwt.data_source, qwt.depth_top;
--
  BEGIN
--
    SELECT COUNT(iz.kid) 
      INTO l_count
      FROM iqstrat.zeller iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
       AND tlt.well_header_kid = sKID;
--    SELECT count(*) 
--      INTO l_count
--      FROM iqstrat.doe_co2_tops qwt,
--           nomenclature.strat_units nsu
--     WHERE qwt.strat_unit_kid  = nsu.kid
----       AND qwt.well_header_kid = sKID;
--         AND qwt.well_header_kid IN (SELECT kid
--                                       FROM qualified.well_headers
--                                      WHERE well_header_kid = (SELECT well_header_kid
--                                                                 FROM qualified.well_headers
--                                                                WHERE kid = sKID));
--
    IF (l_count > 0) THEN
--
      htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
      htp.p('<TH bgColor=#b0c4de colspan="8">Tops Data</TH>');
      htp.tableRowClose;
--
      htp.p('<TH bgColor=#b0c4de>Top</TH>');
      htp.p('<TH bgColor=#b0c4de>Base</TH>');
      htp.p('<TH bgColor=#b0c4de>Name</TH>');
      htp.p('<TH bgColor=#b0c4de>Rank</TH>');
      htp.p('<TH bgColor=#b0c4de>System</TH>');
      htp.p('<TH bgColor=#b0c4de>Subsystem</TH>');
      htp.p('<TH bgColor=#b0c4de>Series</TH>');
      htp.p('<TH bgColor=#b0c4de>Source</TH>');
      htp.tableRowClose;
--
    OPEN crsr(sKID);
--
    LOOP
      FETCH crsr
         INTO o_rank,       -- Rank, SYSTEM,SERIES, etc.
              o_name,       -- Name of Unit
--            
              o_source,    -- Source Name of Stratigraphic Units
--              o_src,        -- Source KID
              o_top,        -- Start Depth
              o_base,       -- End Depth
--    
              o_system,     -- System name
              o_series,     -- Series name
              o_subsystem,  -- Subsystem name
              o_subseries,  -- Subseries name                       
              o_stage,      -- Stage name
              o_supergroup, -- Supergroup name
              o_group,      -- Group name
              o_subgroup,   -- Subgroup name
              o_formation;  -- formation name
--       INTO o_rank,      -- Rank of Stratigraphic Unit
--            o_name,      -- Stratigraphic unit name
--            o_source,    -- Source Name of Stratigraphic Units
--            o_top,       -- Depth Top
--            o_base,      -- Depth Base
--            o_system,    -- Stratigraphic Unit System
--            o_series,    -- Stratigraphic Unit Series
--            o_stage,     -- Stratigraphic Unit Stage
--            o_group,     -- Stratigraphic Unit Group
--            o_formation; -- Stratigraphic Unit Formation
      EXIT WHEN crsr%NOTFOUND;
--
      IF (o_top > 0) THEN
        htp.tableRowOpen('LEFT');
          htp.tableData(o_top);
--
          IF (o_base > o_top) THEN
            htp.tableData(o_base);
          ELSE
            htp.tableData('&nbsp;');          
          END IF;
--          
          htp.tableData(o_name);
--          
          htp.tableData(o_rank);
--          
          IF (o_system != '99999') THEN
            htp.tableData(o_system);
          ELSE
            htp.tableData('&nbsp;');          
          END IF;
--          
          IF (o_subsystem != '99999') THEN
            htp.tableData(o_subsystem);
          ELSE
            htp.tableData('&nbsp;');          
          END IF;
--          
          IF (o_series != '99999') THEN
            htp.tableData(o_series);
          ELSE
            htp.tableData('&nbsp;');          
          END IF;
--          
          htp.tableData(o_source);
--          
        htp.tableRowClose;
      END IF;
--
    END LOOP;
    CLOSE crsr;
--
    htp.tableClose;
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
--
  END add_tops;
--
--
-- PROCEDURE    add_georeport
-- Description: This procedure will build a Georeport Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_georeport(sKID IN VARCHAR2) IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- LAS File Information
  o_las_kid       NUMBER(10);    -- Primary Key for the LAS File
  o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
  o_file_path     VARCHAR2(255); -- File Path to LAS File
  o_file_name     VARCHAR2(255); -- File Name of LAS File
  o_version       VARCHAR2(20);  -- Version Number of LAS File
  o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
  o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
  o_proprietary   NUMBER(5);     -- Proprietary Indicator
--
-- LAS File Cursor to retrieve the Cuttings Report File for a specific well
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT well_header_kid,       -- Primary Key for the Well Header
           geo_path,              -- Unix File Path for URL Ref
           geo_filename,          -- Filename of File
           depth_start,           -- Starting Depth of File
           depth_stop             -- Ending Depth of File
      FROM iqstrat.doe_co2_georeport
     WHERE well_header_kid = sKID;
--
  BEGIN
--
--  Count the total number of Georeport Files for a specific well.
--
    SELECT COUNT(well_header_kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM iqstrat.doe_co2_georeport
     WHERE well_header_kid = sKID;
--
--  Build Table
--
    IF (l_count > 0) THEN
--    
      htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
      htp.p('<TH bgColor=#b0c4de colspan="14">Geologist (cuttings and core descriptions) Report ASCII Text File</TH>');      
      htp.tableRowClose;
--      
      htp.p('<TH bgColor=#b0c4de colspan="2">Depth Range</TH>');
      htp.p('<TH bgColor=#b0c4de >View the</TH>');      
      htp.tableRowClose;
--
      htp.p('<TH bgColor=#b0c4de>Start</TH>');
      htp.p('<TH bgColor=#b0c4de>Stop</TH>');
      htp.p('<TH bgColor=#b0c4de >georeport</TH>');
      htp.tableRowClose;
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_well_kid,
              o_file_path,
              o_file_name,
              o_depth_start,
              o_depth_end;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
        htp.tableRowOpen('LEFT');
          htp.tableData(o_depth_start);
          htp.tableData(o_depth_end);
--          
          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||'" target="body">http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||'</a></td>');
--
        htp.tableRowClose;
--
      END LOOP;
      htp.tableClose;
      CLOSE las_file_info_crsr;
    END IF;
--
  END add_georeport;
--
--
-- PROCEDURE    add_core_csv
-- Description: This procedure will build a Core CSV File Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_core_csv(sKID IN VARCHAR2) IS
--
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- LAS File Information
  o_las_kid       NUMBER(10);    -- Primary Key for the LAS File
  o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
  o_file_path     VARCHAR2(255); -- File Path to LAS File
  o_file_name     VARCHAR2(255); -- File Name of LAS File
  o_version       VARCHAR2(20);  -- Version Number of LAS File
  o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
  o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
  o_proprietary   NUMBER(5);     -- Proprietary Indicator
--
-- LAS File Cursor to retrieve the Core CSV File for a specific well
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT well_header_kid,       -- Primary Key for the Well Header
           geo_path,              -- Unix File Path for URL Ref
           geo_filename,          -- Filename of File
           depth_start,           -- Starting Depth of File
           depth_stop             -- Ending Depth of File
      FROM iqstrat.doe_co2_core_csv
     WHERE well_header_kid = sKID;
--
  BEGIN
--
--  Count the total number of Core CSV Files for a specific well.
--
    SELECT COUNT(well_header_kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM iqstrat.doe_co2_core_csv
     WHERE well_header_kid = sKID;
--
--  Build Table
--
    IF (l_count > 0) THEN
--    
      htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
      htp.p('<TH bgColor=#b0c4de colspan="14">Measured Core Data ASCII CSV Text File</TH>');      
      htp.tableRowClose;
--      
      htp.p('<TH bgColor=#b0c4de colspan="2">Depth Range</TH>');
      htp.p('<TH bgColor=#b0c4de >View the</TH>');      
      htp.tableRowClose;
--
      htp.p('<TH bgColor=#b0c4de>Start</TH>');
      htp.p('<TH bgColor=#b0c4de>Stop</TH>');
      htp.p('<TH bgColor=#b0c4de >Core CSV</TH>');
      htp.tableRowClose;
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_well_kid,
              o_file_path,
              o_file_name,
              o_depth_start,
              o_depth_end;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
        htp.tableRowOpen('LEFT');
          htp.tableData(o_depth_start);
          htp.tableData(o_depth_end);
--          
          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||'" target="body">http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||'</a></td>');
--
        htp.tableRowClose;
--
      END LOOP;
      htp.tableClose;
      CLOSE las_file_info_crsr;
    END IF;
--
  END add_core_csv;
--
--
-- PROCEDURE    add_las3
-- Description: This procedure will build a LAS Table List
-- * Input:     sKID = Well Header KID
-- * Output:    HTML Table containing user information.
--
  PROCEDURE add_las3(sKID IN VARCHAR2) IS
--
  o_kid           NUMBER(10);    -- Well Header KID
  l_count         NUMBER(6);     -- Total Number of LAS Files
-- LAS File Information
  o_well_kid      NUMBER(10);    -- Primary Key for the Well Header
  o_file_path     VARCHAR2(255); -- File Path to LAS File
  o_file_name     VARCHAR2(255); -- File Name of LAS File
  o_depth_start   NUMBER(10,4);  -- Starting Depth of LAS File
  o_depth_end     NUMBER(10,4);  -- Ending Depth of LAS File
-- Type of Log Curves Available
  o_ohm           iqstrat.doe_co2_las3.ohm_log%TYPE;     -- Resistivity Log Curves
  o_density       iqstrat.doe_co2_las3.density_log%TYPE; -- Density Log Curves
  o_neutron       iqstrat.doe_co2_las3.neutron_log%TYPE; -- Neutron Log Curves
  o_sonic         iqstrat.doe_co2_las3.sonic_log%TYPE;   -- Sonic Log Curves
  o_gamma         iqstrat.doe_co2_las3.gr_log%TYPE;      -- Gamma Ray Log Curve
  o_pe            iqstrat.doe_co2_las3.pe_log%TYPE;      -- Photoelectric Log Curves
  o_th            iqstrat.doe_co2_las3.th_log%TYPE;      -- Thorium Log Curve
  o_u             iqstrat.doe_co2_las3.u_log%TYPE;       -- Uranium Log Curves
  o_p             iqstrat.doe_co2_las3.k_log%TYPE;       -- Potassium Log Curves
--
-- LAS File Cursor to retrieve all the LAS Files for a specific well
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT file_path,             -- File Path for URL Ref
           file_name,             -- Filename of LAS File
           depth_start,           -- Starting Depth of LAS File
           depth_stop,            -- Ending Depth of LAS File
           gr_log,
           ohm_log,
           neutron_log,
           density_log,
           pe_log,
           sonic_log,
           th_log,
           u_log,
           k_log
      FROM iqstrat.doe_co2_las3
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = (SELECT well_header_kid
                                                           FROM qualified.well_headers
                                                          WHERE kid = sKID));
--
  BEGIN
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(well_header_kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM iqstrat.doe_co2_las3
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = (SELECT well_header_kid
                                                           FROM qualified.well_headers
                                                          WHERE kid = sKID));
--
--  Build Table
--
    IF (l_count > 0) THEN
--    
      htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
      htp.p('<TH bgColor=#b0c4de colspan="13">Log ASCII Standard (LAS) File(s)</TH>');      
      htp.tableRowClose;
--      
      htp.p('<TH bgColor=#b0c4de colspan="2">Depth Range</TH>');
      htp.p('<TH bgColor=#b0c4de colspan="9">Log Curves Available</TH>');
--      htp.p('<TH bgColor=#b0c4de >Download</TH>');
      htp.p('<TH bgColor=#b0c4de >View this</TH>');      
      htp.tableRowClose;
--
      htp.p('<TH bgColor=#b0c4de>Start</TH>');
      htp.p('<TH bgColor=#b0c4de>Stop</TH>');
      htp.p('<TH bgColor=#b0c4de>GR</TH>');
      htp.p('<TH bgColor=#b0c4de>OHM-M</TH>');
      htp.p('<TH bgColor=#b0c4de>DT</TH>');
      htp.p('<TH bgColor=#b0c4de>RHOB</TH>');
      htp.p('<TH bgColor=#b0c4de>NPHI</TH>');
      htp.p('<TH bgColor=#b0c4de>PE</TH>');
      htp.p('<TH bgColor=#b0c4de>TH</TH>');
      htp.p('<TH bgColor=#b0c4de>U</TH>');
      htp.p('<TH bgColor=#b0c4de>K</TH>');
      htp.p('<TH bgColor=#b0c4de >log</TH>');
--      htp.p('<TH bgColor=#b0c4de >log header</TH>');
      htp.tableRowClose;
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_file_path,
              o_file_name,
              o_depth_start,
              o_depth_end,
              o_gamma,   -- Gamma Ray Log Curve
              o_ohm,     -- Resistivity Log Curves
              o_neutron, -- Neutron Log Curves
              o_density, -- Density Log Curves
              o_pe,      -- Photoelectric Log Curves
              o_sonic,   -- Sonic Log Curves
              o_th,      -- Thorium Log Curve
              o_u,       -- Uranium Log Curves
              o_p;       -- Potassium Log Curves
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
        htp.tableRowOpen('LEFT');
          htp.tableData(o_depth_start);
          htp.tableData(o_depth_end);
--          
          IF (o_gamma = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_ohm = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_sonic = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_density = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_neutron = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_pe = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_th = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_u = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--          
          IF (o_p = 'YES') THEN
            htp.p('<td class=good>YES</td>');
          ELSE
            htp.tableData('NO');
          END IF;
--   
          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_file_path||'/'||o_file_name||'" target="body">LAS File</a></td>');
--          htp.p('<td><a href="http://www.kgs.ku.edu/'||o_file_path||'/'||o_las_kid||'.zip" target="body">LAS File</a></td>');
--          htp.p('<td><a href="http://chasm.kgs.ku.edu/apex/qualified.well_page.ViewLasHeader?f_kid='||o_las_kid||'" target="body">LAS Header</a></td>');
--
        htp.tableRowClose;
--
      END LOOP;
      htp.tableClose;
      CLOSE las_file_info_crsr;
    END IF;
--
  END add_las3;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width=108>');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||sTitle||'</h1></center></td>');
    htp.print('  </tr>');
    htp.print('</table>');
--
    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_title_icons;
--
--
-- PROCEDURE    build_finish
-- Description: This procedure will close out the Web Page
--
  PROCEDURE build_finish(sCounty IN VARCHAR2) IS
--
  BEGIN
--
    htp.line;
--
-- End Section for the Web Page
--
    htp.print('This web page generated by ORACLE PLSQL Stored '||
              'Procedure http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_web_page?sCounty='||sCounty);
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_finish;
--
--
-- PROCEDURE    build_web_page_by_tops()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_web_page_by_tops(sCounty IN VARCHAR2, sTops IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    iqstrat.doe_co2_wells.well_header_kid%TYPE; -- headers table primary key
    o_api    qualified.well_headers.api_number%TYPE;  -- Primary Key for table
--
    CURSOR crsr(sCounty IN VARCHAR2, sTops IN VARCHAR2) IS
     SELECT kid, qwh.api_number
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw,
             iqstrat.doe_co2_tops dct
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.kid = dct.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty)
         AND dct.zeller_kid  = (SELECT kid
                                  FROM iqstrat.zeller
                                 WHERE UPPER(name) = UPPER(sTops))
--         AND UPPER(dct.name) = sTops
      ORDER BY qwh.api_number, kid;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw,
           iqstrat.doe_co2_tops dct
     WHERE qwh.kid = itlw.well_header_kid
       AND qwh.kid = dct.well_header_kid
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty)
       AND dct.zeller_kid  = (SELECT kid
                                FROM iqstrat.zeller
                               WHERE UPPER(name) = UPPER(sTops));
--        AND UPPER(dct.name) = sTops;
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Type Log Summary Page');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    build_title_icons( 'Summary Page for '||INITCAP(sCounty)||' County' );
--
    htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
--
--    htp.tableRowOpen('CENTER');
    htp.print('<center><table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.p('<TH bgColor=#b0c4de colspan="5">&nbsp;</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="6">Wells with</TH>');
    htp.p('<TH bgColor=#b0c4de>&nbsp;</TH>');
    htp.tableRowClose;
--
    htp.p('<TH bgColor=#b0c4de>KID</TH>');
    htp.p('<TH bgColor=#b0c4de>API-Number</TH>');
    htp.p('<TH bgColor=#b0c4de>Well Name</TH>');
    htp.p('<TH bgColor=#b0c4de>TRS</TH>');
    htp.p('<TH bgColor=#b0c4de>TYPE LOG</TH>');
    htp.p('<TH bgColor=#b0c4de>LAS Files</TH>');
    htp.p('<TH bgColor=#b0c4de>Tops</TH>');
    htp.p('<TH bgColor=#b0c4de>Core</TH>');
    htp.p('<TH bgColor=#b0c4de>Images</TH>');
    htp.p('<TH bgColor=#b0c4de>Georeport</TH>');
    htp.p('<TH bgColor=#b0c4de>LAS 3.0</TH>');
    htp.p('<TH bgColor=#b0c4de>Status</TH>');      
    htp.tableRowClose;
    htp.print('</center>');
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty, sTops);
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;
        EXIT WHEN crsr%NOTFOUND;
--
        add_well(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    END IF;
--
    htp.tableClose;
--
    htp.print('<p><center><A href="http://www.kgs.ku.edu/PRS/Ozark/Summary/Legend.html" target="_blank">Click for Legend</A></center> ');
--    
    htp.p('<hr>');
--
    htp.p('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.p('  <tr><td><center><h3>Comma Separated Values (CSV) Links</h3></center></td></tr>');
    htp.p('</table>');
--
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the wells in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_las_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the KGS LAS Files in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_tops_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the tops in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_geo_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the Geologist Report ASCII Files in this county</a>');
    htp.p('<p><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_ascii_pkg.build_csv_las3_page?sCounty='||sCounty||'" target="_blank">'||
          ' Create a Comma Separated Values (CSV) for the LAS version 3.0 Files in this county</a>');
--
    build_finish(sCounty);
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page_by_tops;
--
--
END doe_co2_summary_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON doe_co2_summary_pkg TO apex_public_user;