-- * PLSQL:       iqstrat_doe_co2_tops_pkg.sql Version 1.1 09/13/2012
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the CO2 Tops
--                data for a well with a specific API-Number.
-- * Copyright (c) 2012 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE iqstrat_doe_co2_tops_pkg AS
  PROCEDURE getXML(src IN VARCHAR2, sAPI IN VARCHAR2);
  PROCEDURE getXML(src IN VARCHAR2, sKID IN VARCHAR2);
  PROCEDURE getXML(sKID IN VARCHAR2);
  PROCEDURE dtd;
  PROCEDURE save_data( sKID    IN VARCHAR2,
                       src     IN VARCHAR2, 
                       sZeller IN VARCHAR2, 
                       sName   IN VARCHAR2, 
                       dTop    IN NUMBER,
                       dBase   IN NUMBER );
  PROCEDURE delete_data( sKID    IN VARCHAR2,
                         src     IN VARCHAR2, 
                         sZeller IN VARCHAR2 );
END iqstrat_doe_co2_tops_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY iqstrat_doe_co2_tops_pkg AS
--
-- PROCEDURE    getXML
-- Description: This procedure will build a ZELLER Stratigrpahic Unit XML
-- * Input:     src  = the type log tops source
-- * Input:     sAPI = API-Number of Well 
-- * Output:    xml stream containing user information.
--
  PROCEDURE getXML(src IN VARCHAR2, sAPI IN VARCHAR2) IS
--
    l_count  NUMBER(6);
    l_count2 NUMBER(6);
--
    o_kid        iqstrat.zeller.KID%TYPE;      -- Unique KEY For record
    o_seq        iqstrat.zeller.sequence%TYPE; -- Order 
    o_rank       iqstrat.zeller.rank%TYPE;     -- Rank, SYSTEM,SERIES, etc.
    o_name       iqstrat.zeller.name%TYPE;     -- Name of Unit
--    
    o_top        iqstrat.doe_co2_tops.depth_top%TYPE;  -- Start Depth
    o_base       iqstrat.doe_co2_tops.depth_base%TYPE; -- End Depth
--    
    o_system     iqstrat.zeller.name%TYPE;     -- System name
    o_series     iqstrat.zeller.name%TYPE;     -- Series name
    o_subsystem  iqstrat.zeller.name%TYPE;     -- Subsystem name
    o_subseries  iqstrat.zeller.name%TYPE;     -- Subseries name                       
    o_stage      iqstrat.zeller.name%TYPE;     -- Stage name
    o_supergroup iqstrat.zeller.name%TYPE;     -- Supergroup name
    o_group      iqstrat.zeller.name%TYPE;     -- Group name
    o_subgroup   iqstrat.zeller.name%TYPE;     -- Subgroup name
    o_formation  iqstrat.zeller.name%TYPE;     -- formation name
--
    CURSOR crsr(src IN VARCHAR2, sAPI IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
         AND tlt.source_kid = src
         AND tlt.api_number = sAPI
    ORDER BY iz.sequence;
--
    CURSOR crsr2(src IN VARCHAR2, sAPI IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller2 iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
         AND tlt.source_kid = src
         AND tlt.api_number = sAPI
    ORDER BY iz.sequence;
--
  BEGIN
--
--  Add DTD to XML
--
    dtd;
--
    SELECT COUNT(iz.kid) 
      INTO l_count
      FROM iqstrat.zeller iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
       AND tlt.source_kid = src
       AND tlt.api_number = sAPI;
--
    SELECT COUNT(iz.kid) 
      INTO l_count2
      FROM iqstrat.zeller2 iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
       AND tlt.source_kid = src
       AND tlt.api_number = sAPI;
--
    l_count := l_count+l_count2;
    htp.print('<strat records="'||l_count||'" ref="KGS The Stratigraphic Succession in Kansas, edited by D. E. Zeller, Dec. 1968, updated 2012">');
--
    OPEN crsr(src, sAPI);
    LOOP
      FETCH crsr
       INTO o_kid,        -- Unique KEY For record
            o_seq,        -- Order 
            o_rank,       -- Rank, SYSTEM,SERIES, etc.
            o_name,       -- Name of Unit
            o_top,        -- Start Depth
            o_base,       -- End Depth
--    
            o_system,     -- System name
            o_series,     -- Series name
            o_subsystem,  -- Subsystem name
            o_subseries,  -- Subseries name                       
            o_stage,      -- Stage name
            o_supergroup, -- Supergroup name
            o_group,      -- Group name
            o_subgroup,   -- Subgroup name
            o_formation;  -- formation name
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <age key="'||o_kid||'" '||
                       'id="'||o_seq||'" '||
                       'rank="'||o_rank||'" '||
                       'name="'||o_name||'" '||
                       'top="'||o_top||'" ');
--
      IF (o_base > o_top) THEN
        htp.print('base="'||o_base||'" ');
      END IF;
--
      IF (o_system != '99999') THEN
        htp.print('system="'||o_system||'" ');
      END IF;
--      
      IF (o_subsystem != '99999') THEN
        htp.print('subsystem="'||o_subsystem||'" ');
      END IF;
--      
      IF (o_series != '99999') THEN
        htp.print('series="'||o_series||'" ');
      END IF;
--      
      IF (o_stage != '99999') THEN
        htp.print('stage="'||o_stage||'" ');
      END IF;
--      
      IF (o_group != '99999') THEN
        htp.print('group="'||o_group||'" ');
      END IF;
--      
      IF (o_subgroup != '99999') THEN
        htp.print('subgroup="'||o_subgroup||'" ');
      END IF;
--      
      IF (o_formation != '99999') THEN
        htp.print('form="'||o_formation||'" ');
      END IF;
--      
      htp.print('/>');
--
    END LOOP;
    CLOSE crsr;
--
    OPEN crsr2(src, sAPI);
    LOOP
      FETCH crsr2
       INTO o_kid,        -- Unique KEY For record
            o_seq,        -- Order 
            o_rank,       -- Rank, SYSTEM,SERIES, etc.
            o_name,       -- Name of Unit
            o_top,        -- Start Depth
            o_base,       -- End Depth
--    
            o_system,     -- System name
            o_series,     -- Series name
            o_subsystem,  -- Subsystem name
            o_subseries,  -- Subseries name                       
            o_stage,      -- Stage name
            o_supergroup, -- Supergroup name
            o_group,      -- Group name
            o_subgroup,   -- Subgroup name
            o_formation;  -- formation name
      EXIT WHEN crsr2%NOTFOUND;
--
      htp.print('  <age key="'||o_kid||'" '||
                       'id="'||o_seq||'" '||
                       'rank="'||o_rank||'" '||
                       'name="'||o_name||'" '||
                       'top="'||o_top||'" ');
--
      IF (o_base > o_top) THEN
        htp.print('base="'||o_base||'" ');
      END IF;
--
      IF (o_system != '99999') THEN
        htp.print('system="'||o_system||'" ');
      END IF;
--      
      IF (o_series != '99999') THEN
        htp.print('series="'||o_series||'" ');
      END IF;
--      
      IF (o_subsystem != '99999') THEN
        htp.print('subsystem="'||o_subsystem||'" ');
      END IF;
--      
      IF (o_subseries != '99999') THEN
        htp.print('subseries="'||o_subseries||'" ');
      END IF;
--      
      IF (o_stage != '99999') THEN
        htp.print('stage="'||o_stage||'" ');
      END IF;
--      
      IF (o_group != '99999') THEN
        htp.print('group="'||o_group||'" ');
      END IF;
--      
      IF (o_subgroup != '99999') THEN
        htp.print('subgroup="'||o_subgroup||'" ');
      END IF;
--      
      IF (o_formation != '99999') THEN
        htp.print('form="'||o_formation||'" ');
      END IF;
--      
      htp.print('/>');
--
    END LOOP;
    CLOSE crsr2;
--
    htp.print('</strat>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
--
  END getXML;
--
--
-- PROCEDURE    getXML
-- Description: This procedure will build a ZELLER Stratigrpahic Unit XML
-- * Input:     src  = the type log Zeller KID
-- * Input:     sKID = Well Header KID
-- * Output:    xml stream containing user information.
--
  PROCEDURE getXML(src IN VARCHAR2, sKID IN VARCHAR2) IS
--
    l_count  NUMBER(6);
    l_count2 NUMBER(6);
--
    o_kid        iqstrat.zeller.KID%TYPE;      -- Unique KEY For record
    o_seq        iqstrat.zeller.sequence%TYPE; -- Order 
    o_rank       iqstrat.zeller.rank%TYPE;     -- Rank, SYSTEM,SERIES, etc.
    o_name       iqstrat.zeller.name%TYPE;     -- Name of Unit
--    
    o_src        iqstrat.doe_co2_tops.source_kid%TYPE; -- Source KID
    o_top        iqstrat.doe_co2_tops.depth_top%TYPE;  -- Start Depth
    o_base       iqstrat.doe_co2_tops.depth_base%TYPE; -- End Depth
--    
    o_system     iqstrat.zeller.name%TYPE;     -- System name
    o_series     iqstrat.zeller.name%TYPE;     -- Series name
    o_subsystem  iqstrat.zeller.name%TYPE;     -- Subsystem name
    o_subseries  iqstrat.zeller.name%TYPE;     -- Subseries name                       
    o_stage      iqstrat.zeller.name%TYPE;     -- Stage name
    o_supergroup iqstrat.zeller.name%TYPE;     -- Supergroup name
    o_group      iqstrat.zeller.name%TYPE;     -- Group name
    o_subgroup   iqstrat.zeller.name%TYPE;     -- Subgroup name
    o_formation  iqstrat.zeller.name%TYPE;     -- formation name
--
    CURSOR crsr(src IN VARCHAR2, sKID IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.source_kid,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
--         AND tlt.source_kid = src
         AND tlt.zeller_kid = src
         AND tlt.well_header_kid = sKID
    ORDER BY iz.sequence;
--
    CURSOR crsr2(src IN VARCHAR2, sKID IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.source_kid,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller2 iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
--         AND tlt.source_kid = src
         AND tlt.zeller_kid = src
         AND tlt.well_header_kid = sKID
    ORDER BY iz.sequence;
--
  BEGIN
--
--  Add DTD to XML
--
    dtd;
--
    SELECT COUNT(iz.kid) 
      INTO l_count
      FROM iqstrat.zeller iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
--       AND tlt.source_kid = src
       AND tlt.zeller_kid = src
       AND tlt.well_header_kid = sKID;
--
    SELECT COUNT(iz.kid) 
      INTO l_count2
      FROM iqstrat.zeller2 iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
--       AND tlt.source_kid = src
       AND tlt.zeller_kid = src
       AND tlt.well_header_kid = sKID;
--
    l_count := l_count+l_count2;
    htp.print('<strat records="'||l_count||'" ref="KGS The Stratigraphic Succession in Kansas, edited by D. E. Zeller, Dec. 1968, updated 2012">');
--
    OPEN crsr(src, sKID);
    LOOP
      FETCH crsr
       INTO o_kid,        -- Unique KEY For record
            o_seq,        -- Order 
            o_rank,       -- Rank, SYSTEM,SERIES, etc.
            o_name,       -- Name of Unit
--            
            o_src,        -- Source KID
            o_top,        -- Start Depth
            o_base,       -- End Depth
--    
            o_system,     -- System name
            o_series,     -- Series name
            o_subsystem,  -- Subsystem name
            o_subseries,  -- Subseries name                       
            o_stage,      -- Stage name
            o_supergroup, -- Supergroup name
            o_group,      -- Group name
            o_subgroup,   -- Subgroup name
            o_formation;  -- formation name
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <age key="'||o_kid||'" '||
                       'id="'||o_seq||'" '||
                       'src="'||o_src||'" '||
                       'rank="'||o_rank||'" '||
                       'name="'||o_name||'" '||
                       'top="'||o_top||'" ');
--
      IF (o_base > o_top) THEN
        htp.print('base="'||o_base||'" ');
      END IF;
--
      IF (o_system != '99999') THEN
        htp.print('system="'||o_system||'" ');
      END IF;
--      
      IF (o_subsystem != '99999') THEN
        htp.print('subsystem="'||o_subsystem||'" ');
      END IF;
--      
      IF (o_series != '99999') THEN
        htp.print('series="'||o_series||'" ');
      END IF;
--      
      IF (o_stage != '99999') THEN
        htp.print('stage="'||o_stage||'" ');
      END IF;
--      
      IF (o_group != '99999') THEN
        htp.print('group="'||o_group||'" ');
      END IF;
--      
      IF (o_subgroup != '99999') THEN
        htp.print('subgroup="'||o_subgroup||'" ');
      END IF;
--      
      IF (o_formation != '99999') THEN
        htp.print('form="'||o_formation||'" ');
      END IF;
--      
      htp.print('/>');
--
    END LOOP;
    CLOSE crsr;
--
    OPEN crsr2(src, sKID);
    LOOP
      FETCH crsr2
       INTO o_kid,        -- Unique KEY For record
            o_seq,        -- Order 
            o_rank,       -- Rank, SYSTEM,SERIES, etc.
            o_name,       -- Name of Unit
--
            o_src,        -- Source KID
            o_top,        -- Start Depth
            o_base,       -- End Depth
--    
            o_system,     -- System name
            o_series,     -- Series name
            o_subsystem,  -- Subsystem name
            o_subseries,  -- Subseries name                       
            o_stage,      -- Stage name
            o_supergroup, -- Supergroup name
            o_group,      -- Group name
            o_subgroup,   -- Subgroup name
            o_formation;  -- formation name
      EXIT WHEN crsr2%NOTFOUND;
--
      htp.print('  <age key="'||o_kid||'" '||
                       'id="'||o_seq||'" '||
                       'src="'||o_src||'" '||
                       'rank="'||o_rank||'" '||
                       'name="'||o_name||'" '||
                       'top="'||o_top||'" ');
--
      IF (o_base > o_top) THEN
        htp.print('base="'||o_base||'" ');
      END IF;
--
      IF (o_system != '99999') THEN
        htp.print('system="'||o_system||'" ');
      END IF;
--      
      IF (o_series != '99999') THEN
        htp.print('series="'||o_series||'" ');
      END IF;
--      
      IF (o_subsystem != '99999') THEN
        htp.print('subsystem="'||o_subsystem||'" ');
      END IF;
--      
      IF (o_subseries != '99999') THEN
        htp.print('subseries="'||o_subseries||'" ');
      END IF;
--      
      IF (o_stage != '99999') THEN
        htp.print('stage="'||o_stage||'" ');
      END IF;
--      
      IF (o_group != '99999') THEN
        htp.print('group="'||o_group||'" ');
      END IF;
--      
      IF (o_subgroup != '99999') THEN
        htp.print('subgroup="'||o_subgroup||'" ');
      END IF;
--      
      IF (o_formation != '99999') THEN
        htp.print('form="'||o_formation||'" ');
      END IF;
--      
      htp.print('/>');
--
    END LOOP;
    CLOSE crsr2;
--
    htp.print('</strat>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
--
  END getXML;
--
--
-- PROCEDURE    getXML
-- Description: This procedure will build a ZELLER Stratigrpahic Unit XML
-- * Input:     sKID = Well Header KID
-- * Output:    xml stream containing user information.
--
  PROCEDURE getXML(sKID IN VARCHAR2) IS
--
    l_cnt        NUMBER;
    l_count      NUMBER(6);
    l_count2     NUMBER(6);
--
    o_kid        iqstrat.zeller.KID%TYPE;      -- Unique KEY For record
    o_seq        iqstrat.zeller.sequence%TYPE; -- Order 
    o_rank       iqstrat.zeller.rank%TYPE;     -- Rank, SYSTEM,SERIES, etc.
    o_name       iqstrat.zeller.name%TYPE;     -- Name of Unit
--    
    o_src        iqstrat.doe_co2_tops.source_kid%TYPE; -- Source KID
    o_top        iqstrat.doe_co2_tops.depth_top%TYPE;  -- Start Depth
    o_base       iqstrat.doe_co2_tops.depth_base%TYPE; -- End Depth
--    
    o_level      VARCHAR2(20);
--
    o_system     iqstrat.zeller.name%TYPE;     -- System name
    o_series     iqstrat.zeller.name%TYPE;     -- Series name
    o_subsystem  iqstrat.zeller.name%TYPE;     -- Subsystem name
    o_subseries  iqstrat.zeller.name%TYPE;     -- Subseries name                       
    o_stage      iqstrat.zeller.name%TYPE;     -- Stage name
    o_supergroup iqstrat.zeller.name%TYPE;     -- Supergroup name
    o_group      iqstrat.zeller.name%TYPE;     -- Group name
    o_subgroup   iqstrat.zeller.name%TYPE;     -- Subgroup name
    o_formation  iqstrat.zeller.name%TYPE;     -- formation name
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.source_kid,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
--         AND tlt.well_header_kid = sKID
         AND tlt.well_header_kid IN (SELECT kid
                                       FROM qualified.well_headers
                                      WHERE well_header_kid = (SELECT well_header_kid
                                                                 FROM qualified.well_headers
                                                                WHERE kid = sKID))
    ORDER BY iz.sequence;
--
    CURSOR crsr2(sKID IN VARCHAR2) IS
      SELECT iz.kid,
             iz.sequence,
             iz.rank,
             iz.name,
             tlt.source_kid,
             tlt.depth_top,
             tlt.depth_base,
             NVL((SELECT name FROM zeller WHERE iz.system = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.series = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subsystem = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subseries = kid), '99999'),                        
             NVL((SELECT name FROM zeller WHERE iz.stage = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.supergroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.sGroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.subgroup = kid), '99999'),
             NVL((SELECT name FROM zeller WHERE iz.formation = kid), '99999')
        FROM iqstrat.zeller2 iz,
             iqstrat.doe_co2_tops tlt
       WHERE tlt.zeller_kid = iz.kid
--         AND tlt.well_header_kid = sKID
         AND tlt.well_header_kid IN (SELECT kid
                                       FROM qualified.well_headers
                                      WHERE well_header_kid = (SELECT well_header_kid
                                                                 FROM qualified.well_headers
                                                                WHERE kid = sKID))
    ORDER BY iz.sequence;
--
  BEGIN
--
--  Add DTD to XML
--
    dtd;
--
    SELECT COUNT(iz.kid) 
      INTO l_count
      FROM iqstrat.zeller iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
--       AND tlt.well_header_kid = sKID;
       AND tlt.well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = sKID));
--
    SELECT COUNT(iz.kid) 
      INTO l_count2
      FROM iqstrat.zeller2 iz,
           iqstrat.doe_co2_tops tlt
     WHERE tlt.zeller_kid = iz.kid
--       AND tlt.well_header_kid = sKID;
       AND tlt.well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = sKID));
--
    l_count := l_count+l_count2;
    htp.print('<strat records="'||l_count||'" ref="KGS The Stratigraphic Succession in Kansas, edited by D. E. Zeller, Dec. 1968, updated 2012">');
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,        -- Unique KEY For record
            o_seq,        -- Order 
            o_rank,       -- Rank, SYSTEM,SERIES, etc.
            o_name,       -- Name of Unit
--            
            o_src,        -- Source KID
            o_top,        -- Start Depth
            o_base,       -- End Depth
--    
            o_system,     -- System name
            o_series,     -- Series name
            o_subsystem,  -- Subsystem name
            o_subseries,  -- Subseries name                       
            o_stage,      -- Stage name
            o_supergroup, -- Supergroup name
            o_group,      -- Group name
            o_subgroup,   -- Subgroup name
            o_formation;  -- formation name
      EXIT WHEN crsr%NOTFOUND;
--
      htp.print('  <age key="'||o_kid||'" '||
                       'id="'||o_seq||'" '||
                       'src="'||o_src||'" '||
                       'rank="'||o_rank||'" '||
                       'name="'||o_name||'" '||
                       'top="'||o_top||'" ');
--
      IF (o_base > o_top) THEN
        htp.print('base="'||o_base||'" ');
      END IF;
--
      SELECT COUNT(*)
        INTO l_cnt
        FROM iqstrat.type_log_tops_evaluated
       WHERE well_header_kid = sKID
         AND zeller_kid      = o_kid
         AND evaluated       = 'ACCEPT';
--
      IF (l_cnt = 3) THEN
        htp.print('level="Excellent" ');
      ELSIF (l_cnt = 2) THEN
        htp.print('level="Good" ');
      ELSIF (l_cnt = 1) THEN
        htp.print('level="Fair" ');
      ELSE      
        htp.print('level="Poor" ');
      END IF;
--
      IF (o_system != '99999') THEN
        htp.print('system="'||o_system||'" ');
      END IF;
--      
      IF (o_subsystem != '99999') THEN
        htp.print('subsystem="'||o_subsystem||'" ');
      END IF;
--      
      IF (o_series != '99999') THEN
        htp.print('series="'||o_series||'" ');
      END IF;
--      
      IF (o_stage != '99999') THEN
        htp.print('stage="'||o_stage||'" ');
      END IF;
--      
      IF (o_group != '99999') THEN
        htp.print('group="'||o_group||'" ');
      END IF;
--      
      IF (o_subgroup != '99999') THEN
        htp.print('subgroup="'||o_subgroup||'" ');
      END IF;
--      
      IF (o_formation != '99999') THEN
        htp.print('form="'||o_formation||'" ');
      END IF;
--
      htp.print('/>');
--
    END LOOP;
    CLOSE crsr;
--
    OPEN crsr2(sKID);
    LOOP
      FETCH crsr2
       INTO o_kid,        -- Unique KEY For record
            o_seq,        -- Order 
            o_rank,       -- Rank, SYSTEM,SERIES, etc.
            o_name,       -- Name of Unit
--
            o_src,        -- Source KID
            o_top,        -- Start Depth
            o_base,       -- End Depth
--    
            o_system,     -- System name
            o_series,     -- Series name
            o_subsystem,  -- Subsystem name
            o_subseries,  -- Subseries name                       
            o_stage,      -- Stage name
            o_supergroup, -- Supergroup name
            o_group,      -- Group name
            o_subgroup,   -- Subgroup name
            o_formation;  -- formation name
      EXIT WHEN crsr2%NOTFOUND;
--
      htp.print('  <age key="'||o_kid||'" '||
                       'id="'||o_seq||'" '||
                       'src="'||o_src||'" '||
                       'rank="'||o_rank||'" '||
                       'name="'||o_name||'" '||
                       'top="'||o_top||'" ');
--
      IF (o_base > o_top) THEN
        htp.print('base="'||o_base||'" ');
      END IF;
--
      SELECT COUNT(*)
        INTO l_cnt
        FROM iqstrat.type_log_tops_evaluated
       WHERE well_header_kid = sKID
         AND zeller_kid      = o_kid
         AND evaluated       = 'ACCEPT';
--
      IF (l_cnt = 3) THEN
        htp.print('level="Excellent" ');
      ELSIF (l_cnt = 2) THEN
        htp.print('level="Good" ');
      ELSIF (l_cnt = 1) THEN
        htp.print('level="Fair" ');
      ELSE      
        htp.print('level="Poor" ');
      END IF;
--
      IF (o_system != '99999') THEN
        htp.print('system="'||o_system||'" ');
      END IF;
--      
      IF (o_series != '99999') THEN
        htp.print('series="'||o_series||'" ');
      END IF;
--      
      IF (o_subsystem != '99999') THEN
        htp.print('subsystem="'||o_subsystem||'" ');
      END IF;
--      
      IF (o_subseries != '99999') THEN
        htp.print('subseries="'||o_subseries||'" ');
      END IF;
--      
      IF (o_stage != '99999') THEN
        htp.print('stage="'||o_stage||'" ');
      END IF;
--      
      IF (o_group != '99999') THEN
        htp.print('group="'||o_group||'" ');
      END IF;
--      
      IF (o_subgroup != '99999') THEN
        htp.print('subgroup="'||o_subgroup||'" ');
      END IF;
--      
      IF (o_formation != '99999') THEN
        htp.print('form="'||o_formation||'" ');
      END IF;
--
      htp.print('/>');
--
    END LOOP;
    CLOSE crsr2;
--
    htp.print('</strat>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
--
  END getXML;
--
--
-- PROCEDURE    dtd
-- Description: This procedure will build the DTD and the Columns in the 
--              Kansas Stratigraphic Units data table.
  PROCEDURE dtd IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE strat [');
    htp.print('<!ELEMENT strat (age*)>');
    htp.print('<!ATTLIST strat records  CDATA #IMPLIED');
    htp.print('                ref      CDATA #IMPLIED>');
    htp.print('<!ELEMENT age  EMPTY>');
    htp.print('<!ATTLIST age  key       CDATA #IMPLIED');
    htp.print('               id        CDATA #IMPLIED');
    htp.print('               src       CDATA #IMPLIED');
    htp.print('               rank      CDATA #IMPLIED');
    htp.print('               name      CDATA #IMPLIED');
    htp.print('               top       CDATA #IMPLIED');
    htp.print('               base      CDATA #IMPLIED');
    htp.print('               start     CDATA #IMPLIED');
    htp.print('               s_cor     CDATA #IMPLIED');
    htp.print('               end       CDATA #IMPLIED');
    htp.print('               e_cor     CDATA #IMPLIED');
    htp.print('               level     CDATA #IMPLIED');
    htp.print('               red       CDATA #IMPLIED');
    htp.print('               green     CDATA #IMPLIED');
    htp.print('               blue      CDATA #IMPLIED');
    htp.print('               eon       CDATA #IMPLIED');
    htp.print('               era       CDATA #IMPLIED');
    htp.print('               system    CDATA #IMPLIED');
    htp.print('               subsystem CDATA #IMPLIED');
    htp.print('               series    CDATA #IMPLIED');
    htp.print('               stage     CDATA #IMPLIED');
    htp.print('               group     CDATA #IMPLIED');
    htp.print('               subgroup  CDATA #IMPLIED');
    htp.print('               form      CDATA #IMPLIED');
    htp.print('               error     CDATA #IMPLIED>]>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END dtd;
--
--
-- PROCEDURE     save_data
-- Description: This procedure will save data to the type log tops Table.
-- Input:       sKID     = Primary Key of record
--              src      = Owner KID of top
--              sZeller  = Zeller KID
--              sName    = Horizon Name
--              dTop     = Top Depth
--              dBase    = Base Depth
--
  PROCEDURE save_data( sKID    IN VARCHAR2,
                       src     IN VARCHAR2, 
                       sZeller IN VARCHAR2, 
                       sName   IN VARCHAR2, 
                       dTop    IN NUMBER,
                       dBase   IN NUMBER ) IS
--
    l_count NUMBER;
--
  BEGIN
--
    SELECT COUNT(*)
      INTO l_count
      FROM doe_co2_tops 
     WHERE well_header_KID=sKID 
       AND source_KID=src
       AND zeller_KID=sZeller;
--
    IF (l_count > 0) THEN
      UPDATE doe_co2_tops  
         SET name=sName,
             depth_top=dTop,
             depth_base=dBase
       WHERE well_header_KID=sKID 
         AND source_KID=src
         AND zeller_KID=sZeller;
    ELSE
      INSERT 
        INTO doe_co2_tops 
             (well_header_KID, source_KID, zeller_KID, name, depth_top, depth_base) 
      VALUES (sKID, src, sZeller, sName, dTop, dBase);
    END IF;
--    
    COMMIT;
--    
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE errors [');
    htp.print('<!ELEMENT errors (data*)>');   
    htp.print('<!ELEMENT data EMPTY>');
    htp.print('<!ATTLIST data error CDATA #IMPLIED>]>');
    htp.print('<errors>');
    htp.print('  <data error=""/>');
    htp.print('</errors>');
--    
  EXCEPTION
    WHEN OTHERS THEN
--
    ROLLBACK;
--    
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE errors [');
    htp.print('<!ELEMENT errors (data*)>');   
    htp.print('<!ELEMENT data EMPTY>');
    htp.print('<!ATTLIST data error CDATA #IMPLIED>]>');
    htp.print('<errors>');
    htp.print('  <data error="'||SQLERRM||'"/>');
    htp.print('</errors>');
--
  END save_data;
--
--
-- PROCEDURE     delete_data
-- Description: This procedure will delete data from the type log tops Table.
-- Input:       sKID     = Primary Key of record
--              src      = Owner KID of top
--              sZeller  = Zeller KID
--
  PROCEDURE delete_data( sKID    IN VARCHAR2,
                         src     IN VARCHAR2, 
                         sZeller IN VARCHAR2 ) IS
--
    l_count NUMBER;
--
  BEGIN
--
    SELECT COUNT(*)
      INTO l_count
      FROM doe_co2_tops 
     WHERE well_header_KID=sKID 
       AND source_KID=src
       AND zeller_KID=sZeller;
--
    IF (l_count > 0) THEN
      DELETE
        FROM doe_co2_tops  
       WHERE well_header_KID=sKID 
         AND source_KID=src
         AND zeller_KID=sZeller;
--    
      COMMIT;
--      
      htp.print('<?xml version="1.0"?>');
      htp.print('<!DOCTYPE errors [');
      htp.print('<!ELEMENT errors (data*)>');   
      htp.print('<!ELEMENT data EMPTY>');
      htp.print('<!ATTLIST data error CDATA #IMPLIED>]>');
      htp.print('<errors>');
      htp.print('  <data error=""/>');
      htp.print('</errors>');
--    
    ELSE
      htp.print('<?xml version="1.0"?>');
      htp.print('<!DOCTYPE errors [');
      htp.print('<!ELEMENT errors (data*)>');   
      htp.print('<!ELEMENT data EMPTY>');
      htp.print('<!ATTLIST data error CDATA #IMPLIED>]>');
      htp.print('<errors>');
      htp.print('  <data error="No Record Found"/>');
      htp.print('</errors>');
    END IF;
--    
  EXCEPTION
    WHEN OTHERS THEN
--
    ROLLBACK;
--    
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE errors [');
    htp.print('<!ELEMENT errors (data*)>');   
    htp.print('<!ELEMENT data EMPTY>');
    htp.print('<!ATTLIST data error CDATA #IMPLIED>]>');
    htp.print('<errors>');
    htp.print('  <data error="'||SQLERRM||'"/>');
    htp.print('</errors>');
--
  END delete_data;
--
--
END iqstrat_doe_co2_tops_pkg;
/
SHOW ERRORS;
--
grant execute on iqstrat_doe_co2_tops_pkg to apex_public_user;