-- * PLSQL:       iqstrat_doe_co2_wells_pkg.sql Version 1.1 10/11/2007
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2012 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE iqstrat_doe_co2_wells_pkg AS
  PROCEDURE getXML;
  PROCEDURE getWellXML(sCounty IN VARCHAR2);
  PROCEDURE getWellXML(sArea IN VARCHAR2);
  PROCEDURE getWellXML(sAPI IN VARCHAR2);
  PROCEDURE getWellXML(sKID IN VARCHAR2);
  PROCEDURE getWellLAS3XML(sCounty IN VARCHAR2);
  PROCEDURE getWellLAS3XML(sArea IN VARCHAR2);
  PROCEDURE getData(sKID IN VARCHAR2);
  PROCEDURE getLAS3Data(sKID IN VARCHAR2);
  PROCEDURE dtd_and_columns;
END iqstrat_doe_co2_wells_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY iqstrat_doe_co2_wells_pkg AS
--
-- PROCEDURE    getXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    xml stream containing user information.
--
  PROCEDURE getXML IS
--
    l_count   NUMBER;
    o_kid     qualified.well_headers.kid%TYPE;        -- primary key
    o_api     qualified.well_headers.api_number%TYPE; -- API-Number
--
    CURSOR crsr IS
      SELECT qwh.kid, 
             qwh.api_number
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
--             iqstrat.doe_co2_wells itlw
      WHERE qwh.kid = itlw.well_header_kid
      ORDER BY qwh.api_number;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
--           iqstrat.doe_co2_wells itlw
     WHERE qwh.kid = itlw.well_header_kid;
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;    -- API-Number
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
--             iqstrat.doe_co2_wells itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
--           iqstrat.doe_co2_wells itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sArea = the area id
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sArea IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sArea IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
--             iqstrat.doe_co2_wells itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code IN (SELECT county_code 
                                  FROM iqstrat.type_log_county
                                 WHERE area_id = sArea);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
--           iqstrat.doe_co2_wells itlw
     WHERE qwh.kid = itlw.well_header_kid 
       AND qwh.county_code IN (SELECT county_code 
                                FROM iqstrat.type_log_county 
                               WHERE area_id = sArea);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sArea);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sAPI = the API-Number
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sAPI IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sAPI IN VARCHAR2) IS
      SELECT UNIQUE(well_header_kid)
--        FROM elog.ozark_co2
        FROM iqstrat.doe_co2_wells
       WHERE api_number LIKE sAPI||'%';
--
  BEGIN
--
    SELECT COUNT(well_header_kid)
      INTO l_count
--      FROM elog.ozark_co2
      FROM iqstrat.doe_co2_wells
     WHERE api_number LIKE sAPI||'%';
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sAPI);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE" />');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'" />');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sKID = the Well Header KID
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sKID IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sKID IN VARCHAR2) IS
      SELECT UNIQUE(well_header_kid)
        FROM elog.ozark_co2
--        FROM iqstrat.doe_co2_wells
       WHERE well_header_kid = sKID;
--
  BEGIN
--
    SELECT COUNT(well_header_kid)
      INTO l_count
      FROM elog.ozark_co2
--      FROM iqstrat.doe_co2_wells
     WHERE well_header_kid = sKID;
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sKID);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE" />');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'" />');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getWellLAS3XML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellLAS3XML(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count2 NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             iqstrat.doe_co2_las3 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           iqstrat.doe_co2_las3 itlw
     WHERE qwh.kid = itlw.well_header_kid                        
       AND qwh.county_code = (SELECT code 
                                FROM global.counties 
                               WHERE LOWER(name) = sCounty);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getLAS3Data(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellLAS3XML;
--
--
-- PROCEDURE    getWellLAS3XML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sArea = the area id
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellLAS3XML(sArea IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count2 NUMBER;
    l_count3 NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sArea IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM qualified.well_headers qwh,
             iqstrat.doe_co2_las3 itlw
       WHERE qwh.kid = itlw.well_header_kid
         AND qwh.county_code IN (SELECT county_code 
                                  FROM iqstrat.type_log_county
                                 WHERE area_id = sArea);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM qualified.well_headers qwh,
           iqstrat.doe_co2_las3 itlw
     WHERE qwh.kid = itlw.well_header_kid 
       AND qwh.county_code IN (SELECT county_code 
                                FROM iqstrat.type_log_county 
                               WHERE area_id = sArea);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sArea);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getLAS3Data(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellLAS3XML;
--
--
-- PROCEDURE    getData()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--              sKEY    = User Created Primary Key
--              sUser   = User Primary Key
--              iAccess = User Access to data
--
  PROCEDURE getData(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_type       headers.type%TYPE;                      -- Type of header
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Other well Data Columns
    o_field      qualified.well_headers.field_name%TYPE;    -- Field Name       (well)
    o_field_kid  qualified.well_headers.field_kid%TYPE;     -- Field KID        (well)
    o_operator   qualified.well_headers.operator_name%TYPE; -- Operator Name    (well)
    o_oper_kid   qualified.well_headers.operator_kid%TYPE;  -- Operator KID     (well)
-- Location Columns
    o_state_cd   qualified.well_headers.state_code%TYPE;   -- State Code
    o_state      global.states.name%TYPE;                  -- State Name
    o_county_cd  qualified.well_headers.county_code%TYPE;  -- County Code
    o_county     global.states_counties.county_name%TYPE;  -- County Name
    o_location   headers.location%TYPE;                    -- Location 
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   qualified.well_headers.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  qualified.well_headers.nad27_longitude%TYPE;    -- Longitude in decimal degrees
    o_utm_x      qualified.well_headers.nad27_utm_x%TYPE;        -- UTM X-Coordinate
    o_utm_y      qualified.well_headers.nad27_utm_y%TYPE;        -- UTM Y-Coordinate
    o_utm_zone   qualified.well_headers.nad27_utm_zone%TYPE;     -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
-- Miscellaneous Columns
    o_by         qualified.well_headers.update_initials%TYPE; -- update by
    o_date       VARCHAR(20);                                 -- update date
    o_comments   qualified.well_headers.comments%TYPE;        -- general comments
--
    l_cnt        NUMBER(6);  -- Number of LAS Files
    lu_cnt       NUMBER(6);  -- Number of LAS Upload Files
    t_cnt        NUMBER(6);  -- Number of tops
    te_cnt       NUMBER(6);  -- Number of tops Evaluated
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
    e_cnt        NUMBER(6);  -- Number of ELOG Files
    s_cnt        NUMBER(6);  -- Number of Scan URLs 
    g_cnt        NUMBER(6);  -- Number of ASCII Geologist Reports Available 
--
    o_text       VARCHAR(2000);
--
    o_las_kid    NUMBER(10); -- Primary Key for the LAS File
    o_ohm        NUMBER(3);  -- Resistivity Log Curves
    o_density    NUMBER(3);  -- Density Log Curves
    o_neutron    NUMBER(3);  -- Neutron Log Curves
    o_sonic      NUMBER(3);  -- Sonic Log Curves
    o_sp         NUMBER(3);  -- Spontaneous Potential Log Curve
    o_gamma      NUMBER(3);  -- Gamma Ray Log Curve
    o_pe         NUMBER(3);  -- Photoelectric Log Curves
    o_th         NUMBER(3);  -- Thorium Log Curve
    o_u          NUMBER(3);  -- Uranium Log Curves
    o_p          NUMBER(3);  -- Potassium Log Curves
--
    o_res        NUMBER(3);  -- Resistivity Type Log
    o_lith       NUMBER(3);  -- Litho-density Type Log
    o_dt         NUMBER(3);  -- Sonic Type Log
    o_spgr       NUMBER(3);  -- Spectral Gamma Ray Type Log
    o_gr         NUMBER(3);  -- Gamma Ray Type Log
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             'WELL',       
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(REPLACE(field_name,'&','&amp;'), '-99'), 
             NVL(field_kid, -99), 
             NVL(REPLACE(operator_name,'&','&amp;'), '-99'),
             NVL(operator_kid, -99),
             NVL(state_code, -9),
             NVL((SELECT name 
                    FROM global.states 
                   WHERE code = A.state_code), '-99'), 
             NVL(county_code, -99),  
             NVL((SELECT county_name 
                    FROM global.states_counties 
                   WHERE state_code = A.state_code
                     AND county_code = A.county_code), '-99'), 
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(nad27_utm_x, -99), 
             NVL(nad27_utm_y, -99), 
             NVL(nad27_utm_zone, -99), 
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99), 
             NVL(update_initials, '-99'), 
             TO_CHAR(update_date, 'MM/DD/YYYY')
--             NVL(REPLACE(comments,'&','&amp;'), '-99')         
        FROM qualified.well_headers A
       WHERE kid = sKID;
--       WHERE well_header_kid = kid
--
    CURSOR las_file_info_crsr (sKID VARCHAR2) IS
      SELECT kid   
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = sKID);
--
  BEGIN
--
    o_kid       := '-99';
    o_type      := '-99';  -- Type of header - WELL or OUTCROP
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Other well Data Columns
    o_field     := '-99';  -- Field Name       (well)
    o_field_kid := -99;    -- Field KID        (well)
    o_operator  := '-99';  -- Operator Name    (well)
    o_oper_kid  := -99;    -- Operator KID     (well)
-- Location Columns
    o_state_cd  := -9;     -- State Code
    o_state     := '-99';  -- State Name
    o_county_cd := -99;    -- County Code
    o_county    := '-99';  -- County Name
    o_location  := '-99';  -- Location 
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- XY Position of Columns
    o_latitude  := -99;    -- Latitude in decimal degrees
    o_longitude := -99;    -- Longitude in decimal degrees
    o_utm_x     := -99;    -- UTM X-Coordinate
    o_utm_y     := -99;    -- UTM Y-Coordinate
    o_utm_zone  := -99;    -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
-- Miscellaneous Columns
    o_by        := '-99';  -- update by
    o_date      := '-99';  -- update date
    o_comments  := '-99';  -- general comments
--
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM las.well_headers
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = sKID);
--
    IF (l_count > 0) THEN
      o_res  :=0;  -- Resistivity Type Log
      o_lith :=0;  -- Litho-density Type Log
      o_dt   :=0;  -- Sonic Type Log
      o_spgr :=0;  -- Spectral Gamma Ray Type Log
      o_gr   :=0;  -- Gamma Ray Type Log
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_las_kid;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
        o_sp := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%SPONTANEOUS%');
        o_gamma := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%GAMMA%');
        o_ohm := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%RESISTIVITY%');
        o_sonic := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%SONIC%');
        o_density := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%DENSITY%');
        o_neutron := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%NEUTRON%');
        o_pe := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%PHOTOELECTRIC%');
        o_th := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%THORIUM%');
        o_u := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%URANIUM%');
        o_p := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%POTASSIUM%');
--
        IF (o_ohm > 0) THEN
          o_res := 1;
        END IF;
--        
        IF (o_gr > 0) AND (o_neutron > 0) AND (o_density > 0) THEN
          o_lith := 1;
        END IF;
--
        IF (o_sonic > 0) THEN
          o_dt := 1;
        END IF;
--
        IF (o_th > 0) AND (o_u > 0) AND (o_p > 0) THEN
          o_spgr := 1;
        END IF;
--
        IF (o_gamma > 0) THEN
          o_gr := 1;
        END IF;
--
      END LOOP;
      CLOSE las_file_info_crsr;
--
    END IF;
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_type,      -- Type of header - WELL or OUTCROP
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Other well Data Columns
            o_field,     -- Field Name       (well)
            o_field_kid, -- Field KID        (well)
            o_operator,  -- Operator Name    (well)
            o_oper_kid,  -- Operator KID     (well)
            -- Location Columns
            o_state_cd,  -- State Code
            o_state,     -- State Name
            o_county_cd, -- County Code
            o_county,    -- County Name
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            o_utm_x,     -- UTM X-Coordinate
            o_utm_y,     -- UTM Y-Coordinate
            o_utm_zone,  -- UTM Zone
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df,        -- elevation derrick floor (well)
            -- Miscellaneous Columns
            o_by,        -- update by
            o_date;      -- update date
--            o_comments;  -- general comments
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        htp.print('  <data>');
--        htp.print('    <info kid="0" '||
--                            'well_kid="'||o_kid||'" ');
        o_text := '    <info kid="0" '||'well_kid="'||o_kid||'" ';
--        
        IF (o_type != '-99') THEN
--          htp.print('type="'||o_type||'" ');
          o_text := o_text||'type="'||o_type||'" ';
        END IF;
--        
        IF (o_api != '-99') THEN
--          htp.print('api="'||o_api||'" ');
          o_text := o_text||'api="'||o_api||'" ';
        END IF;
--        
        IF (o_name != '-99') THEN
--          htp.print('name="'||o_name||'" ');
          o_text := o_text||'name="'||o_name||'" ';
        END IF;
--        
        IF (o_status != '-99') THEN
--          htp.print('status="'||o_status||'" ');
          o_text := o_text||'status="'||o_status||'" ';
        END IF;
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
--
--    Other well information
--
      IF ((o_field != '-99')   OR (o_field_kid != -99) OR
          (o_operator!= '-99') OR (o_oper_kid != -99)) THEN
--            
--        htp.print('    <other ');
        o_text := '    <other ';
--          
        IF (o_operator != '-99') THEN
--          htp.print('operator="'||o_operator||'" ');
          o_text := o_text||'operator="'||o_operator||'" ';
        END IF;       
--          
        IF (o_oper_kid != -99) THEN
--          htp.print('oper_kid="'||o_oper_kid||'" ');
          o_text := o_text||'oper_kid="'||o_oper_kid||'" ';
        END IF;
--          
        IF (o_field != '-99') THEN
--          htp.print('field="'||o_field||'" ');
          o_text := o_text||'field="'||o_field||'" ';
        END IF;
--          
        IF (o_field_kid != -99) THEN
--          htp.print('field_kid="'||o_field_kid||'" ');
          o_text := o_text||'field_kid="'||o_field_kid||'" ';
        END IF;
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    Location Information
--
      IF ((o_state_cd != -9)    OR (o_state != '-99')   OR 
          (o_county_cd != -99)  OR (o_county != '-99')  OR 
          (o_location != '-99') OR 
          (o_township != -99)   OR (o_town_dir != 'X')  OR 
          (o_range != -99)      OR (o_range_dir != 'X') OR 
          (o_section != -9)) THEN
--            
--        htp.print('    <loc ');
        o_text := '    <loc ';
--          
        IF (o_state != '-99') THEN
--          htp.print('state="'||o_state||'" ');
          o_text := o_text||'state="'||o_state||'" ';
        END IF;       
--          
        IF (o_state_cd != -9) THEN
--          htp.print('state_cd="'||o_state_cd||'" ');
          o_text := o_text||'state_cd="'||o_state_cd||'" ';
        END IF;       
--          
        IF (o_county != '-99') THEN
--          htp.print('county="'||o_county||'" ');
          o_text := o_text||'county="'||o_county||'" ';
        END IF;       
--          
        IF (o_county_cd != -99) THEN
--          htp.print('county_cd="'||o_county_cd||'" ');
          o_text := o_text||'county_cd="'||o_county_cd||'" ';
        END IF;       
--          
        IF (o_location != '-99') THEN
--          htp.print('loc="'||o_location||'" ');
          o_text := o_text||'loc="'||o_location||'" ';
        END IF;       
--          
        IF (o_township != -99) THEN
--          htp.print('town="'||o_township||'" ');
          o_text := o_text||'town="'||o_township||'" ';
        END IF;       
--          
        IF (o_town_dir != 'X') THEN
--          htp.print('town_dir="'||o_town_dir||'" ');
          o_text := o_text||'town_dir="'||o_town_dir||'" ';
        END IF;       
--          
        IF (o_range != -99) THEN
--          htp.print('range="'||o_range||'" ');
          o_text := o_text||'range="'||o_range||'" ';
        END IF;       
--          
        IF (o_range_dir != 'X') THEN
--          htp.print('range_dir="'||o_range_dir||'" ');
          o_text := o_text||'range_dir="'||o_range_dir||'" ';
        END IF;       
--          
        IF (o_section != -9) THEN
--          htp.print('section="'||o_section||'" ');
          o_text := o_text||'section="'||o_section||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    XY Position Information
--
      IF ((o_latitude != -99) OR (o_longitude != -99) OR 
          (o_utm_x != -99) OR (o_utm_y != -99)  OR (o_utm_zone != -99)) THEN
--            
--        htp.print('    <xy ');
        o_text := '    <xy ';
--          
        IF (o_latitude != -99) THEN
--          htp.print('latitude="'||o_latitude||'" ');
          o_text := o_text||'latitude="'||o_latitude||'" ';
        END IF;       
--          
        IF (o_longitude != -99) THEN
--          htp.print('longitude="'||o_longitude||'" ');
          o_text := o_text||'longitude="'||o_longitude||'" ';
        END IF;       
--          
        IF (o_utm_zone != -99) THEN
--          htp.print('zone="'||o_utm_zone||'" ');
          o_text := o_text||'zone="'||o_utm_zone||'" ';
        END IF;       
--          
        IF (o_utm_x != -99) THEN
--          htp.print('utm_x="'||o_utm_x||'" ');
          o_text := o_text||'utm_x="'||o_utm_x||'" ';
        END IF;       
--          
        IF (o_utm_y != -99) THEN
--          htp.print('utm_y="'||o_utm_y||'" ');
          o_text := o_text||'utm_y="'||o_utm_y||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    Z Position - Depth, Elevation
--
      IF ((o_depth != -99) OR (o_kb != -99) OR (o_gl != -99) OR (o_df != -99)) THEN
--            
--        htp.print('    <z ');
        o_text := '    <z ';
--          
        IF (o_depth != -99) THEN
--          htp.print('depth="'||o_depth||'" ');
          o_text := o_text||'depth="'||o_depth||'" ';
        END IF;       
--          
        IF (o_gl != -99) THEN
--          htp.print('gl="'||o_gl||'" ');
          o_text := o_text||'gl="'||o_gl||'" ';
        END IF;       
--          
        IF (o_kb != -99) THEN
--          htp.print('kb="'||o_kb||'" ');
          o_text := o_text||'kb="'||o_kb||'" ';
        END IF;       
--          
        IF (o_df != -99) THEN
--          htp.print('df="'||o_df||'" ');
          o_text := o_text||'df="'||o_df||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--      
--    Comments
--
---      IF (o_comments != '-99') THEN
---        htp.print('    <comments> '||o_comments||'</comments>');
---      END IF;
--
--    Miscellaneous Fields
--
      IF (o_by != '-99') OR (o_date != '-99') THEN
--        htp.print('    <misc ');
        o_text := '    <misc ';
--          
        IF (o_by != '-99') THEN
--          htp.print('user="'||o_by||'" ');
          o_text := o_text||'user="'||o_by||'" ';
        END IF;       
--         
        IF (o_date != '-99') THEN
--          htp.print('date="'||o_date||'" ');
          o_text := o_text||'date="'||o_date||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid);
--
      lu_cnt := 0;
      SELECT COUNT(*)
        INTO lu_cnt
        FROM las_upload.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      e_cnt := 0;
      SELECT COUNT(*)
        INTO e_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      s_cnt := 0;
      SELECT COUNT(*)
        INTO s_cnt
        FROM elog.scan_urls
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
        FROM iqstrat.type_log_tops
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--       WHERE well_header_kid  = o_kid;
--       
--      SELECT COUNT(*)
--        INTO t_cnt
--        FROM iqstrat.type_log_tops
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid);
      te_cnt := 0;
      SELECT COUNT(*)
        INTO te_cnt
        FROM iqstrat.type_log_tops_evaluated
       WHERE well_header_kid = o_kid
         AND evaluated       = 'ACCEPT';
--
      c_cnt := 0;
      SELECT COUNT(*)
        INTO c_cnt
        FROM iqstrat.doe_co2_core_csv
       WHERE well_header_kid = o_kid; 
--
--      c_cnt := 0;
--      SELECT COUNT(*)
--        INTO c_cnt
--        FROM core_library.core_data_and_descriptions
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE well_header_kid = (SELECT well_header_kid
--                                                             FROM qualified.well_headers
--                                                            WHERE kid = o_kid))
--         AND depth_top_core_ft IS NOT NULL;
--
      i_cnt := 0;
      SELECT COUNT(*)
        INTO i_cnt
        FROM qualified.images
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid)
         AND file_url IS NOT NULL;
--
      g_cnt := 0;
      SELECT COUNT(*)
        INTO g_cnt
       FROM iqstrat.doe_co2_georeport
      WHERE well_header_kid IN (SELECT kid
                                  FROM qualified.well_headers
                                 WHERE well_header_kid = (SELECT well_header_kid
                                                            FROM qualified.well_headers
                                                           WHERE kid = o_kid));
--
--      htp.print('    <cnt  las="'||l_cnt||'" '||
--                          'tops="'||t_cnt||'" '||
--                          'core="'||c_cnt||'" '||
--                          'images="'||i_cnt||'"/>');
    IF (l_count > 0) THEN
      htp.print('    <cnt  las="'||l_cnt||'" '||
                          'upload="'||lu_cnt||'" '||
                          'elog="'||e_cnt||'" '||
                          'urls="'||e_cnt||'" '||
                          'eval="'||te_cnt||'" '||
                          'tops="'||t_cnt||'" '||
                          'geo="'||g_cnt||'" '||
                          'core="'||c_cnt||'" '||
                          'images="'||i_cnt||'" '||
                          'ohm_log="'||o_res||'" '||
                          'litho_log="'||o_lith||'" '||
                          'sonic_log="'||o_dt||'" '||
                          'gr_log="'||o_gr||'" '||
                          'spgr_log="'||o_spgr||'" />');
    ELSE
      htp.print('    <cnt  las="'||l_cnt||'" '||
                          'upload="'||lu_cnt||'" '||
                          'elog="'||e_cnt||'" '||
                          'urls="'||e_cnt||'" '||
                          'eval="'||te_cnt||'" '||
                          'tops="'||t_cnt||'" '||
                          'geo="'||g_cnt||'" '||
                          'core="'||c_cnt||'" '||
                          'images="'||i_cnt||'" />');
    END IF;
--        
      htp.print('  </data>');
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'" />');
      htp.print(' </data>');
--
  END getData;
--
--
-- PROCEDURE    getLAS3Data()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--              sKEY    = User Created Primary Key
--              sUser   = User Primary Key
--              iAccess = User Access to data
--
  PROCEDURE getLAS3Data(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_type       headers.type%TYPE;                      -- Type of header
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Other well Data Columns
    o_field      qualified.well_headers.field_name%TYPE;    -- Field Name       (well)
    o_field_kid  qualified.well_headers.field_kid%TYPE;     -- Field KID        (well)
    o_operator   qualified.well_headers.operator_name%TYPE; -- Operator Name    (well)
    o_oper_kid   qualified.well_headers.operator_kid%TYPE;  -- Operator KID     (well)
-- Location Columns
    o_state_cd   qualified.well_headers.state_code%TYPE;   -- State Code
    o_state      global.states.name%TYPE;                  -- State Name
    o_county_cd  qualified.well_headers.county_code%TYPE;  -- County Code
    o_county     global.states_counties.county_name%TYPE;  -- County Name
    o_location   headers.location%TYPE;                    -- Location 
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   qualified.well_headers.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  qualified.well_headers.nad27_longitude%TYPE;    -- Longitude in decimal degrees
    o_utm_x      qualified.well_headers.nad27_utm_x%TYPE;        -- UTM X-Coordinate
    o_utm_y      qualified.well_headers.nad27_utm_y%TYPE;        -- UTM Y-Coordinate
    o_utm_zone   qualified.well_headers.nad27_utm_zone%TYPE;     -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
-- Miscellaneous Columns
    o_by         qualified.well_headers.update_initials%TYPE; -- update by
    o_date       VARCHAR(20);                                 -- update date
    o_comments   qualified.well_headers.comments%TYPE;        -- general comments
--
    l_cnt        NUMBER(6);  -- Number of LAS Files
    lu_cnt       NUMBER(6);  -- Number of LAS Upload Files
    t_cnt        NUMBER(6);  -- Number of tops
    te_cnt       NUMBER(6);  -- Number of tops Evaluated
    c_cnt        NUMBER(6);  -- Number of Core Data
    i_cnt        NUMBER(6);  -- Number of Image Data
    e_cnt        NUMBER(6);  -- Number of ELOG Files
    s_cnt        NUMBER(6);  -- Number of Scan URLs 
    g_cnt        NUMBER(6);  -- Number of ASCII Geologist Reports Available 
--
    o_text       VARCHAR(2000);
--
    o_las_kid    NUMBER(10); -- Primary Key for the LAS File
    o_ohm        NUMBER(3);  -- Resistivity Log Curves
    o_density    NUMBER(3);  -- Density Log Curves
    o_neutron    NUMBER(3);  -- Neutron Log Curves
    o_sonic      NUMBER(3);  -- Sonic Log Curves
    o_sp         NUMBER(3);  -- Spontaneous Potential Log Curve
    o_gamma      NUMBER(3);  -- Gamma Ray Log Curve
    o_pe         NUMBER(3);  -- Photoelectric Log Curves
    o_th         NUMBER(3);  -- Thorium Log Curve
    o_u          NUMBER(3);  -- Uranium Log Curves
    o_p          NUMBER(3);  -- Potassium Log Curves
--
    s_ohm        VARCHAR(4);  -- Resistivity Log Curves
    s_density    VARCHAR(4);  -- Density Log Curves
    s_neutron    VARCHAR(4);  -- Neutron Log Curves
    s_sonic      VARCHAR(4);  -- Sonic Log Curves
    s_sp         VARCHAR(4);  -- Spontaneous Potential Log Curve
    s_gamma      VARCHAR(4);  -- Gamma Ray Log Curve
    s_pe         VARCHAR(4);  -- Photoelectric Log Curves
    s_th         VARCHAR(4);  -- Thorium Log Curve
    s_u          VARCHAR(4);  -- Uranium Log Curves
    s_p          VARCHAR(4);  -- Potassium Log Curves
--
    o_res        NUMBER(3);  -- Resistivity Type Log
    o_lith       NUMBER(3);  -- Litho-density Type Log
    o_dt         NUMBER(3);  -- Sonic Type Log
    o_spgr       NUMBER(3);  -- Spectral Gamma Ray Type Log
    o_gr         NUMBER(3);  -- Gamma Ray Type Log
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             'WELL',       
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(REPLACE(field_name,'&','&amp;'), '-99'), 
             NVL(field_kid, -99), 
             NVL(REPLACE(operator_name,'&','&amp;'), '-99'),
             NVL(operator_kid, -99),
             NVL(state_code, -9),
             NVL((SELECT name 
                    FROM global.states 
                   WHERE code = A.state_code), '-99'), 
             NVL(county_code, -99),  
             NVL((SELECT county_name 
                    FROM global.states_counties 
                   WHERE state_code = A.state_code
                     AND county_code = A.county_code), '-99'), 
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(nad27_utm_x, -99), 
             NVL(nad27_utm_y, -99), 
             NVL(nad27_utm_zone, -99), 
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99), 
             NVL(update_initials, '-99'), 
             TO_CHAR(update_date, 'MM/DD/YYYY')
--             NVL(REPLACE(comments,'&','&amp;'), '-99')         
        FROM qualified.well_headers A
       WHERE kid = sKID;
--       WHERE well_header_kid = kid
--
    CURSOR las_file_info_crsr (sKID VARCHAR2) IS
      SELECT kid   
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = sKID);
--
  BEGIN
--
    o_kid       := '-99';
    o_type      := '-99';  -- Type of header - WELL or OUTCROP
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Other well Data Columns
    o_field     := '-99';  -- Field Name       (well)
    o_field_kid := -99;    -- Field KID        (well)
    o_operator  := '-99';  -- Operator Name    (well)
    o_oper_kid  := -99;    -- Operator KID     (well)
-- Location Columns
    o_state_cd  := -9;     -- State Code
    o_state     := '-99';  -- State Name
    o_county_cd := -99;    -- County Code
    o_county    := '-99';  -- County Name
    o_location  := '-99';  -- Location 
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- XY Position of Columns
    o_latitude  := -99;    -- Latitude in decimal degrees
    o_longitude := -99;    -- Longitude in decimal degrees
    o_utm_x     := -99;    -- UTM X-Coordinate
    o_utm_y     := -99;    -- UTM Y-Coordinate
    o_utm_zone  := -99;    -- UTM Zone
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
-- Miscellaneous Columns
    o_by        := '-99';  -- update by
    o_date      := '-99';  -- update date
    o_comments  := '-99';  -- general comments
--
--
--  Count the total number of LAS Files for a specific well.
--
    SELECT COUNT(kid)
      INTO l_count                   -- Total Number of Digital LAS Files
      FROM las.well_headers
     WHERE well_header_kid IN (SELECT kid
                                 FROM qualified.well_headers
                                WHERE well_header_kid = sKID);
--
    IF (l_count > 0) THEN
      o_res  :=0;  -- Resistivity Type Log
      o_lith :=0;  -- Litho-density Type Log
      o_dt   :=0;  -- Sonic Type Log
      o_spgr :=0;  -- Spectral Gamma Ray Type Log
      o_gr   :=0;  -- Gamma Ray Type Log
--
      OPEN las_file_info_crsr(sKID);
--
      LOOP
        FETCH las_file_info_crsr
         INTO o_las_kid;
        EXIT WHEN las_file_info_crsr%NOTFOUND;
--
        SELECT gr_log,
               ohm_log,
               neutron_log,
               density_log,
               pe_log,
               sonic_log,
               th_log,
               u_log,
               k_log
          INTO s_gamma,
               s_ohm,
               s_neutron,
               s_density,
               s_pe,
               s_sonic,
               s_th,
               s_u,
               s_p
          FROM iqstrat.doe_co2_las3
         WHERE well_header_kid = sKID;              
--
         o_gamma :=0;
         IF (s_gamma = 'YES') THEN
           o_gamma := 1;
         END IF;
--         
         o_ohm :=0;
         IF (s_ohm = 'YES') THEN
           o_ohm := 1;
         END IF;
--         
         o_neutron :=0;
         IF (s_neutron = 'YES') THEN
           o_neutron := 1;
         END IF;
--         
         o_density :=0;
         IF (s_density = 'YES') THEN
           o_density := 1;
         END IF;
--         
         o_pe :=0;
         IF (s_pe = 'YES') THEN
           o_pe := 1;
         END IF;
--         
         o_sonic :=0;
         IF (s_sonic = 'YES') THEN
           o_sonic := 1;
         END IF;
--         
         o_th :=0;
         IF (s_th = 'YES') THEN
           o_th := 1;
         END IF;
--         
         o_u :=0;
         IF (s_u = 'YES') THEN
           o_u := 1;
         END IF;
--         
         o_p :=0;
         IF (s_p = 'YES') THEN
           o_p := 1;
         END IF;
--         
--        o_sp := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%SPONTANEOUS%');
--        o_gamma := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%GAMMA%');
--        o_ohm := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%RESISTIVITY%');
--        o_sonic := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%SONIC%');
--        o_density := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%DENSITY%');
--        o_neutron := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%NEUTRON%');
--        o_pe := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%PHOTOELECTRIC%');
--        o_th := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%THORIUM%');
--        o_u := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%URANIUM%');
--        o_p := iqstrat.type_log_summary_pkg.count_log(o_las_kid,'%POTASSIUM%');
--
        IF (s_ohm = 'YES') THEN
          o_res := 1;
        END IF;
--        
        IF (s_gamma = 'YES') AND (s_neutron = 'YES') AND (s_density = 'YES') THEN
          o_lith := 1;
        END IF;
--
        IF (s_sonic = 'YES') THEN
          o_dt := 1;
        END IF;
--
        IF (s_th = 'YES') AND (s_u = 'YES') AND (s_p = 'YES') THEN
          o_spgr := 1;
        END IF;
--
        IF (s_gamma = 'YES') THEN
          o_gr := 1;
        END IF;
--
      END LOOP;
      CLOSE las_file_info_crsr;
--
    END IF;
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_type,      -- Type of header - WELL or OUTCROP
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Other well Data Columns
            o_field,     -- Field Name       (well)
            o_field_kid, -- Field KID        (well)
            o_operator,  -- Operator Name    (well)
            o_oper_kid,  -- Operator KID     (well)
            -- Location Columns
            o_state_cd,  -- State Code
            o_state,     -- State Name
            o_county_cd, -- County Code
            o_county,    -- County Name
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            o_utm_x,     -- UTM X-Coordinate
            o_utm_y,     -- UTM Y-Coordinate
            o_utm_zone,  -- UTM Zone
            -- Z Position - Depth, Elevation Columns
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df,        -- elevation derrick floor (well)
            -- Miscellaneous Columns
            o_by,        -- update by
            o_date;      -- update date
--            o_comments;  -- general comments
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        htp.print('  <data>');
--        htp.print('    <info kid="0" '||
--                            'well_kid="'||o_kid||'" ');
        o_text := '    <info kid="0" '||'well_kid="'||o_kid||'" ';
--        
        IF (o_type != '-99') THEN
--          htp.print('type="'||o_type||'" ');
          o_text := o_text||'type="'||o_type||'" ';
        END IF;
--        
        IF (o_api != '-99') THEN
--          htp.print('api="'||o_api||'" ');
          o_text := o_text||'api="'||o_api||'" ';
        END IF;
--        
        IF (o_name != '-99') THEN
--          htp.print('name="'||o_name||'" ');
          o_text := o_text||'name="'||o_name||'" ';
        END IF;
--        
        IF (o_status != '-99') THEN
--          htp.print('status="'||o_status||'" ');
          o_text := o_text||'status="'||o_status||'" ';
        END IF;
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
--
--    Other well information
--
      IF ((o_field != '-99')   OR (o_field_kid != -99) OR
          (o_operator!= '-99') OR (o_oper_kid != -99)) THEN
--            
--        htp.print('    <other ');
        o_text := '    <other ';
--          
        IF (o_operator != '-99') THEN
--          htp.print('operator="'||o_operator||'" ');
          o_text := o_text||'operator="'||o_operator||'" ';
        END IF;       
--          
        IF (o_oper_kid != -99) THEN
--          htp.print('oper_kid="'||o_oper_kid||'" ');
          o_text := o_text||'oper_kid="'||o_oper_kid||'" ';
        END IF;
--          
        IF (o_field != '-99') THEN
--          htp.print('field="'||o_field||'" ');
          o_text := o_text||'field="'||o_field||'" ';
        END IF;
--          
        IF (o_field_kid != -99) THEN
--          htp.print('field_kid="'||o_field_kid||'" ');
          o_text := o_text||'field_kid="'||o_field_kid||'" ';
        END IF;
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    Location Information
--
      IF ((o_state_cd != -9)    OR (o_state != '-99')   OR 
          (o_county_cd != -99)  OR (o_county != '-99')  OR 
          (o_location != '-99') OR 
          (o_township != -99)   OR (o_town_dir != 'X')  OR 
          (o_range != -99)      OR (o_range_dir != 'X') OR 
          (o_section != -9)) THEN
--            
--        htp.print('    <loc ');
        o_text := '    <loc ';
--          
        IF (o_state != '-99') THEN
--          htp.print('state="'||o_state||'" ');
          o_text := o_text||'state="'||o_state||'" ';
        END IF;       
--          
        IF (o_state_cd != -9) THEN
--          htp.print('state_cd="'||o_state_cd||'" ');
          o_text := o_text||'state_cd="'||o_state_cd||'" ';
        END IF;       
--          
        IF (o_county != '-99') THEN
--          htp.print('county="'||o_county||'" ');
          o_text := o_text||'county="'||o_county||'" ';
        END IF;       
--          
        IF (o_county_cd != -99) THEN
--          htp.print('county_cd="'||o_county_cd||'" ');
          o_text := o_text||'county_cd="'||o_county_cd||'" ';
        END IF;       
--          
        IF (o_location != '-99') THEN
--          htp.print('loc="'||o_location||'" ');
          o_text := o_text||'loc="'||o_location||'" ';
        END IF;       
--          
        IF (o_township != -99) THEN
--          htp.print('town="'||o_township||'" ');
          o_text := o_text||'town="'||o_township||'" ';
        END IF;       
--          
        IF (o_town_dir != 'X') THEN
--          htp.print('town_dir="'||o_town_dir||'" ');
          o_text := o_text||'town_dir="'||o_town_dir||'" ';
        END IF;       
--          
        IF (o_range != -99) THEN
--          htp.print('range="'||o_range||'" ');
          o_text := o_text||'range="'||o_range||'" ';
        END IF;       
--          
        IF (o_range_dir != 'X') THEN
--          htp.print('range_dir="'||o_range_dir||'" ');
          o_text := o_text||'range_dir="'||o_range_dir||'" ';
        END IF;       
--          
        IF (o_section != -9) THEN
--          htp.print('section="'||o_section||'" ');
          o_text := o_text||'section="'||o_section||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    XY Position Information
--
      IF ((o_latitude != -99) OR (o_longitude != -99) OR 
          (o_utm_x != -99) OR (o_utm_y != -99)  OR (o_utm_zone != -99)) THEN
--            
--        htp.print('    <xy ');
        o_text := '    <xy ';
--          
        IF (o_latitude != -99) THEN
--          htp.print('latitude="'||o_latitude||'" ');
          o_text := o_text||'latitude="'||o_latitude||'" ';
        END IF;       
--          
        IF (o_longitude != -99) THEN
--          htp.print('longitude="'||o_longitude||'" ');
          o_text := o_text||'longitude="'||o_longitude||'" ';
        END IF;       
--          
        IF (o_utm_zone != -99) THEN
--          htp.print('zone="'||o_utm_zone||'" ');
          o_text := o_text||'zone="'||o_utm_zone||'" ';
        END IF;       
--          
        IF (o_utm_x != -99) THEN
--          htp.print('utm_x="'||o_utm_x||'" ');
          o_text := o_text||'utm_x="'||o_utm_x||'" ';
        END IF;       
--          
        IF (o_utm_y != -99) THEN
--          htp.print('utm_y="'||o_utm_y||'" ');
          o_text := o_text||'utm_y="'||o_utm_y||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    Z Position - Depth, Elevation
--
      IF ((o_depth != -99) OR (o_kb != -99) OR (o_gl != -99) OR (o_df != -99)) THEN
--            
--        htp.print('    <z ');
        o_text := '    <z ';
--          
        IF (o_depth != -99) THEN
--          htp.print('depth="'||o_depth||'" ');
          o_text := o_text||'depth="'||o_depth||'" ';
        END IF;       
--          
        IF (o_gl != -99) THEN
--          htp.print('gl="'||o_gl||'" ');
          o_text := o_text||'gl="'||o_gl||'" ';
        END IF;       
--          
        IF (o_kb != -99) THEN
--          htp.print('kb="'||o_kb||'" ');
          o_text := o_text||'kb="'||o_kb||'" ';
        END IF;       
--          
        IF (o_df != -99) THEN
--          htp.print('df="'||o_df||'" ');
          o_text := o_text||'df="'||o_df||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--      
--    Comments
--
---      IF (o_comments != '-99') THEN
---        htp.print('    <comments> '||o_comments||'</comments>');
---      END IF;
--
--    Miscellaneous Fields
--
      IF (o_by != '-99') OR (o_date != '-99') THEN
--        htp.print('    <misc ');
        o_text := '    <misc ';
--          
        IF (o_by != '-99') THEN
--          htp.print('user="'||o_by||'" ');
          o_text := o_text||'user="'||o_by||'" ';
        END IF;       
--         
        IF (o_date != '-99') THEN
--          htp.print('date="'||o_date||'" ');
          o_text := o_text||'date="'||o_date||'" ';
        END IF;       
--
--        htp.print('/>');
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid);
--
      lu_cnt := 0;
      SELECT COUNT(*)
        INTO lu_cnt
        FROM las_upload.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      e_cnt := 0;
      SELECT COUNT(*)
        INTO e_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      s_cnt := 0;
      SELECT COUNT(*)
        INTO s_cnt
        FROM elog.scan_urls
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE kid = o_kid);
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
        FROM iqstrat.type_log_tops
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
--      t_cnt := 0;
--      SELECT COUNT(*)
--        INTO t_cnt
--        FROM iqstrat.type_log_tops
--       WHERE well_header_kid  = o_kid;
--       
      te_cnt := 0;
      SELECT COUNT(*)
        INTO te_cnt
        FROM iqstrat.type_log_tops_evaluated
       WHERE well_header_kid = o_kid
         AND evaluated       = 'ACCEPT';
--
      c_cnt := 0;
      SELECT COUNT(*)
        INTO c_cnt
        FROM iqstrat.doe_co2_core_csv
       WHERE well_header_kid = o_kid; 
--
--      c_cnt := 0;
--      SELECT COUNT(*)
--        INTO c_cnt
--        FROM core_library.core_data_and_descriptions
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE well_header_kid = (SELECT well_header_kid
--                                                             FROM qualified.well_headers
--                                                            WHERE kid = o_kid))
--         AND depth_top_core_ft IS NOT NULL;
--
      i_cnt := 0;
      SELECT COUNT(*)
        INTO i_cnt
        FROM qualified.images
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
--       WHERE well_header_kid IN (SELECT kid
--                                   FROM qualified.well_headers
--                                  WHERE kid = o_kid)
         AND file_url IS NOT NULL;
--
      g_cnt := 0;
      SELECT COUNT(*)
        INTO g_cnt
       FROM iqstrat.doe_co2_georeport
      WHERE well_header_kid = o_kid; 
--
    IF (l_count > 0) THEN
      htp.print('    <cnt  las="'||l_cnt||'" '||
                          'upload="'||lu_cnt||'" '||
                          'elog="'||e_cnt||'" '||
                          'urls="'||e_cnt||'" '||
                          'eval="'||te_cnt||'" '||
                          'tops="'||t_cnt||'" '||
                          'geo="'||g_cnt||'" '||
                          'core="'||c_cnt||'" '||
                          'images="'||i_cnt||'" '||
                          'ohm_log="'||o_res||'" '||
                          'litho_log="'||o_lith||'" '||
                          'sonic_log="'||o_dt||'" '||
                          'gr_log="'||o_gr||'" '||
                          'spgr_log="'||o_spgr||'" />');
    ELSE
      htp.print('    <cnt  las="'||l_cnt||'" '||
                          'upload="'||lu_cnt||'" '||
                          'elog="'||e_cnt||'" '||
                          'urls="'||e_cnt||'" '||
                          'eval="'||te_cnt||'" '||
                          'tops="'||t_cnt||'" '||
                          'geo="'||g_cnt||'" '||
                          'core="'||c_cnt||'" '||
                          'images="'||i_cnt||'" />');
    END IF;
--        
      htp.print('  </data>');
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'" />');
      htp.print(' </data>');
--
  END getLAS3Data;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the core
--              data table.
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE headers [');
    htp.print('<!ELEMENT headers (data*)>');                  
    htp.print('<!ATTLIST headers records CDATA #IMPLIED>');    -- Total # of Records
    htp.print('<!ELEMENT data (info*, ');                      
    htp.print('                other?, ');                     
    htp.print('                loc?, ');                       
    htp.print('                xy?, ');                        
    htp.print('                z?, ');                         
    htp.print('                comments?, ');                  
    htp.print('                misc?, ');                  
    htp.print('                cnt?)>');                      
    htp.print('<!ELEMENT info  EMPTY>');                       
    htp.print('<!ATTLIST info  kid   CDATA #IMPLIED');          -- Primary KGS KEY
    htp.print('                well_kid   CDATA #IMPLIED');     -- Primary KEY Defined
    htp.print('                key   CDATA #IMPLIED');          -- Primary KEY Defined
    htp.print('                type  CDATA #IMPLIED');          -- type of data
    htp.print('                api   CDATA #IMPLIED');          -- API Number of Well
    htp.print('                name   CDATA #IMPLIED');         -- Outcrop Name
    htp.print('                status CDATA #IMPLIED');         -- Well Status
    htp.print('                error  CDATA #IMPLIED>');        -- Error
    htp.print('<!ELEMENT other EMPTY>');                       
    htp.print('<!ATTLIST other operator  CDATA #IMPLIED');      -- Operator Name
    htp.print('                oper_kid  CDATA #IMPLIED');      -- Operator KID
    htp.print('                field     CDATA #IMPLIED');      -- Field Name
    htp.print('                field_kid CDATA #IMPLIED>');     -- Field KID
    htp.print('<!ELEMENT loc EMPTY>');                         
    htp.print('<!ATTLIST loc state     CDATA #IMPLIED');        -- State Name
    htp.print('              state_cd  CDATA #IMPLIED');        -- State Code
    htp.print('              county    CDATA #IMPLIED');        -- County Name
    htp.print('              county_cd CDATA #IMPLIED');        -- County Code
    htp.print('              loc       CDATA #IMPLIED');        -- Location
    htp.print('              town      CDATA #IMPLIED');        -- township
    htp.print('              town_dir  CDATA #IMPLIED');        -- township direction
    htp.print('              range     CDATA #IMPLIED');        -- range
    htp.print('              range_dir CDATA #IMPLIED');        -- range direction
    htp.print('              section   CDATA #IMPLIED>');       -- section
    htp.print('<!ELEMENT xy  EMPTY>');                         
    htp.print('<!ATTLIST xy  latitude  CDATA #IMPLIED');        -- Latitude
    htp.print('              longitude CDATA #IMPLIED');        -- Longitude
    htp.print('              zone      CDATA #IMPLIED');        -- UTM X-Position
    htp.print('              utm_x     CDATA #IMPLIED');        -- UTM X-Position
    htp.print('              utm_y     CDATA #IMPLIED>');       -- UTM Y-Position
    htp.print('<!ELEMENT z   EMPTY>');                         
    htp.print('<!ATTLIST z   depth     CDATA #IMPLIED');        -- Depth or Height
    htp.print('              gl        CDATA #IMPLIED');        -- Ground Level
    htp.print('              kb        CDATA #IMPLIED');        -- Kelly Bushing
    htp.print('              df        CDATA #IMPLIED>');       -- Derrick Floor
    htp.print('<!ELEMENT comments (#PCDATA)>');                 -- Comments
    htp.print('<!ELEMENT misc EMPTY>');                        
    htp.print('<!ATTLIST misc user      CDATA #IMPLIED');       -- user update info
    htp.print('               access    CDATA #IMPLIED');       -- access of data
    htp.print('               source    CDATA #IMPLIED');       -- source of this data
    htp.print('               date      CDATA #IMPLIED>');      -- Date modified    
    htp.print('<!ELEMENT cnt  EMPTY>');
    htp.print('<!ATTLIST cnt  las       CDATA #IMPLIED');
    htp.print('               upload    CDATA #IMPLIED');
    htp.print('               elog      CDATA #IMPLIED');
    htp.print('               urls      CDATA #IMPLIED');
    htp.print('               eval      CDATA #IMPLIED');
    htp.print('               tops      CDATA #IMPLIED');
    htp.print('               geo       CDATA #IMPLIED');
    htp.print('               core      CDATA #IMPLIED');
    htp.print('               images    CDATA #IMPLIED');
    htp.print('               ohm_log   CDATA #IMPLIED');
    htp.print('               litho_log CDATA #IMPLIED');
    htp.print('               sonic_log CDATA #IMPLIED');
    htp.print('               gr_log    CDATA #IMPLIED');
    htp.print('               spgr_log  CDATA #IMPLIED>]>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
--
--
END iqstrat_doe_co2_wells_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON iqstrat_doe_co2_wells_pkg TO apex_public_user;