-- * PLSQL:       kgs_summary_pkg.sql Version 1.1 10/08/2014
-- * Author:      John R. Victorine
-- * Description: This Package will build a summary page identifing cuttings reports
-- *              by county.
-- * Copyright (c) 2014 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE kgs_summary_pkg AS
  PROCEDURE build_web_page(sCounty IN VARCHAR2);
-----
  PROCEDURE add_well(sKID IN VARCHAR2);
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2);
  PROCEDURE build_finish(sCounty IN VARCHAR2);
END kgs_summary_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY kgs_summary_pkg AS
--
-- PROCEDURE    build_web_page()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    Summary Web Page for specific County of Kansas.
--
  PROCEDURE build_web_page(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    l_count3 NUMBER;
    o_kid    iqstrat.doe_co2_wells.well_header_kid%TYPE; -- headers table primary key
    o_api    qualified.well_headers.api_number%TYPE;  -- Primary Key for table
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
--      SELECT UNIQUE(kid)
      SELECT kid, api_number
        FROM qualified.well_headers qwh
       WHERE qwh.kid IN (SELECT well_header_kid
                          FROM elog.log_headers
                         WHERE well_header_kid = qwh.kid
                           AND (logger_id = 83   AND tool_id = 1165)
                            OR (logger_id = 6422 AND tool_id = 6423)
                            OR (logger_id = 6422 AND tool_id = 7924))
         AND qwh.county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty)
      ORDER BY api_number, kid;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM qualified.well_headers qwh
      WHERE qwh.kid IN (SELECT well_header_kid
                         FROM elog.log_headers
                        WHERE well_header_kid = qwh.kid
                          AND (logger_id = 83   AND tool_id = 1165)
                           OR (logger_id = 6422 AND tool_id = 6423)
                           OR (logger_id = 6422 AND tool_id = 7924))
        AND qwh.county_code = (SELECT code 
                                 FROM global.counties 
                                WHERE LOWER(name) = sCounty);
--
--  Start HTML
--
    htp.print('<LINK href="http://www.kgs.ku.edu/PRS/Ozark/Summary/iqstrat.css" type=text/css rel=stylesheet>');
    htp.headOpen;
    htp.title('Type Log Summary Page');
    htp.headClose;
--    
    htp.print('<BODY>');
--
    build_title_icons( 'Summary Page for '||INITCAP(sCounty)||' County' );
--
    htp.tableOpen('BORDER=1 ALIGN="CENTER" CELLPADDING=1');
--
--    htp.tableRowOpen('CENTER');
    htp.print('<center><table cellpadding="2" cellspacing="2" border="1" width="100%">');
    htp.p('<TH bgColor=#b0c4de colspan="4">&nbsp;</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="2">Total Depth</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="1">&nbsp;</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="6">Wells with</TH>');
    htp.p('<TH bgColor=#b0c4de>&nbsp;</TH>');
    htp.tableRowClose;
--
    htp.p('<TH bgColor=#b0c4de>KID</TH>');
    htp.p('<TH bgColor=#b0c4de>API-Number</TH>');
    htp.p('<TH bgColor=#b0c4de>Well Name</TH>');
    htp.p('<TH bgColor=#b0c4de>TRS</TH>');
--    htp.p('<TH bgColor=#b0c4de>TYPE LOG</TH>');
    htp.p('<TH bgColor=#b0c4de>[feet]</TH>');
    htp.p('<TH bgColor=#b0c4de>FORMATION</TH>');
    htp.p('<TH bgColor=#b0c4de>Project</TH>');
    htp.p('<TH bgColor=#b0c4de>LAS</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="2">Tops</TH>');
--    htp.p('<TH bgColor=#b0c4de>Core CSV</TH>');
    htp.p('<TH bgColor=#b0c4de>Core</TH>');
--    htp.p('<TH bgColor=#b0c4de>Images</TH>');
--    htp.p('<TH bgColor=#b0c4de>Source</TH>');
    htp.p('<TH bgColor=#b0c4de colspan="2">Georeport</TH>');
    htp.p('<TH bgColor=#b0c4de>LAS 3.0</TH>');
--    htp.p('<TH bgColor=#b0c4de>Status</TH>');      
    htp.tableRowClose;
    htp.print('</center>');
--
    IF (l_count > 0) THEN
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;
        EXIT WHEN crsr%NOTFOUND;
--
        add_well(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
    END IF;
--
    htp.tableClose;
--
    build_finish(sCounty);
--    
    htp.bodyClose;
    htp.htmlClose;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('<td colspan=4>'||SQLERRM||'</td>');
    htp.tableClose;
    htp.bodyClose;
    htp.htmlClose;
--
  END build_web_page;
--
--
-- PROCEDURE    add_well()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct well data table.
-- Input:       sKID = Headers Primary Key of the header information data 
--
  PROCEDURE add_well(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        qualified.well_headers.kid%TYPE;        -- Primary Key for table
    o_api        qualified.well_headers.api_number%TYPE; -- Well API-Number or UWI 
    o_name       VARCHAR(200);                           -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;     -- well status or Outcrop Type  
-- Location Columns
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- Z Position - Depth, Elevation Columns
    o_form       qualified.well_headers.rotary_total_depth_formation%TYPE;  -- Formation at TD
    o_depth      qualified.well_headers.rotary_total_depth%TYPE;  -- depth of well or height of outcrop
    o_kb         qualified.well_headers.elevation_kb%TYPE;    -- elevation kelly bushing (well)
    o_gl         qualified.well_headers.elevation_gl%TYPE;    -- elevation ground level
    o_df         qualified.well_headers.elevation_df%TYPE;    -- elevation derrick floor (well)
--
    o_TRS        VARCHAR(40);
    l_percent    NUMBER;
--
    ta_cnt       NUMBER(6);  -- Number of Arbuckle indicator
    tc_cnt       NUMBER(6);  -- Number of DOE CO2 indicator
    tl_cnt       NUMBER(6);  -- Number of Type Log indicator
    l_cnt        NUMBER(6);  -- Number of LAS Files
    t_cnt        NUMBER(6);  -- Number of tops
    ts_cnt       NUMBER(6);  -- Number of tops sources
    c_cnt        NUMBER(6);  -- Number of DOE CO2 Core Data
    ck_cnt       NUMBER(6);  -- Number of KGS Core Data
    ca_cnt       NUMBER(6);  -- Number of Core Analysis Documents
    i_cnt        NUMBER(6);  -- Number of Image Data
    e_cnt        NUMBER(6);  -- Number of ELOG Files
    e2_cnt       NUMBER(6);  -- Number of ELOG Files
--    s_cnt        NUMBER(6);  -- Number of Scan URLs 
    g_cnt        NUMBER(6);  -- Number of ASCII Georeport Files
    l3_cnt       NUMBER(6);  -- Number of LAS 3.0 Files
    l3_status    iqstrat.doe_co2_las3.file_status%TYPE; -- Status
--
    l_start      las.well_headers.depth_start%TYPE;  -- Starting Depth of LAS File
    l_stop       las.well_headers.depth_stop%TYPE;   -- Ending Depth of LAS File
    l_max        NUMBER(6);
    l_min        NUMBER(6);   
    las_value    NUMBER(6);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(api_number, '-99'), 
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(rotary_total_depth_formation, '-99'),
             NVL(rotary_total_depth, -99),    
             NVL(elevation_kb, -99),
             NVL(elevation_gl, -99), 
             NVL(elevation_df, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
  CURSOR las_file_info_crsr (sKID VARCHAR2) IS
    SELECT depth_start,           
           depth_stop             
      FROM las.well_headers
     WHERE well_header_kid = sKID;
--       
  BEGIN
--
    o_kid       := '-99';
    o_api       := '-99';  -- Well API-Number or UWI 
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_status    := '-99';  -- well status or Outcrop Type  
-- Location Columns
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- Z Position - Depth, Elevation Columns
    o_depth     := -99;    -- depth of well or height of outcrop
    o_kb        := -99;    -- elevation kelly bushing (well)
    o_gl        := -99;    -- elevation ground level
    o_df        := -99;    -- elevation derrick floor (well)
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_api,       -- Well API-Number or UWI 
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- well status or Outcrop Type  
            -- Location Columns
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- Z Position - Depth, Elevation Columns
            o_form,      -- formation at TD
            o_depth,     -- depth of well or height of outcrop
            o_kb,        -- elevation kelly bushing (well)
            o_gl,        -- elevation ground level
            o_df;        -- elevation derrick floor (well)
--            o_comments;  -- general comments
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        IF (o_township != -99) THEN
          o_TRS := 'T'||o_township||o_town_dir;
        END IF;       
--          
        IF (o_range != -99) THEN
          o_TRS := o_TRS||' '||'R'||o_range||o_range_dir;
        END IF;       
--          
        IF (o_section != -9) THEN
          o_TRS := o_TRS||' '||'sec. '||o_section;
        END IF;       
--
      tc_cnt := 0;
      SELECT COUNT(*)
        INTO tc_cnt
        FROM elog.ozark_co2       
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
      tl_cnt := 0;
      SELECT COUNT(*)
        INTO tl_cnt
        FROM iqstrat.type_log_wells        
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
      l_cnt := 0;
      SELECT COUNT(*)
        INTO l_cnt
        FROM las.well_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
      e_cnt := 0;
      SELECT COUNT(*)
        INTO e_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
--       WHERE well_header_kid = o_kid
         AND logger_id = 6422
         AND (tool_id = 6423
          OR tool_id = 7924);
--
      e2_cnt := 0;
      SELECT COUNT(*)
        INTO e2_cnt
        FROM elog.log_headers
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
         AND logger_id = 83
         AND tool_id   = 1165;
--
      t_cnt := 0;
      SELECT COUNT(*)
        INTO t_cnt
        FROM iqstrat.doe_co2_tops
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--
      ts_cnt := 0;
--      IF (t_cnt> 0) THEN
--        SELECT COUNT(Unique(data_source))
        SELECT COUNT(*)
          INTO ts_cnt
          FROM qualified.well_tops
         WHERE well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = o_kid));
--      END IF;
--
      ta_cnt := 0;
      IF (t_cnt > 0) THEN      
        SELECT COUNT(*)
          INTO ta_cnt
          FROM iqstrat.doe_co2_tops
         WHERE UPPER(name) LIKE 'ARB%'
           AND well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = o_kid));
      ELSIF (ts_cnt > 0) THEN
        SELECT COUNT(*)
          INTO ta_cnt
          FROM qualified.well_tops
         WHERE UPPER(formation_name) LIKE 'ARB%'
           AND well_header_kid IN (SELECT kid
                                     FROM qualified.well_headers
                                    WHERE well_header_kid = (SELECT well_header_kid
                                                               FROM qualified.well_headers
                                                              WHERE kid = o_kid));
      END IF;
--
      c_cnt := 0;
      SELECT COUNT(*)
        INTO c_cnt
       FROM iqstrat.doe_co2_core_csv
      WHERE well_header_kid = o_kid; 
--
      ck_cnt := 0;
      SELECT COUNT(*)
        INTO ck_cnt
        FROM core_library.core_data_and_descriptions
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
         AND depth_top_core_ft IS NOT NULL;
--
      ca_cnt := 0;
      SELECT COUNT(qwh.kid)
        INTO ca_cnt
        FROM qualified.well_headers qwh,
             qualified.aco_scan_urls qasu
       WHERE qwh.kid = qasu.well_header_kid
         AND qasu.pdf_format = 1
--         AND (qasu.type_of_scan = 'Geochemical Analyses'
         AND  qasu.type_of_scan = 'Core Analysis'
         AND qwh.kid = o_kid;
--           
      i_cnt := 0;
      SELECT COUNT(*)
        INTO i_cnt
        FROM qualified.images
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid))
         AND file_url IS NOT NULL;
--
      g_cnt := 0;
      SELECT COUNT(*)
        INTO g_cnt
       FROM iqstrat.doe_co2_georeport
      WHERE well_header_kid = o_kid; 
--         
      l3_cnt := 0;
      SELECT COUNT(*)
        INTO l3_cnt
        FROM iqstrat.doe_co2_las3
       WHERE well_header_kid IN (SELECT kid
                                   FROM qualified.well_headers
                                  WHERE well_header_kid = (SELECT well_header_kid
                                                             FROM qualified.well_headers
                                                            WHERE kid = o_kid));
--         
--    Validate LAS File Depth Range with Tops
--
      IF (l_cnt > 0) THEN
        las_value := 0;
--        
        OPEN las_file_info_crsr(o_kid);
        LOOP
          FETCH las_file_info_crsr
           INTO  l_start,
                 l_stop;
          EXIT WHEN las_file_info_crsr%NOTFOUND;
--
          IF (t_cnt > 0) AND (las_value = 0) THEN
            SELECT MAX(depth_top), MIN(depth_top)
              INTO l_max, l_min
--              FROM qualified.well_tops
              FROM iqstrat.doe_co2_tops
             WHERE well_header_kid = o_kid;
--      
            IF (l_min >= l_start) AND (l_max <= l_stop) THEN
                las_value := 2;
            ELSIF (l_min >= l_start) OR (l_max <= l_stop) THEN
                IF (las_value < 2) THEN
                  las_value := 1;
                END IF;
            ELSE
              IF (las_value < 1) THEN
                las_value := 0;
              END IF;
            END IF;
          END IF;
--
        END LOOP;
        CLOSE las_file_info_crsr;
      END IF;
--
      htp.tableRowOpen('LEFT');
--        htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_web_page?sKID='||o_kid||'" target="body">'||o_kid||'</a></td>');
        htp.p('<td><a href="http://chasm.kgs.ku.edu/ords/qualified.well_page.DisplayWell?f_kid='||o_kid||'" target="body">'||o_kid||'</a></td>');
--        htp.tableData(o_kid);
        IF (o_api != '-99') THEN
          htp.tableData(o_api);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
        htp.tableData(o_name);
        htp.tableData(o_TRS);
--        
        IF (o_depth != -99) THEN
          htp.tableData(o_depth);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        
        IF (o_form != '-99') THEN
          htp.tableData(o_form);
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        
        IF (tl_cnt > 0) THEN
          htp.p('<td class=excellent>Type</td>');
        ELSIF (tc_cnt > 0) THEN
          htp.p('<td class=good>CO<sub>2</sub></td>');
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        
        IF (l_cnt = 0) THEN
          htp.p('<td class=empty>'||l_cnt||'</td>');
        ELSIF (l_cnt > 0) THEN
          IF (las_value = 2) THEN
            htp.p('<td class=good>'||l_cnt||'</td>');
          ELSIF (las_value = 1) THEN
            htp.p('<td class=fair>'||l_cnt||'</td>');
          ELSE
            htp.p('<td class=poor>'||l_cnt||'</td>');
          END IF;
        ELSE
          htp.tableData(l_cnt);
        END IF;
--        
--        IF (t_cnt = 0) THEN
        IF ((t_cnt = 0) AND (ts_cnt = 0))THEN
          htp.p('<td class=empty>'||t_cnt||'</td>');
        ELSIF ((t_cnt = 0) AND (ts_cnt > 0))THEN
          htp.p('<td class=silver>'||ts_cnt||'</td>');
        ELSIF (t_cnt < 10) THEN
          htp.p('<td class=poor>'||t_cnt||'</td>');
        ELSIF (t_cnt < 20) THEN
          htp.p('<td class=fair>'||t_cnt||'</td>');
        ELSIF (t_cnt < 30) THEN
          htp.p('<td class=good>'||t_cnt||'</td>');
        ELSIF (t_cnt >= 30) THEN
          htp.p('<td class=excellent>'||t_cnt||'</td>');
        END IF;
--
        IF (ta_cnt > 0) THEN
          htp.p('<td class=good>Arbuckle</td>');
        ELSE 
          htp.tableData('&nbsp;');
        END IF;
--
        IF ((c_cnt > 0) AND (ck_cnt > 0)) THEN
          htp.p('<td class=excellent>BOTH</td>');
        ELSIF ((ck_cnt > 0) AND (ca_cnt > 0)) THEN
          htp.p('<td class=good>K-P</td>');
        ELSIF (ck_cnt > 0) THEN
          htp.p('<td class=silver>KGS</td>');
        ELSIF (ca_cnt > 0) THEN
          htp.p('<td class=fair>PDF</td>');
        ELSIF (c_cnt > 0) THEN
          htp.p('<td class=poor>CO<sub>2</sub></td>');
        ELSE 
          htp.tableData('&nbsp;');
        END IF;
--        
        IF (e_cnt > 0) THEN
          htp.p('<td class=fair>Davies</td>');
        ELSIF (e2_cnt > 0) THEN
          htp.p('<td class=poor>Other</td>');
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        
        IF (g_cnt > 0) THEN
          htp.p('<td class=good>ASCII Text</td>');
        ELSE
          htp.tableData('&nbsp;');
        END IF;
--        IF (e_cnt > 0) AND (g_cnt = 0) THEN
--          htp.p('<td class=fair>TIFF (Davies)</td>');
--        ELSIF (e2_cnt > 0) AND (g_cnt = 0) THEN
--          htp.p('<td class=poor>TIFF (Other)</td>');
--        ELSIF (g_cnt > 0) THEN
--          htp.p('<td class=good>ASCII Text</td>');
--        ELSE
--          htp.tableData('&nbsp;');
--        END IF;
-- 
       l3_status := '-99';
        IF (l3_cnt > 0) THEN
          SELECT NVL(file_status, '-99') 
            INTO l3_status
            FROM iqstrat.doe_co2_las3
--           WHERE well_header_kid = o_kid; 
           WHERE well_header_kid IN (SELECT kid
                                       FROM qualified.well_headers
                                      WHERE well_header_kid = (SELECT well_header_kid
                                                                 FROM qualified.well_headers
                                                                WHERE kid = o_kid));
--
          IF (l3_status != '-99') THEN
            htp.p('<td class=good><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_image_page?sKID='||o_kid||'" target="body">VIEW</a></td>');
          ELSE
            htp.p('<td class=fair><a href="http://chasm.kgs.ku.edu/ords/iqstrat.doe_co2_summary_pkg.build_image_page?sKID='||o_kid||'" target="body">VIEW</a></td>');
          END IF;
        ELSE 
          htp.tableData('&nbsp;');
        END IF;
--        
--        IF (l_cnt = 0) AND (t_cnt = 0) THEN
--          htp.p('<td class=empty>Empty</td>');
--        ELSIF (l3_status != '-99') AND (las_value = 2) THEN
--          htp.p('<td class=complete>Complete</td>');
--        ELSIF (l3_cnt > 0) AND (las_value = 2) THEN
--          htp.p('<td class=excellent>Done</td>');
--        ELSIF (l_cnt = 0) AND (t_cnt > 0) THEN
--          htp.p('<td class=empty>Missing</td>');
--        ELSIF (l_cnt > 0) AND (t_cnt = 0) THEN
--          htp.p('<td class=empty>Missing</td>');
--        ELSIF (l_cnt > 0) AND (t_cnt < 10) THEN
--          htp.p('<td class=poor>Poor</td>');
--        ELSIF (l_cnt > 0) AND (t_cnt < 30) THEN
--          htp.p('<td class=fair>Fair</td>');
--        ELSIF (l_cnt > 0) AND (t_cnt >= 30) THEN
--          htp.p('<td class=good>Good</td>');
--        END IF;
--        
      htp.tableRowClose;
--
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.tableRowOpen('CENTER');
        htp.tableData(SQLERRM);
      htp.tableRowClose;
--
  END add_well;
--
--
-- PROCEDURE    build_title_icons
-- Description: This procedure will add the Title icons to the Web Page
--
  PROCEDURE build_title_icons(sTitle IN VARCHAR2) IS
--
  BEGIN
--
    htp.print('<table class=header cellpadding="2" cellspacing="2" border="0" width="100%">');
    htp.print('  <tr>');
    htp.print('    <td width=108>');
    htp.print('      <a href="http://www.kgs.ku.edu/"');
    htp.print('         target="body">');
    htp.print('         <img src="http://www.kgs.ku.edu/PRS/Ozark/Summary/images/kgsSmB.png"');
    htp.print('              border="0"');
    htp.print('              align="left"></a>');
    htp.print('    </td>');
    htp.print('    <td><center><h1>South-central Kansas CO<sub>2</sub> Project<br>'||sTitle||'<br>Cuttings Reports</h1></center></td>');
    htp.print('  </tr>');
    htp.print('</table>');
--
    htp.line;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_title_icons;
--
--
-- PROCEDURE    build_finish
-- Description: This procedure will close out the Web Page
--
  PROCEDURE build_finish(sCounty IN VARCHAR2) IS
--
  BEGIN
--
    htp.line;
--
-- End Section for the Web Page
--
    htp.print('This web page generated by ORACLE PLSQL Stored '||
              'Procedure http://chasm.kgs.ku.edu/ords/iqstrat.kgs_summary_pkg.build_web_page?sCounty='||sCounty);
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM||'. Please try again later.');
  END build_finish;
--
--
END kgs_summary_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON kgs_summary_pkg TO apex_public_user;