-- * PLSQL:       production_doe_co2_wells_pkg.sql Version 1.1 10/11/2007
-- * Author:      John R. Victorine
-- * Description: This Package will retrieve the Headers information.
-- * Copyright (c) 2012 Kansas Geological Survey
-- * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
-- * All Rights Reserved.
--
SET SCAN OFF;
--
CREATE OR REPLACE PACKAGE production_doe_co2_wells_pkg AS
  PROCEDURE getXML;
  PROCEDURE getWellXML(sCounty IN VARCHAR2);
  PROCEDURE getWellXML(sArea IN VARCHAR2);
  PROCEDURE getWellXML(sField IN VARCHAR2);
  PROCEDURE getData(sKID IN VARCHAR2);
--
  PROCEDURE getLeaseXML(sField IN VARCHAR2);
  PROCEDURE getLeaseXML(sLatMin  IN VARCHAR2,
                        sLatMax  IN VARCHAR2,
                        sLongMin IN VARCHAR2,
                        sLongMax IN VARCHAR2);
  PROCEDURE getLeaseData(sKID IN VARCHAR2);
--  
  PROCEDURE dtd_and_columns;
END production_doe_co2_wells_pkg;
/
--
CREATE OR REPLACE PACKAGE BODY production_doe_co2_wells_pkg AS
--
-- PROCEDURE    getXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Output:    xml stream containing user information.
--
  PROCEDURE getXML IS
--
    l_count   NUMBER;
    o_kid     qualified.well_headers.kid%TYPE;        -- primary key
    o_api     qualified.well_headers.api_number%TYPE; -- API-Number
--
    CURSOR crsr IS
      SELECT qwh.kid, 
             qwh.api_number
        FROM qualified.well_headers qwh,
             elog.ozark_co2 itlw
      WHERE qwh.kid = itlw.well_header_kid
      ORDER BY qwh.api_number;
--
  BEGIN
--
    SELECT COUNT(kid)
      INTO l_count
      FROM qualified.well_headers qwh,
           elog.ozark_co2 itlw
     WHERE qwh.kid = itlw.well_header_kid;
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr;
      LOOP
        FETCH crsr
         INTO o_kid,    -- headers table primary key
              o_api;    -- API-Number
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sCounty = the county to select from 
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sCounty IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sCounty IN VARCHAR2) IS
      SELECT UNIQUE(well_header_kid)
        FROM qualified.well_headers
       WHERE county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty)
         AND field_kid > 0
         AND (oil_lease_kid > 0
         OR gas_lease_kid > 0 );
--
  BEGIN
--
      SELECT COUNT(UNIQUE(well_header_kid))
        INTO l_count
        FROM qualified.well_headers
       WHERE county_code = (SELECT code 
                                  FROM global.counties 
                                 WHERE LOWER(name) = sCounty)
         AND field_kid > 0
         AND (oil_lease_kid > 0
         OR gas_lease_kid > 0 );
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sCounty);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sArea = the area id
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sArea IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sArea IN VARCHAR2) IS
      SELECT UNIQUE(well_header_kid)
        FROM qualified.well_headers 
       WHERE county_code IN (SELECT county_code 
                               FROM iqstrat.type_log_county
                              WHERE area_id = sArea);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(well_header_kid))
      INTO l_count
      FROM qualified.well_headers
     WHERE county_code IN (SELECT county_code 
                             FROM iqstrat.type_log_county 
                            WHERE area_id = sArea);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sArea);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getWellXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sField = the field kid to select from 
-- * Output:    xml stream containing user information.
--
  PROCEDURE getWellXML(sField IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sField IN VARCHAR2) IS
      SELECT UNIQUE(well_header_kid)
        FROM qualified.well_headers
       WHERE field_kid = sField;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(well_header_kid))
      INTO l_count
      FROM qualified.well_headers
     WHERE field_kid = sField;
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sField);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getWellXML;
--
--
-- PROCEDURE    getData()
-- Description: This procedure will retrieve headers information from the
--              headers table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--
  PROCEDURE getData(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        qualified.well_headers.kid%TYPE;                -- Primary Key for table
    o_name       qualified.well_headers.lease_name%TYPE;         -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;          -- well status or Outcrop Type 
--    o_oil        qualified.well_headers.produces_oil%TYPE;       -- Produces OIL
--    o_gas        qualified.well_headers.produces_gas%TYPE;       -- Produces GAS
-- Other well Data Columns
    o_field      qualified.well_headers.field_name%TYPE;    -- Field Name       (well)
    o_field_kid  qualified.well_headers.field_kid%TYPE;     -- Field KID        (well)
    o_operator   qualified.well_headers.operator_name%TYPE; -- Operator Name    (well)
    o_oper_kid   qualified.well_headers.operator_kid%TYPE;  -- Operator KID     (well)
    o_oil_kid    qualified.well_headers.oil_lease_kid%TYPE;   -- Oil Lease Production KID
    o_gas_kid    qualified.well_headers.gas_lease_kid%TYPE;   -- GAS Lease Production KID
-- Location Columns
    o_state_cd   qualified.well_headers.state_code%TYPE;         -- State Code
    o_state      global.states.name%TYPE;                     -- State Name
    o_county_cd  qualified.well_headers.county_code%TYPE;        -- County Code
    o_county     global.states_counties.county_name%TYPE;     -- County Name
    o_township   qualified.well_headers.township%TYPE;           -- Township
    o_town_dir   qualified.well_headers.township_direction%TYPE; -- Township direction
    o_range      qualified.well_headers.range%TYPE;              -- Range
    o_range_dir  qualified.well_headers.range_direction%TYPE;    -- Range direction
    o_section    qualified.well_headers.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   qualified.well_headers.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  qualified.well_headers.nad27_longitude%TYPE;    -- Longitude in decimal degrees
    o_utm_x      qualified.well_headers.nad27_utm_x%TYPE;        -- UTM X-Coordinate
    o_utm_y      qualified.well_headers.nad27_utm_y%TYPE;        -- UTM Y-Coordinate
    o_utm_zone   qualified.well_headers.nad27_utm_zone%TYPE;     -- UTM Zone
--
    o_text       VARCHAR(2000);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT well_header_kid,                    
             NVL(REPLACE((lease_name||' '||well_name),'&','&amp;'), '-99'),
             NVL(REPLACE(status,'&','&amp;'), '-99'),  
             NVL(REPLACE(field_name,'&','&amp;'), '-99'), 
             NVL(field_kid, -99), 
             NVL(REPLACE(operator_name,'&','&amp;'), '-99'),
             NVL(operator_kid, -99),
             NVL(oil_lease_kid, -99), 
             NVL(gas_lease_kid, -99),
             NVL(state_code, -9),
             NVL((SELECT name 
                    FROM global.states 
                   WHERE code = A.state_code), '-99'), 
             NVL(county_code, -99),  
             NVL((SELECT county_name 
                    FROM global.states_counties 
                   WHERE state_code = A.state_code
                     AND county_code = A.county_code), '-99'), 
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(nad27_utm_x, -99), 
             NVL(nad27_utm_y, -99), 
             NVL(nad27_utm_zone, -99) 
        FROM qualified.well_headers A
       WHERE kid = sKID;
--
  BEGIN
--
    o_kid       := '-99';
    o_name      := '-99';  -- Well Name or Outcrop Name
--    o_oil       := '-99';  -- Produces Oil 
--    o_gas       := '-99';  -- Produces Gas 
    o_status    := '-99';  -- well status or Outcrop Type  
-- Other well Data Columns
    o_field     := '-99';  -- Field Name       (well)
    o_field_kid := -99;    -- Field KID        (well)
    o_operator  := '-99';  -- Operator Name    (well)
    o_oper_kid  := -99;    -- Operator KID     (well)
    o_oil_kid   := -99;    -- Oil Lease Production KID
    o_gas_kid   := -99;    -- Gas Lease Production KID
-- Location Columns
    o_state_cd  := -9;     -- State Code
    o_state     := '-99';  -- State Name
    o_county_cd := -99;    -- County Code
    o_county    := '-99';  -- County Name
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- XY Position of Columns
    o_latitude  := -99;    -- Latitude in decimal degrees
    o_longitude := -99;    -- Longitude in decimal degrees
    o_utm_x     := -99;    -- UTM X-Coordinate
    o_utm_y     := -99;    -- UTM Y-Coordinate
    o_utm_zone  := -99;    -- UTM Zone
--
--  Count the total number of LAS Files for a specific well.
--
--    SELECT COUNT(kid)
--      INTO l_count                   -- Total Number of Digital LAS Files
--      FROM las.well_headers
--     WHERE well_header_kid IN (SELECT kid
--                                 FROM qualified.well_headers
--                                WHERE well_header_kid = sKID);
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_name,      -- Well Name or Outcrop Name
            o_status,    -- Well Status
            -- Other well Data Columns
            o_field,     -- Field Name       (well)
            o_field_kid, -- Field KID        (well)
            o_operator,  -- Operator Name    (well)
            o_oper_kid,  -- Operator KID     (well)
            o_oil_kid,   -- Oil Lease KID
            o_gas_kid,   -- Gas Lease KID
--            o_oil,       -- produces OIL
--            o_gas,       -- produces GAS
            -- Location Columns
            o_state_cd,  -- State Code
            o_state,     -- State Name
            o_county_cd, -- County Code
            o_county,    -- County Name
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            o_utm_x,     -- UTM X-Coordinate
            o_utm_y,     -- UTM Y-Coordinate
            o_utm_zone;  -- UTM Zone
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        htp.print('  <data>');
        o_text := '    <info kid="'||o_kid||'" ';
--        
        IF (o_name != '-99') THEN
          o_name := REPLACE(o_name, '"', '??');        
          o_text := o_text||'name="'||o_name||'" ';
        END IF;
--        
        IF (o_status != '-99') THEN
          o_text := o_text||'status="'||o_status||'" ';
        END IF;
--        
--        IF ((o_oil != 'No') AND (o_gas != 'No')) THEN
--          o_text := o_text||'status="O&amp;G" ';
--        ELSIF (o_oil != 'No') THEN
--          o_text := o_text||'status="OIL" ';
--        ELSIF (o_gas != 'No') THEN
--          o_text := o_text||'status="GAS" ';
--        END IF;
--
        o_text := o_text||' />';
        htp.print(o_text);
--
--      Other well information
--  
        IF ((o_field    != '-99') OR (o_field_kid != -99) OR
            (o_operator != '-99') OR (o_oper_kid  != -99) OR
            (o_oil_kid  != -99)   OR (o_gas_kid   != -99)) THEN
--            
          o_text := '    <other ';
--          
          IF (o_operator != '-99') THEN
            o_text := o_text||'operator="'||o_operator||'" ';
          END IF;       
--          
          IF (o_oper_kid != -99) THEN
            o_text := o_text||'oper_kid="'||o_oper_kid||'" ';
          END IF;
--          
          IF (o_field != '-99') THEN
            o_text := o_text||'field="'||o_field||'" ';
          END IF;
--          
          IF (o_field_kid != -99) THEN
            o_text := o_text||'field_kid="'||o_field_kid||'" ';
          END IF;
--
          IF (o_gas_kid != -99) THEN
            o_text := o_text||'gas_kid="'||o_gas_kid||'" ';
          END IF;
--        
          IF (o_oil_kid != -99) THEN
            o_text := o_text||'oil_kid="'||o_oil_kid||'" ';
          END IF;
--
          o_text := o_text||' />';
          htp.print(o_text);
        END IF;
--
--    Location Information
--
      IF ((o_state_cd != -9)    OR (o_state != '-99')   OR 
          (o_county_cd != -99)  OR (o_county != '-99')  OR 
          (o_township != -99)   OR (o_town_dir != 'X')  OR 
          (o_range != -99)      OR (o_range_dir != 'X') OR 
          (o_section != -9)) THEN
--            
        o_text := '    <loc ';
--          
        IF (o_state != '-99') THEN
          o_text := o_text||'state="'||o_state||'" ';
        END IF;       
--          
        IF (o_state_cd != -9) THEN
          o_text := o_text||'state_cd="'||o_state_cd||'" ';
        END IF;       
--          
        IF (o_county != '-99') THEN
          o_text := o_text||'county="'||o_county||'" ';
        END IF;       
--          
        IF (o_county_cd != -99) THEN
          o_text := o_text||'county_cd="'||o_county_cd||'" ';
        END IF;       
--          
        IF (o_township != -99) THEN
          o_text := o_text||'town="'||o_township||'" ';
        END IF;       
--          
        IF (o_town_dir != 'X') THEN
          o_text := o_text||'town_dir="'||o_town_dir||'" ';
        END IF;       
--          
        IF (o_range != -99) THEN
          o_text := o_text||'range="'||o_range||'" ';
        END IF;       
--          
        IF (o_range_dir != 'X') THEN
          o_text := o_text||'range_dir="'||o_range_dir||'" ';
        END IF;       
--          
        IF (o_section != -9) THEN
          o_text := o_text||'section="'||o_section||'" ';
        END IF;       
--
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    XY Position Information
--
      IF ((o_latitude != -99) OR (o_longitude != -99) OR 
          (o_utm_x != -99) OR (o_utm_y != -99)  OR (o_utm_zone != -99)) THEN
--            
        o_text := '    <xy ';
--          
        IF (o_latitude != -99) THEN
          o_text := o_text||'latitude="'||o_latitude||'" ';
        END IF;       
--          
        IF (o_longitude != -99) THEN
          o_text := o_text||'longitude="'||o_longitude||'" ';
        END IF;       
--          
        IF (o_utm_zone != -99) THEN
          o_text := o_text||'zone="'||o_utm_zone||'" ';
        END IF;       
--          
        IF (o_utm_x != -99) THEN
          o_text := o_text||'utm_x="'||o_utm_x||'" ';
        END IF;       
--          
        IF (o_utm_y != -99) THEN
          o_text := o_text||'utm_y="'||o_utm_y||'" ';
        END IF;       
--
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
      htp.print('  </data>');
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'" />');
      htp.print(' </data>');
--
  END getData;
--
--
-- PROCEDURE    getLeaseXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sField = the field kid to select from 
-- * Output:    xml stream containing user information.
--
  PROCEDURE getLeaseXML(sField IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sField IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM nomenclature.leases
       WHERE field_kid = sField
         AND 'T'||township||township_direction||'-'||
             'R'||range||range_direction||'-'||
             'S'||section IN ( SELECT 'T'||township||township_direction||'-'||
                                      'R'||range||range_direction||'-'||
                                      'S'||section
                                 FROM nomenclature.fields_sections
                                WHERE FIELD_KID = sField);
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM nomenclature.leases
     WHERE field_kid = sField
       AND 'T'||township||township_direction||'-'||
           'R'||range||range_direction||'-'||
           'S'||section IN ( SELECT 'T'||township||township_direction||'-'||
                                    'R'||range||range_direction||'-'||
                                    'S'||section
                               FROM nomenclature.fields_sections
                              WHERE FIELD_KID = sField);
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sField);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getLeaseData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getLeaseXML;
--
--
-- PROCEDURE    getLeaseXML()
-- Description: This procedure will retrieve well headers information from the
--              qualified well headers table using the iqstrat type log wells table
--              api-numbers and construct a XML.
-- * Input:     sLatMin  = the Minimum Latitude  
--              sLatMax  = the Maximum Latitude
--              sLongMin = the Minimum Longitude  
--              sLongMax = the Maximum Longitude
-- * Output:    xml stream containing user information.
--
  PROCEDURE getLeaseXML(sLatMin  IN VARCHAR2,
                        sLatMax  IN VARCHAR2,
                        sLongMin IN VARCHAR2,
                        sLongMax IN VARCHAR2) IS
--
    l_count  NUMBER;
    o_kid    user_headers.headers_kid%TYPE; -- headers table primary key
--
    CURSOR crsr(sLatMin  IN VARCHAR2,
                sLatMax  IN VARCHAR2,
                sLongMin IN VARCHAR2,
                sLongMax IN VARCHAR2) IS
      SELECT UNIQUE(kid)
        FROM nomenclature.leases
       WHERE nad27_latitude  >= sLatMin
         AND nad27_latitude  <= sLatMax
         AND nad27_longitude >= sLongMin
         AND nad27_longitude <= sLongMax;
--
  BEGIN
--
    SELECT COUNT(UNIQUE(kid))
      INTO l_count
      FROM nomenclature.leases
     WHERE nad27_latitude  >= sLatMin
       AND nad27_latitude  <= sLatMax
       AND nad27_longitude >= sLongMin
       AND nad27_longitude <= sLongMax;
--
--  ADD Headers DTD 
--
    dtd_and_columns;
--
    IF (l_count > 0) THEN
--
      htp.print('<headers records="'||l_count||'">');     
--
      OPEN crsr(sLatMin, sLatMax, sLongMin, sLongMax);
      LOOP
        FETCH crsr
         INTO o_kid;    -- headers table primary key
        EXIT WHEN crsr%NOTFOUND;
--
        getLeaseData(o_kid);
--
      END LOOP;
      CLOSE crsr;
--
      htp.print('</headers>');
    ELSE
      htp.print('<headers records="0">');
      htp.print(' <data>');
      htp.print('    <info error="NO DATA AVAILABLE"/>');
      htp.print(' </data>');
      htp.print('</headers>');
    END IF;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'"/>');
      htp.print(' </data>');
      htp.print('</headers>');
--
  END getLeaseXML;
--
--
-- PROCEDURE    getLeaseData()
-- Description: This procedure will retrieve headers information from the
--              leases table and construct a XML.
-- Input:       sKID = Headers Primary Key of the header information data 
--
  PROCEDURE getLeaseData(sKID IN VARCHAR2) IS
--
    l_count      NUMBER;
--    
    o_kid        nomenclature.leases.kid%TYPE;                -- Primary Key for table
    o_name       nomenclature.leases.lease_name%TYPE;         -- Well Name or Outcrop Name
    o_status     qualified.well_headers.status%TYPE;          -- well status or Outcrop Type 
    o_oil        nomenclature.leases.produces_oil%TYPE;       -- Produces OIL
    o_gas        nomenclature.leases.produces_gas%TYPE;       -- Produces GAS
-- Other well Data Columns
    o_oil_kid    qualified.well_headers.oil_lease_kid%TYPE;   -- Oil Lease Production KID
    o_gas_kid    qualified.well_headers.gas_lease_kid%TYPE;   -- GAS Lease Production KID
-- Location Columns
    o_state_cd   nomenclature.leases.state_code%TYPE;         -- State Code
    o_state      global.states.name%TYPE;                     -- State Name
    o_county_cd  nomenclature.leases.county_code%TYPE;        -- County Code
    o_county     global.states_counties.county_name%TYPE;     -- County Name
    o_township   nomenclature.leases.township%TYPE;           -- Township
    o_town_dir   nomenclature.leases.township_direction%TYPE; -- Township direction
    o_range      nomenclature.leases.range%TYPE;              -- Range
    o_range_dir  nomenclature.leases.range_direction%TYPE;    -- Range direction
    o_section    nomenclature.leases.section%TYPE;            -- Section
-- XY Position of Columns
    o_latitude   nomenclature.leases.nad27_latitude%TYPE;     -- Latitude in decimal degrees
    o_longitude  nomenclature.leases.nad27_longitude%TYPE;    -- Longitude in decimal degrees
    o_utm_x      nomenclature.leases.nad27_utm_x%TYPE;        -- UTM X-Coordinate
    o_utm_y      nomenclature.leases.nad27_utm_y%TYPE;        -- UTM Y-Coordinate
    o_utm_zone   nomenclature.leases.nad27_utm_zone%TYPE;     -- UTM Zone
--
    o_text       VARCHAR(2000);
--
    CURSOR crsr (sKID VARCHAR2) IS
      SELECT kid,                    
             NVL(REPLACE(lease_name,'&','&amp;'), '-99'),
             NVL(produces_oil, '-99'),
             NVL(produces_gas, '-99'),
             NVL(state_code, -9),
             NVL((SELECT name 
                    FROM global.states 
                   WHERE code = A.state_code), '-99'), 
             NVL(county_code, -99),  
             NVL((SELECT county_name 
                    FROM global.states_counties 
                   WHERE state_code = A.state_code
                     AND county_code = A.county_code), '-99'), 
             NVL(township, -99),  
             NVL(township_direction, 'X'), 
             NVL(range, -99),  
             NVL(range_direction, 'X'), 
             NVL(section, -9),
             NVL(nad27_latitude, -99), 
             NVL(nad27_longitude, -99), 
             NVL(nad27_utm_x, -99), 
             NVL(nad27_utm_y, -99), 
             NVL(nad27_utm_zone, -99) 
        FROM nomenclature.leases A
       WHERE kid = sKID;
--
  BEGIN
--
    o_kid       := '-99';
    o_name      := '-99';  -- Well Name or Outcrop Name
    o_oil       := '-99';  -- Produces Oil 
    o_gas       := '-99';  -- Produces Gas 
    o_status    := '-99';  -- well status or Outcrop Type  
-- Other well Data Columns
    o_oil_kid   := -99;    -- Oil Lease Production KID
    o_gas_kid   := -99;    -- Gas Lease Production KID
-- Location Columns
    o_state_cd  := -9;     -- State Code
    o_state     := '-99';  -- State Name
    o_county_cd := -99;    -- County Code
    o_county    := '-99';  -- County Name
    o_township  := -99;    -- Township
    o_town_dir  := 'X';    -- Township direction
    o_range     := -99;    -- Range
    o_range_dir := 'X';    -- Range direction
    o_section   := -9;     -- Section
-- XY Position of Columns
    o_latitude  := -99;    -- Latitude in decimal degrees
    o_longitude := -99;    -- Longitude in decimal degrees
    o_utm_x     := -99;    -- UTM X-Coordinate
    o_utm_y     := -99;    -- UTM Y-Coordinate
    o_utm_zone  := -99;    -- UTM Zone
--
--  Count the total number of LAS Files for a specific well.
--
--    SELECT COUNT(kid)
--      INTO l_count                   -- Total Number of Digital LAS Files
--      FROM las.well_headers
--     WHERE well_header_kid IN (SELECT kid
--                                 FROM qualified.well_headers
--                                WHERE well_header_kid = sKID);
--
    OPEN crsr(sKID);
    LOOP
      FETCH crsr
       INTO o_kid,       -- Primary Key for table
            o_name,      -- Well Name or Outcrop Name
            o_oil,       -- produces OIL
            o_gas,       -- produces GAS
            -- Location Columns
            o_state_cd,  -- State Code
            o_state,     -- State Name
            o_county_cd, -- County Code
            o_county,    -- County Name
            o_township,  -- Township
            o_town_dir,  -- Township direction
            o_range,     -- Range
            o_range_dir, -- Range direction
            o_section,   -- Section
            -- XY Position of Columns
            o_latitude,  -- Latitude in decimal degrees
            o_longitude, -- Longitude in decimal degrees
            o_utm_x,     -- UTM X-Coordinate
            o_utm_y,     -- UTM Y-Coordinate
            o_utm_zone;  -- UTM Zone
      EXIT WHEN crsr%NOTFOUND;
--
--      Identification Information
--
        htp.print('  <data>');
        o_text := '    <info kid="'||o_kid||'" ';
--        
        IF (o_name != '-99') THEN
          o_name := REPLACE(o_name, '"', ' ');        
          o_text := o_text||'name="'||o_name||'" ';
        END IF;
--        
        IF ((o_oil != 'No') AND (o_gas != 'No')) THEN
          o_text := o_text||'status="O&amp;G" ';
        ELSIF (o_oil != 'No') THEN
          o_text := o_text||'status="OIL" ';
        ELSIF (o_gas != 'No') THEN
          o_text := o_text||'status="GAS" ';
        END IF;
--
        o_text := o_text||' />';
        htp.print(o_text);
--
--      Other well information
--  
        IF ((o_oil != 'No') OR (o_gas != 'No')) THEN
--            
          o_text := '    <other ';
--          
          IF (o_gas != 'No') THEN
            o_text := o_text||'gas_kid="'||o_kid||'" ';
          END IF;
--        
          IF (o_oil != 'No') THEN
            o_text := o_text||'oil_kid="'||o_kid||'" ';
          END IF;
--
          o_text := o_text||' />';
          htp.print(o_text);
        END IF;
--
--    Location Information
--
      IF ((o_state_cd != -9)    OR (o_state != '-99')   OR 
          (o_county_cd != -99)  OR (o_county != '-99')  OR 
          (o_township != -99)   OR (o_town_dir != 'X')  OR 
          (o_range != -99)      OR (o_range_dir != 'X') OR 
          (o_section != -9)) THEN
--            
        o_text := '    <loc ';
--          
        IF (o_state != '-99') THEN
          o_text := o_text||'state="'||o_state||'" ';
        END IF;       
--          
        IF (o_state_cd != -9) THEN
          o_text := o_text||'state_cd="'||o_state_cd||'" ';
        END IF;       
--          
        IF (o_county != '-99') THEN
          o_text := o_text||'county="'||o_county||'" ';
        END IF;       
--          
        IF (o_county_cd != -99) THEN
          o_text := o_text||'county_cd="'||o_county_cd||'" ';
        END IF;       
--          
        IF (o_township != -99) THEN
          o_text := o_text||'town="'||o_township||'" ';
        END IF;       
--          
        IF (o_town_dir != 'X') THEN
          o_text := o_text||'town_dir="'||o_town_dir||'" ';
        END IF;       
--          
        IF (o_range != -99) THEN
          o_text := o_text||'range="'||o_range||'" ';
        END IF;       
--          
        IF (o_range_dir != 'X') THEN
          o_text := o_text||'range_dir="'||o_range_dir||'" ';
        END IF;       
--          
        IF (o_section != -9) THEN
          o_text := o_text||'section="'||o_section||'" ';
        END IF;       
--
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
--    XY Position Information
--
      IF ((o_latitude != -99) OR (o_longitude != -99) OR 
          (o_utm_x != -99) OR (o_utm_y != -99)  OR (o_utm_zone != -99)) THEN
--            
        o_text := '    <xy ';
--          
        IF (o_latitude != -99) THEN
          o_text := o_text||'latitude="'||o_latitude||'" ';
        END IF;       
--          
        IF (o_longitude != -99) THEN
          o_text := o_text||'longitude="'||o_longitude||'" ';
        END IF;       
--          
        IF (o_utm_zone != -99) THEN
          o_text := o_text||'zone="'||o_utm_zone||'" ';
        END IF;       
--          
        IF (o_utm_x != -99) THEN
          o_text := o_text||'utm_x="'||o_utm_x||'" ';
        END IF;       
--          
        IF (o_utm_y != -99) THEN
          o_text := o_text||'utm_y="'||o_utm_y||'" ';
        END IF;       
--
        o_text := o_text||' />';
        htp.print(o_text);
      END IF;
--
      htp.print('  </data>');
    END LOOP;
    CLOSE crsr;
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.print(' <data>');
      htp.print('    <info error="'||SQLERRM||'" />');
      htp.print(' </data>');
--
  END getLeaseData;
--
--
-- PROCEDURE    dtd_and_columns
-- Description: This procedure will build the DTD and the Columns in the core
--              data table.
  PROCEDURE dtd_and_columns IS
--
  BEGIN
--
    htp.print('<?xml version="1.0"?>');
    htp.print('<!DOCTYPE headers [');
    htp.print('<!ELEMENT headers (data*)>');                  
    htp.print('<!ATTLIST headers records CDATA #IMPLIED>');    -- Total # of Records
    htp.print('<!ELEMENT data (info*, ');                      
    htp.print('                other?, ');                     
    htp.print('                loc?, ');                       
    htp.print('                xy?, ');                        
    htp.print('                z?, ');                         
    htp.print('                comments?, ');                  
    htp.print('                misc?, ');                  
    htp.print('                cnt?)>');                      
    htp.print('<!ELEMENT info  EMPTY>');                       
    htp.print('<!ATTLIST info  kid   CDATA #IMPLIED');          -- Primary KGS KEY
    htp.print('                well_kid   CDATA #IMPLIED');     -- Primary KEY Defined
    htp.print('                key   CDATA #IMPLIED');          -- Primary KEY Defined
    htp.print('                type  CDATA #IMPLIED');          -- type of data
    htp.print('                api   CDATA #IMPLIED');          -- API Number of Well
    htp.print('                name   CDATA #IMPLIED');         -- Outcrop Name
    htp.print('                status CDATA #IMPLIED');         -- Well Status
    htp.print('                error  CDATA #IMPLIED>');        -- Error
    htp.print('<!ELEMENT other EMPTY>');                       
    htp.print('<!ATTLIST other operator  CDATA #IMPLIED');      -- Operator Name
    htp.print('                oper_kid  CDATA #IMPLIED');      -- Operator KID
    htp.print('                field     CDATA #IMPLIED');      -- Field Name
    htp.print('                field_kid CDATA #IMPLIED');      -- Field KID
    htp.print('                gas_kid   CDATA #IMPLIED');      -- GAS Lease Production KID
    htp.print('                oil_kid   CDATA #IMPLIED>');     -- OIL Lease Production KID
    htp.print('<!ELEMENT loc EMPTY>');                         
    htp.print('<!ATTLIST loc state     CDATA #IMPLIED');        -- State Name
    htp.print('              state_cd  CDATA #IMPLIED');        -- State Code
    htp.print('              county    CDATA #IMPLIED');        -- County Name
    htp.print('              county_cd CDATA #IMPLIED');        -- County Code
    htp.print('              loc       CDATA #IMPLIED');        -- Location
    htp.print('              town      CDATA #IMPLIED');        -- township
    htp.print('              town_dir  CDATA #IMPLIED');        -- township direction
    htp.print('              range     CDATA #IMPLIED');        -- range
    htp.print('              range_dir CDATA #IMPLIED');        -- range direction
    htp.print('              section   CDATA #IMPLIED>');       -- section
    htp.print('<!ELEMENT xy  EMPTY>');                         
    htp.print('<!ATTLIST xy  latitude  CDATA #IMPLIED');        -- Latitude
    htp.print('              longitude CDATA #IMPLIED');        -- Longitude
    htp.print('              zone      CDATA #IMPLIED');        -- UTM X-Position
    htp.print('              utm_x     CDATA #IMPLIED');        -- UTM X-Position
    htp.print('              utm_y     CDATA #IMPLIED>');       -- UTM Y-Position
    htp.print('<!ELEMENT z   EMPTY>');                         
    htp.print('<!ATTLIST z   depth     CDATA #IMPLIED');        -- Depth or Height
    htp.print('              gl        CDATA #IMPLIED');        -- Ground Level
    htp.print('              kb        CDATA #IMPLIED');        -- Kelly Bushing
    htp.print('              df        CDATA #IMPLIED>');       -- Derrick Floor
    htp.print('<!ELEMENT comments (#PCDATA)>');                 -- Comments
    htp.print('<!ELEMENT misc EMPTY>');                        
    htp.print('<!ATTLIST misc user      CDATA #IMPLIED');       -- user update info
    htp.print('               access    CDATA #IMPLIED');       -- access of data
    htp.print('               source    CDATA #IMPLIED');       -- source of this data
    htp.print('               date      CDATA #IMPLIED>');      -- Date modified    
    htp.print('<!ELEMENT cnt  EMPTY>');
    htp.print('<!ATTLIST cnt  las       CDATA #IMPLIED');
    htp.print('               upload    CDATA #IMPLIED');
    htp.print('               elog      CDATA #IMPLIED');
    htp.print('               urls      CDATA #IMPLIED');
    htp.print('               eval      CDATA #IMPLIED');
    htp.print('               tops      CDATA #IMPLIED');
    htp.print('               geo       CDATA #IMPLIED');
    htp.print('               ohm_log   CDATA #IMPLIED');
    htp.print('               litho_log CDATA #IMPLIED');
    htp.print('               sonic_log CDATA #IMPLIED');
    htp.print('               gr_log    CDATA #IMPLIED');
    htp.print('               spgr_log  CDATA #IMPLIED>]>');
--    htp.print('               core      CDATA #IMPLIED');
--    htp.print('               images    CDATA #IMPLIED>]>');
--
  EXCEPTION
    WHEN OTHERS THEN
      htp.p('An error occurred: '||SQLERRM);
  END dtd_and_columns;
--
--
END production_doe_co2_wells_pkg;
/
SHOW ERRORS;
--
GRANT EXECUTE ON production_doe_co2_wells_pkg TO apex_public_user;